@@ -8,7 +8,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 
 /**
@@ -25,7 +25,7 @@
  * @package    SeedDMS_Core
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012-2013 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Attribute { /* {{{ */
 	/**
@@ -175,7 +175,7 @@ class SeedDMS_Core_Attribute { /* {{{ */
 
 			if(is_array($values)) {
 				if($values) {
-					$vsep = $this->getValueSetSeparator();
+					$vsep = $this->_attrdef->getValueSetSeparator();
 					if($valueset) {
 						/* Validation should have been done before
 						$error = false;
@@ -326,7 +326,7 @@ class SeedDMS_Core_Attribute { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	/**
@@ -409,7 +409,9 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	protected $_dms;
 
 	/**
-	 * @var string
+	 * @var string just the separator of a value set (not used)
+	 *
+	 * @access protected
 	 */
 	protected $_separator;
 
@@ -441,6 +443,25 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	const objtype_document = '2';
 	const objtype_documentcontent = '3';
 
+	/*
+	 * The validation error codes
+	 */
+	const val_error_none = 0;
+	const val_error_min_values = 1;
+	const val_error_max_values = 2;
+	const val_error_boolean = 8;
+	const val_error_int = 6;
+	const val_error_date = 9;
+	const val_error_float = 7;
+	const val_error_regex = 3;
+	const val_error_email = 5;
+	const val_error_url = 4;
+	const val_error_document = 10;
+	const val_error_folder = 11;
+	const val_error_user = 12;
+	const val_error_group = 13;
+	const val_error_valueset = 14;
+
 	/**
 	 * Constructor
 	 *
@@ -465,10 +486,10 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 		$this->_minvalues = $minvalues;
 		$this->_maxvalues = $maxvalues;
 		$this->_valueset = $valueset;
-		$this->_separator = '';
+		$this->_separator = substr($valueset, 0, 1);
 		$this->_regex = $regex;
 		$this->_dms = null;
-		$this->_validation_error = 0;
+		$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_none;
 	} /* }}} */
 
 	/**
@@ -671,10 +692,10 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 		if(strlen($this->_valueset) > 1) {
 			return $this->_valueset[0];
 		} elseif($this->_multiple) {
-			if($this->_type == SeedDMS_Core_AttributeDefinition::type_user || $this->_type == SeedDMS_Core_AttributeDefinition::type_group)
-				return ',';
-			else
+			if($this->_type == SeedDMS_Core_AttributeDefinition::type_boolean)
 				return '';
+			else
+				return ',';
 		} else {
 			return '';
 		}
@@ -683,6 +704,8 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	/**
 	 * Get the whole value set as an array
 	 *
+	 * Each element is trimmed.
+	 *
 	 * @return array values of value set or false if the value set has
 	 *         less than 2 chars
 	 */
@@ -694,9 +717,9 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	} /* }}} */
 
 	/**
-	 * Get the n'th value of a value set
+	 * Get the n'th trimmed value of a value set
 	 *
-	 * @param $ind
+	 * @param $ind starting from 0 for the first element in the value set
 	 * @return string n'th value of value set or false if the index is
 	 *         out of range or the value set has less than 2 chars
 	 * @internal param int $index
@@ -717,7 +740,9 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	 *
 	 * A value set is a list of values allowed for an attribute. The values
 	 * are separated by a char which must also be the first char of the
-	 * value set string.
+	 * value set string. The method decomposes the value set, removes all
+	 * leading and trailing white space from the elements and recombines them
+	 * into a string.
 	 *
 	 * @param string $valueset
 	 * @return boolean true if value set could be set, otherwise false
@@ -729,8 +754,9 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 			$tmp[] = str_replace('"', '""', $value);
 		}
 		$valuesetstr = implode(",", $tmp);
-	*/
-		if(trim($valueset)) {
+	 */
+		$valueset = trim($valueset);
+		if($valueset) {
 			$valuesetarr = array_map('trim', explode($valueset[0], substr($valueset, 1)));
 			$valuesetstr = $valueset[0].implode($valueset[0], $valuesetarr);
 		} else {
@@ -744,8 +770,8 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 		if (!$res)
 			return false;
 
-		$this->_valueset = $valueset;
-		$this->_separator = substr($valueset, 0, 1);
+		$this->_valueset = $valuesetstr;
+		$this->_separator = substr($valuesetstr, 0, 1);
 		return true;
 	} /* }}} */
 
@@ -763,12 +789,23 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	 *
 	 * A value of the attribute must match this regular expression.
 	 *
+	 * The methods checks if the regular expression is valid by running
+	 * preg_match() on an empty string and see if it fails. Trying to set
+	 * an invalid regular expression will not overwrite the current
+	 * regular expression.
+	 *
+	 * All leading and trailing spaces of $regex will be removed.
+	 *
 	 * @param string $regex
-	 * @return boolean true if regex could be set, otherwise false
+	 * @return boolean true if regex could be set or is invalid, otherwise false
 	 */
 	function setRegex($regex) { /* {{{ */
 		$db = $this->_dms->getDB();
 
+		$regex = trim($regex);
+		if($regex && @preg_match($regex, '') === false)
+			return false;
+
 		$queryStr = "UPDATE `tblAttributeDefinitions` SET `regex` =".$db->qstr($regex)." WHERE `id` = " . $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
@@ -809,13 +846,15 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	/**
 	 * Parse a given value according to attribute definition
 	 *
-	 * The return value is always an array, even if the attribute is single
-	 * value attribute.
+	 * The return value is always an array, even if the attribute is a single
+	 * value attribute. If the type of attribute is any of document, folder, user,
+	 * or group then this method will fetch each object from the database and
+	 * return an array of SeedDMS_Core_Document, SeedDMS_Core_Folder, etc.
 	 *
-	 * @param $value
+	 * @param $value string
 	 * @return array|bool
 	 */
-	function parseValue($value) { /* {{{ */
+	function parseValue(string $value) { /* {{{ */
 		if($this->getMultipleValues()) {
 			/* If the value doesn't start with the separator used in the value set,
 			 * then assume that the value was not saved with a leading separator.
@@ -897,6 +936,11 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 					}
 				}
 			}
+			$valueset = $this->getValueSetAsArray();
+			$possiblevalues = array();
+			foreach($valueset as $value) {
+				$possiblevalues[md5($value)] = array('value'=>$value, 'c'=>0);
+			}
 			$queryStr = "SELECT count(*) c, `value` FROM `tblDocumentAttributes` WHERE `attrdef`=".$this->_id." GROUP BY `value` ORDER BY c DESC";
 			$resArr = $db->getResultArray($queryStr);
 			if($resArr) {
@@ -1013,7 +1057,7 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	 * @param integer $limit limit number of documents/folders
 	 * @return array array containing list of documents and folders
 	 */
-	public function getObjects($attrvalue, $limit='') { /* {{{ */
+	public function getObjects($attrvalue, $limit=0) { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		$result = array('docs'=>array(), 'folders'=>array(), 'contents'=>array());
@@ -1144,8 +1188,10 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 	 *
 	 * @param string|array $attrvalue attribute value
 	 * @param object $object set if the current attribute is saved for this object
+	 *   (this will only be passed to the onAttributeValidate callback)
 	 * @param boolean $new set to true if the value is new value and not taken from
-	 *        an existing attribute
+	 *   an existing attribute
+	 *   (this will only be passed to the onAttributeValidate callback)
 	 * @return boolean true if validation succeds, otherwise false
 	 */
 	function validate($attrvalue, $object=null, $new=false) { /* {{{ */
@@ -1159,36 +1205,38 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 		}
 
 		/* Turn $attrvalue into an array of values. Checks if $attrvalue starts
-		 * with a separator char as set in the value set and uses it to explode
+		 * with a separator char as set in the value set and use it to explode
 		 * the $attrvalue. If the separator doesn't match or this attribute
 		 * definition doesn't have a value set, then just create a one element
 		 * array. if $attrvalue is empty, then create an empty array.
 		 */
 		if($this->getMultipleValues()) {
-			if(is_string($attrvalue)) {
+			if(is_string($attrvalue) && $attrvalue) {
 				$sep = $attrvalue[0];
 				$vsep = $this->getValueSetSeparator();
 				if($sep == $vsep)
 					$values = explode($attrvalue[0], substr($attrvalue, 1));
 				else
 					$values = array($attrvalue);
+			} elseif(is_string($attrvalue) && !$attrvalue) {
+				$values = array();
 			} else
-				$values = $attrvalue;
-		} elseif($attrvalue) {
+				$values = array($attrvalue);
+		} elseif($attrvalue !== null) {
 			$values = array($attrvalue);
 		} else {
 			$values = array();
 		}
 
 		/* Check if attribute value has at least the minimum number of values */
-		$this->_validation_error = 0;
+		$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_none;
 		if($this->getMinValues() > count($values)) {
-			$this->_validation_error = 1;
+			$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_min_values;
 			return false;
 		}
 		/* Check if attribute value has not more than maximum number of values */
 		if($this->getMaxValues() && $this->getMaxValues() < count($values)) {
-			$this->_validation_error = 2;
+			$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_max_values;
 			return false;
 		}
 
@@ -1196,54 +1244,56 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 		switch((string) $this->getType()) {
 		case self::type_boolean:
 			foreach($values as $value) {
-				$success &= preg_match('/^[01]$/', $value) ? true : false;
+				$success = $success && (preg_match('/^[01]$/', $value) ? true : false);
 			}
 			if(!$success)
-				$this->_validation_error = 8;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_boolean;
 			break;
 		case self::type_int:
 			foreach($values as $value) {
-				$success &= preg_match('/^[0-9]*$/', $value) ? true : false;
+				$success = $success && (preg_match('/^[0-9]*$/', $value) ? true : false);
 			}
 			if(!$success)
-				$this->_validation_error = 6;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_int;
 			break;
 		case self::type_date:
 			foreach($values as $value) {
-				$success &= preg_match('/^[12][0-9]{3}-[01][0-9]-[0-9]{2}$/', $value) ? true : false;
+				$d = explode('-', $value, 3);
+				$success = $success && (count($d) == 3)&& checkdate((int) $d[1], (int) $d[2], (int) $d[0]);
 			}
 			if(!$success)
-				$this->_validation_error = 9;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_date;
 			break;
 		case self::type_float:
 			foreach($values as $value) {
-				$success &= is_numeric($value);
+				$success = $success && is_numeric($value);
 			}
 			if(!$success)
-				$this->_validation_error = 7;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_float;
 			break;
 		case self::type_string:
 			if(trim($this->getRegex()) != '') {
 				foreach($values as $value) {
-					$success &= preg_match($this->getRegex(), $value) ? true : false;
+					$success = $success && (preg_match($this->getRegex(), $value) ? true : false);
 				}
 			}
 			if(!$success)
-				$this->_validation_error = 3;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_regex;
 			break;
 		case self::type_email:
 			foreach($values as $value) {
-				$success &= preg_match('/^[a-z0-9._-]+@+[a-z0-9._-]+\.+[a-z]{2,4}$/i', $value);
+				//$success &= filter_var($value, FILTER_VALIDATE_EMAIL) ? true : false;
+				$success = $success && (preg_match('/^[a-z0-9._-]+@[a-z0-9-]{2,63}(\.[a-z0-9-]{2,63})*\.[a-z]{2,63}$/i', $value) ? true : false);
 			}
 			if(!$success)
-				$this->_validation_error = 5;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_email;
 			break;
 		case self::type_url:
 			foreach($values as $value) {
-				$success &= preg_match('/^http(s)?:\/\/[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(\/.*)?$/i', $value);
+				$success = $success && (preg_match('/^http(s)?:\/\/[a-z0-9_-]+(\.[a-z0-9-]{2,63})*(:[0-9]+)?(\/.*)?$/i', $value) ? true : false);
 			}
 			if(!$success)
-				$this->_validation_error = 4;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_url;
 			break;
 		case self::type_document:
 			foreach($values as $value) {
@@ -1252,7 +1302,7 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 					$success = false;
 			}
 			if(!$success)
-				$this->_validation_error = 10;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_document;
 			break;
 		case self::type_folder:
 			foreach($values as $value) {
@@ -1261,7 +1311,7 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 					$success = false;
 			}
 			if(!$success)
-				$this->_validation_error = 11;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_folder;
 			break;
 		case self::type_user:
 			foreach($values as $value) {
@@ -1270,7 +1320,7 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 					$success = false;
 			}
 			if(!$success)
-				$this->_validation_error = 12;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_user;
 			break;
 		case self::type_group:
 			foreach($values as $value) {
@@ -1279,7 +1329,7 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 					$success = false;
 			}
 			if(!$success)
-				$this->_validation_error = 13;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_group;
 			break;
 		}
 
@@ -1288,10 +1338,16 @@ class SeedDMS_Core_AttributeDefinition { /* {{{ */
 
 		/* Check if value is in value set */
 		if($valueset = $this->getValueSetAsArray()) {
-			foreach($values as $value) {
-				if(!in_array($value, $valueset)) {
-					$success = false;
-					$this->_validation_error = 10;
+			/* An empty value cannot be the value set */
+			if(!$values) {
+				$success = false;
+				$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_valueset;
+			} else {
+				foreach($values as $value) {
+					if(!in_array($value, $valueset)) {
+						$success = false;
+						$this->_validation_error = SeedDMS_Core_AttributeDefinition::val_error_valueset;
+					}
 				}
 			}
 		}
