@@ -9,7 +9,7 @@
  *             Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 
 /**
@@ -25,7 +25,7 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	/**
@@ -79,22 +79,22 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	protected $_date;
 
 	/**
-	 * @var SeedDMS_Core_Folder
+	 * @var SeedDMS_Core_Folder cached parent folder
 	 */
 	protected $_parent;
 
 	/**
-	 * @var SeedDMS_Core_User
+	 * @var SeedDMS_Core_User cached owner of folder
 	 */
 	protected $_owner;
 
 	/**
-	 * @var SeedDMS_Core_Folder[]
+	 * @var SeedDMS_Core_Folder[] cached array of sub folders
 	 */
 	protected $_subFolders;
 
 	/**
-	 * @var SeedDMS_Core_Document[]
+	 * @var SeedDMS_Core_Document[] cache array of child documents
 	 */
 	protected $_documents;
 
@@ -126,7 +126,27 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 		$this->_inheritAccess = $inheritAccess;
 		$this->_defaultAccess = $defaultAccess;
 		$this->_sequence = $sequence;
-		$this->_notifyList = array();
+        $this->_notifyList = array();
+        /* Cache */
+        $this->clearCache();
+	} /* }}} */
+
+	/**
+     * Clear cache of this instance.
+     *
+     * The result of some expensive database actions (e.g. get all subfolders
+     * or documents) will be saved in a class variable to speed up consecutive
+     * calls of the same method. If a second call of the same method shall not
+     * use the cache, then it must be cleared.
+     *
+	 */
+	public function clearCache() { /* {{{ */
+        $this->_parent = null;
+        $this->_owner = null;
+        $this->_subFolders = null;
+        $this->_documents = null;
+        $this->_accessList = null;
+        $this->_notifyList = null;
 	} /* }}} */
 
 	/**
@@ -244,7 +264,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 			return false;
 
 		if(!$resArr)
-			return false;
+			return null;
 
 		return self::getInstanceByData($resArr[0], $dms);
 	} /* }}} */
@@ -321,7 +341,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	} /* }}} */
 
 	/**
-	 * Set creation date of the document
+	 * Set creation date of the folder
 	 *
 	 * @param integer $date timestamp of creation date. If false then set it
 	 * to the current timestamp
@@ -330,7 +350,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	function setDate($date) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		if(!$date)
+		if($date === false)
 			$date = time();
 		else {
 			if(!is_numeric($date))
@@ -347,11 +367,12 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	/**
 	 * Returns the parent
 	 *
-	 * @return bool|SeedDMS_Core_Folder
+	 * @return null|bool|SeedDMS_Core_Folder returns null, if there is no parent folder
+	 * and false in case of an error
 	 */
 	public function getParent() { /* {{{ */
 		if ($this->_id == $this->_dms->rootFolderID || empty($this->_parentID)) {
-			return false;
+			return null;
 		}
 
 		if (!isset($this->_parent)) {
@@ -363,11 +384,17 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	/**
 	 * Check if the folder is subfolder
 	 *
-	 * This function checks if the passed folder is a subfolder of the current
-	 * folder.
+     * This method checks if the current folder is in the path of the 
+     * passed subfolder. In that case the current folder is a parent,
+     * grant parent, grant grant parent, etc. of the subfolder or
+     * to say it differently the passed folder is somewhere below the
+     * current folder.
 	 *
-	 * @param SeedDMS_Core_Folder $subfolder
-	 * @return bool true if passes folder is a subfolder
+     * This is basically the opposite of {@see SeedDMS_Core_Folder::isDescendant()}
+     *
+     * @param SeedDMS_Core_Folder $subfolder folder to be checked if it is
+     * a subfolder on any level of the current folder
+	 * @return bool true if passed folder is a subfolder, otherwise false
 	 */
 	function isSubFolder($subfolder) { /* {{{ */
 		$target_path = $subfolder->getPath();
@@ -442,7 +469,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 			$res = $db->getResult($queryStr);
 		}
 
-		/* Update path in folderList for all documents */
+		/* Update path in folderList for all folders */
 		$queryStr = "SELECT `tblFolders`.`id`, `tblFolders`.`folderList` FROM `tblFolders` WHERE `folderList` LIKE '%:".$this->_id.":%'";
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
@@ -593,7 +620,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 		if (is_bool($resArr) && !$resArr)
 			return false;
 
-		return $resArr[0]['c'];
+		return (int) $resArr[0]['c'];
 	} /* }}} */
 
 	/**
@@ -770,15 +797,22 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 
 	/**
 	 * Check, if this folder is a subfolder of a given folder
-	 *
+     *
+     * This is basically the opposite of {@see SeedDMS_Core_Folder::isSubFolder()}
+     *
 	 * @param object $folder parent folder
 	 * @return boolean true if folder is a subfolder
 	 */
-	function isDescendant($folder) { /* {{{ */
+    function isDescendant($folder) { /* {{{ */
+        /* If the current folder has no parent it cannot be a descendant */
 		if(!$this->getParent())
-			return false;
+            return false;
+        /* Check if the passed folder is the parent of the current folder.
+         * In that case the current folder is a subfolder of the passed folder.
+         */
 		if($this->getParent()->getID() == $folder->getID())
-			return true;
+            return true;
+        /* Recursively go up to the root folder */
 		return $this->getParent()->isDescendant($folder);
 	} /* }}} */
 
@@ -790,17 +824,19 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	 * @return int number of documents or false in case of an error
 	 */
 	function hasDocuments() { /* {{{ */
-		$db = $this->_dms->getDB();
+        $db = $this->_dms->getDB();
+        /* Do not use the cache because it may not contain all documents if
+         * the former call getDocuments() limited the number of documents
 		if (isset($this->_documents)) {
-			/** @noinspection PhpUndefinedFieldInspection */
 			return count($this->_documents);
-		}
+        }
+         */
 		$queryStr = "SELECT count(*) as c FROM `tblDocuments` WHERE `folder` = " . $this->_id;
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && !$resArr)
 			return false;
 
-		return $resArr[0]['c'];
+		return (int) $resArr[0]['c'];
 	} /* }}} */
 
 	/**
@@ -1015,9 +1051,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 
 		$document = $this->_dms->getDocument($db->getInsertID('tblDocuments'));
 
-//		if ($version_comment!="")
-			$res = $document->addContent($version_comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers, $reqversion, $version_attributes, $workflow);
-//		else $res = $document->addContent($comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers,$reqversion, $version_attributes, $workflow);
+		$res = $document->addContent($version_comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers, $reqversion, $version_attributes, $workflow);
 
 		if (is_bool($res) && !$res) {
 			$db->rollbackTransaction();
@@ -1260,9 +1294,9 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	 * has no access list the returned array contains the two elements
 	 * 'users' and 'groups' which are than empty. The methode returns false
 	 * if the function fails.
-	 *
-	 * @param int $mode access mode (defaults to M_ANY)
-	 * @param int|string $op operation (defaults to O_EQ)
+	 * 
+	 * @param integer $mode access mode (defaults to M_ANY)
+	 * @param integer $op operation (defaults to O_EQ)
 	 * @return bool|SeedDMS_Core_GroupAccess|SeedDMS_Core_UserAccess
 	 */
 	function getAccessList($mode = M_ANY, $op = O_EQ) { /* {{{ */
@@ -1278,14 +1312,14 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 				return $this->_parent->getAccessList($mode, $op);
 		}
 
-		if (!isset($this->_accessList[$mode])) {
+        if (!isset($this->_accessList[$mode])) {
 			if ($op!=O_GTEQ && $op!=O_LTEQ && $op!=O_EQ) {
 				return false;
 			}
 			$modeStr = "";
 			if ($mode!=M_ANY) {
 				$modeStr = " AND mode".$op.(int)$mode;
-			}
+            }
 			$queryStr = "SELECT * FROM `tblACLs` WHERE `targetType` = ".T_FOLDER.
 				" AND `target` = " . $this->_id .	$modeStr . " ORDER BY `targetType`";
 			$resArr = $db->getResultArray($queryStr);
@@ -1299,7 +1333,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 				else //if ($row["groupID"] != -1)
 					array_push($this->_accessList[$mode]["groups"], new SeedDMS_Core_GroupAccess($this->_dms->getGroup($row["groupID"]), (int) $row["mode"]));
 			}
-		}
+        }
 
 		return $this->_accessList[$mode];
 	} /* }}} */
@@ -1339,6 +1373,9 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 	function addAccess($mode, $userOrGroupID, $isUser) { /* {{{ */
 		$db = $this->_dms->getDB();
 
+        if($mode < M_NONE || $mode > M_ALL)
+            return false;
+
 		$userOrGroup = ($isUser) ? "`userID`" : "`groupID`";
 
 		$queryStr = "INSERT INTO `tblACLs` (`target`, `targetType`, ".$userOrGroup.", `mode`) VALUES 
@@ -1413,32 +1450,32 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 
 	/**
 	 * Get the access mode of a user on the folder
-	 *
+     *
+     * The access mode is either M_READ, M_READWRITE, M_ALL, or M_NONE.
+     * It is determined
+     * - by the user (admins and owners have always access mode M_ALL)
+     * - by the access list for the user (possibly inherited)
+     * - by the default access mode
+     *
 	 * This function returns the access mode for a given user. An administrator
 	 * and the owner of the folder has unrestricted access. A guest user has
 	 * read only access or no access if access rights are further limited
-	 * by access control lists. All other users have access rights according
+     * by access control lists all the default access.
+     * All other users have access rights according
 	 * to the access control lists or the default access. This function will
-	 * recursive check for access rights of parent folders if access rights
+	 * recursively check for access rights of parent folders if access rights
 	 * are inherited.
 	 *
-	 * This function returns the access mode for a given user. An administrator
-	 * and the owner of the folder has unrestricted access. A guest user has
-	 * read only access or no access if access rights are further limited
-	 * by access control lists. All other users have access rights according
-	 * to the access control lists or the default access. This function will
-	 * recursive check for access rights of parent folders if access rights
-	 * are inherited.
-	 *
-	 * Before checking the access in the method itself a callback 'onCheckAccessFolder'
+	 * Before checking the access itself a callback 'onCheckAccessFolder'
 	 * is called. If it returns a value > 0, then this will be returned by this
 	 * method without any further checks. The optional paramater $context
 	 * will be passed as a third parameter to the callback. It contains
 	 * the operation for which the access mode is retrieved. It is for example
 	 * set to 'removeDocument' if the access mode is used to check for sufficient
-	 * permission on deleting a document.
+     * permission on deleting a document. This callback could be used to
+     * override any existing access mode in a certain context.
 	 *
-	 * @param object $user user for which access shall be checked
+	 * @param SeedDMS_Core_User $user user for which access shall be checked
 	 * @param string $context context in which the access mode is requested
 	 * @return integer access mode
 	 */
@@ -1458,7 +1495,7 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 		/* Administrators have unrestricted access */
 		if ($user->isAdmin()) return M_ALL;
 
-		/* The owner of the document has unrestricted access */
+		/* The owner of the folder has unrestricted access */
 		if ($user->getID() == $this->_ownerID) return M_ALL;
 
 		/* Check ACLs */
@@ -2008,6 +2045,22 @@ class SeedDMS_Core_Folder extends SeedDMS_Core_Object {
 		return $resArr[0];
 	} /* }}} */
 
+	/**
+	 * Get the min and max sequence value for folders
+	 *
+	 * @return bool|array array with keys 'min' and 'max', false in case of an error
+	 */
+	function getFoldersMinMax() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT min(`sequence`) AS `min`, max(`sequence`) AS `max` FROM `tblFolders` WHERE `parent` = " . (int) $this->_id;
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && $resArr == false)
+			return false;
+
+		return $resArr[0];
+	} /* }}} */
+
 }
 
 ?>
