@@ -9,7 +9,7 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 
 /**
@@ -20,7 +20,7 @@
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_User { /* {{{ */
 	/**
@@ -28,42 +28,42 @@ class SeedDMS_Core_User { /* {{{ */
 	 *
 	 * @access protected
 	 */
-	var $_id;
+	protected $_id;
 
 	/**
 	 * @var string login name of user
 	 *
 	 * @access protected
 	 */
-	var $_login;
+	protected $_login;
 
 	/**
 	 * @var string password of user as saved in database (md5)
 	 *
 	 * @access protected
 	 */
-	var $_pwd;
+	protected $_pwd;
 
 	/**
 	 * @var string date when password expires
 	 *
 	 * @access protected
 	 */
-	var $_pwdExpiration;
+	protected $_pwdExpiration;
 
 	/**
 	 * @var string full human readable name of user
 	 *
 	 * @access protected
 	 */
-	var $_fullName;
+	protected $_fullName;
 
 	/**
 	 * @var string email address of user
 	 *
 	 * @access protected
 	 */
-	var $_email;
+	protected $_email;
 
 	/**
 	 * @var string prefered language of user
@@ -71,21 +71,21 @@ class SeedDMS_Core_User { /* {{{ */
 	 *
 	 * @access protected
 	 */
-	var $_language;
+	protected $_language;
 
 	/**
 	 * @var string preselected theme of user
 	 *
 	 * @access protected
 	 */
-	var $_theme;
+	protected $_theme;
 
 	/**
 	 * @var string comment of user
 	 *
 	 * @access protected
 	 */
-	var $_comment;
+	protected $_comment;
 
 	/**
 	 * @var string role of user. Can be one of SeedDMS_Core_User::role_user,
@@ -93,52 +93,56 @@ class SeedDMS_Core_User { /* {{{ */
 	 *
 	 * @access protected
 	 */
-	var $_role;
+	protected $_role;
 
 	/**
 	 * @var boolean true if user shall be hidden
 	 *
 	 * @access protected
 	 */
-	var $_isHidden;
+	protected $_isHidden;
 
 	/**
 	 * @var boolean true if user is disabled
 	 *
 	 * @access protected
 	 */
-	var $_isDisabled;
+	protected $_isDisabled;
 
 	/**
 	 * @var int number of login failures
 	 *
 	 * @access protected
 	 */
-	var $_loginFailures;
+	protected $_loginFailures;
 
 	/**
 	 * @var SeedDMS_Core_Folder home folder
 	 *
 	 * @access protected
 	 */
-	var $_homeFolder;
+	protected $_homeFolder;
 
 	/**
 	 * @var SeedDMS_Core_DMS reference to the dms instance this user belongs to
 	 *
 	 * @access protected
 	 */
-	var $_dms;
+	protected $_dms;
 
 	/**
 	 * @var int
+	 *
+	 * @access protected
 	 */
-	private $_quota;
+	protected $_quota;
 
 	/**
 	 * @var bool
+	 *
+	 * @access protected
 	 */
-	private $_hasImage;
+	protected $_hasImage;
 
 	const role_user = '0';
 	const role_admin = '1';
@@ -172,8 +176,8 @@ class SeedDMS_Core_User { /* {{{ */
 		$this->_theme = $theme;
 		$this->_comment = $comment;
 		$this->_role = $role;
-		$this->_isHidden = $isHidden;
-		$this->_isDisabled = $isDisabled;
+		$this->_isHidden = (bool) $isHidden;
+		$this->_isDisabled = (bool) $isDisabled;
 		$this->_pwdExpiration = $pwdExpiration;
 		$this->_loginFailures = $loginFailures;
 		$this->_quota = $quota;
@@ -241,7 +245,7 @@ class SeedDMS_Core_User { /* {{{ */
 		$users = array();
 
 		for ($i = 0; $i < count($resArr); $i++) {
-		    /** @var SeedDMS_Core_User $user */
+			/** @var SeedDMS_Core_User $user */
 			$user = new self($resArr[$i]["id"], $resArr[$i]["login"], $resArr[$i]["pwd"], $resArr[$i]["fullName"], $resArr[$i]["email"], (isset($resArr[$i]["language"])?$resArr[$i]["language"]:NULL), (isset($resArr[$i]["theme"])?$resArr[$i]["theme"]:NULL), $resArr[$i]["comment"], $resArr[$i]["role"], $resArr[$i]["hidden"], $resArr[$i]["disabled"], $resArr[$i]["pwdExpiration"], $resArr[$i]["loginfailures"], $resArr[$i]["quota"], $resArr[$i]["homefolder"]);
 			$user->setDMS($dms);
 			$users[$i] = $user;
@@ -288,6 +292,10 @@ class SeedDMS_Core_User { /* {{{ */
 	 * @return bool
 	 */
 	function setLogin($newLogin) { /* {{{ */
+		$newLogin = trim($newLogin);
+		if(!$newLogin)
+			return false;
+
 		$db = $this->_dms->getDB();
 
 		$queryStr = "UPDATE `tblUsers` SET `login` =".$db->qstr($newLogin)." WHERE `id` = " . $this->_id;
@@ -354,6 +362,7 @@ class SeedDMS_Core_User { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		if(trim($newPwdExpiration) == '' || trim($newPwdExpiration) == 'never') {
+			$newPwdExpiration = null;
 			$queryStr = "UPDATE `tblUsers` SET `pwdExpiration` = NULL WHERE `id` = " . $this->_id;
 		} else {
 			if(trim($newPwdExpiration) == 'now')
@@ -380,7 +389,7 @@ class SeedDMS_Core_User { /* {{{ */
 	function setEmail($newEmail) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE `tblUsers` SET `email` =".$db->qstr($newEmail)." WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `email` =".$db->qstr(trim($newEmail))." WHERE `id` = " . $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
 			return false;
@@ -401,7 +410,7 @@ class SeedDMS_Core_User { /* {{{ */
 	function setLanguage($newLanguage) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE `tblUsers` SET `language` =".$db->qstr($newLanguage)." WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `language` =".$db->qstr(trim($newLanguage))." WHERE `id` = " . $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
 			return false;
@@ -422,7 +431,7 @@ class SeedDMS_Core_User { /* {{{ */
 	function setTheme($newTheme) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE `tblUsers` SET `theme` =".$db->qstr($newTheme)." WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `theme` =".$db->qstr(trim($newTheme))." WHERE `id` = " . $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
 			return false;
@@ -443,7 +452,7 @@ class SeedDMS_Core_User { /* {{{ */
 	function setComment($newComment) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE `tblUsers` SET `comment` =".$db->qstr($newComment)." WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `comment` =".$db->qstr(trim($newComment))." WHERE `id` = " . $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
 			return false;
@@ -463,7 +472,8 @@ class SeedDMS_Core_User { /* {{{ */
 	 */
 	function setRole($newrole) { /* {{{ */
 		$db = $this->_dms->getDB();
-		$newrole = intval($newrole);
+		if(!in_array($newrole, array(SeedDMS_Core_User::role_admin, SeedDMS_Core_User::role_guest, SeedDMS_Core_User::role_user), true))
+			return false;
 
 		$queryStr = "UPDATE `tblUsers` SET `role` = " . $newrole . " WHERE `id` = " . $this->_id;
 		if (!$db->getResult($queryStr))
@@ -512,7 +522,7 @@ class SeedDMS_Core_User { /* {{{ */
 	} /* }}} */
 
 	/**
-	 * @return bool|int
+	 * @return bool
 	 */
 	function isHidden() { return $this->_isHidden; }
 
@@ -524,11 +534,11 @@ class SeedDMS_Core_User { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		$isHidden = ($isHidden) ? "1" : "0";
-		$queryStr = "UPDATE `tblUsers` SET `hidden` = " . $isHidden . " WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `hidden` = " . intval($isHidden) . " WHERE `id` = " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 
-		$this->_isHidden = $isHidden;
+		$this->_isHidden = (bool) $isHidden;
 		return true;
 	}	 /* }}} */
 
@@ -545,11 +555,11 @@ class SeedDMS_Core_User { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		$isDisabled = ($isDisabled) ? "1" : "0";
-		$queryStr = "UPDATE `tblUsers` SET `disabled` = " . $isDisabled . " WHERE `id` = " . $this->_id;
+		$queryStr = "UPDATE `tblUsers` SET `disabled` = " . intval($isDisabled) . " WHERE `id` = " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 
-		$this->_isDisabled = $isDisabled;
+		$this->_isDisabled = (bool) $isDisabled;
 		return true;
 	}	 /* }}} */
 
@@ -610,6 +620,11 @@ class SeedDMS_Core_User { /* {{{ */
 	 * @return bool
 	 */
 	function setQuota($quota) { /* {{{ */
+		if (!is_numeric($quota))
+			return false;
+		if($quota < 0)
+			return false;
+
 		$db = $this->_dms->getDB();
 
 		$quota = intval($quota);
@@ -1095,7 +1110,8 @@ class SeedDMS_Core_User { /* {{{ */
 	/**
 	 * Get the image from the users profile
 	 *
-	 * @return array|bool image data
+	 * @return string|null|bool image data as a string or null if no image is set or
+	 * false in case of an error
 	 */
 	function getImage() { /* {{{ */
 		$db = $this->_dms->getDB();
@@ -1106,8 +1122,9 @@ class SeedDMS_Core_User { /* {{{ */
 			return false;
 
 		if($resArr)
-			$resArr = $resArr[0];
-		return $resArr;
+			return $resArr[0];
+		else
+			return null;
 	} /* }}} */
 
 	/**
@@ -1189,6 +1206,106 @@ class SeedDMS_Core_User { /* {{{ */
 		return $documents;
 	} /* }}} */
 
+	/**
+	 * Returns all document links of a given user
+	 * @return SeedDMS_Core_DocumentLink[]|bool list of document links
+	 */
+	function getDocumentLinks() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT * FROM `tblDocumentLinks` ".
+			"WHERE `userID` = " . $this->_id;
+
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && !$resArr)
+			return false;
+
+		$links = array();
+		$classname = 'SeedDMS_Core_DocumentLink';
+		foreach ($resArr as $row) {
+			$document = $this->_dms->getDocument($row["document"]);
+			$target = $this->_dms->getDocument($row["target"]);
+			/** @var SeedDMS_Core_Document $document */
+			$link = new $classname((int) $row["id"], $document, $target, $row["userID"], $row["public"]);
+			$links[] = $link;
+		}
+		return $links;
+	} /* }}} */
+
+	/**
+	 * Returns all document files of a given user
+	 * @return SeedDMS_Core_DocumentFile[]|bool list of document files
+	 */
+	function getDocumentFiles() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT * FROM `tblDocumentFiles` ".
+			"WHERE `userID` = " . $this->_id;
+
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && !$resArr)
+			return false;
+
+		$files = array();
+		$classname = 'SeedDMS_Core_DocumentFile';
+		foreach ($resArr as $row) {
+			$document = $this->_dms->getDocument($row["document"]);
+			/** @var SeedDMS_Core_DocumentFile $file */
+			$file = new $classname((int) $row["id"], $document, $row["userID"], $row["comment"], $row["date"], $row["dir"], $row["fileType"], $row["mimeType"], $row["orgFileName"], $row["name"],$row["version"],$row["public"]);
+			$files[] = $file;
+		}
+		return $files;
+	} /* }}} */
+
+	/**
+	 * Returns all document contents of a given user
+	 * @return SeedDMS_Core_DocumentContent[]|bool list of document contents
+	 */
+	function getDocumentContents() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT * FROM `tblDocumentContent` WHERE `createdBy` = " . $this->_id;
+
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && !$resArr)
+			return false;
+
+		$contents = array();
+		$classname = $this->_dms->getClassname('documentcontent');
+		foreach ($resArr as $row) {
+			$document = $this->_dms->getDocument($row["document"]);
+			/** @var SeedDMS_Core_DocumentContent $content */
+			$content = new $classname((int) $row["id"], $this, $row["version"], $row["comment"], $row["date"], $row["createdBy"], $row["dir"], $row["orgFileName"], $row["fileType"], $row["mimeType"], $row['fileSize'], $row['checksum']);
+			$contents[] = $content;
+		}
+		return $contents;
+	} /* }}} */
+
+	/**
+	 * Returns all folders of a given user
+	 * @return SeedDMS_Core_Folder[]|bool list of folders
+	 */
+	function getFolders() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT * FROM `tblFolders` ".
+			"WHERE `owner` = " . $this->_id . " ORDER BY `sequence`";
+
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && !$resArr)
+			return false;
+
+		$folders = array();
+		$classname = $this->_dms->getClassname('folder');
+		foreach ($resArr as $row) {
+			/** @var SeedDMS_Core_Folder $folder */
+			$folder = new $classname((int) $row["id"], $row["name"], $row['parent'], $row["comment"], $row["date"], $row["owner"], $row["inheritAccess"], $row["defaultAccess"], $row["sequence"]);
+			$folder->setDMS($this->_dms);
+			$folders[] = $folder;
+		}
+		return $folders;
+	} /* }}} */
+
 	/**
 	 * Get a list of reviews
 	 *
@@ -1212,17 +1329,28 @@ class SeedDMS_Core_User { /* {{{ */
 	function getReviewStatus($documentID=null, $version=null) { /* {{{ */
 		$db = $this->_dms->getDB();
 
+		if (!$db->createTemporaryTable("ttreviewid", true)) {
+			return false;
+		}
+
 		$status = array("indstatus"=>array(), "grpstatus"=>array());
 
 		// See if the user is assigned as an individual reviewer.
+		// Attention: this method didn't use ttreviewid to filter out the latest
+		// log entry. This was added 2021-09-29 because $group->getReviewStatus()
+		// does it as well. The check below if the date is larger than the date
+		// of a previos entry is still required to just take the latest version
+		// of a document into account.
 		$queryStr = "SELECT `tblDocumentReviewers`.*, `tblDocumentReviewLog`.`status`, ".
 			"`tblDocumentReviewLog`.`comment`, `tblDocumentReviewLog`.`date`, ".
 			"`tblDocumentReviewLog`.`userID` ".
 			"FROM `tblDocumentReviewers` ".
 			"LEFT JOIN `tblDocumentReviewLog` USING (`reviewID`) ".
-			"WHERE `tblDocumentReviewers`.`type`='0' ".
+			"LEFT JOIN `ttreviewid` on `ttreviewid`.`maxLogID` = `tblDocumentReviewLog`.`reviewLogID` ".
+			"WHERE `ttreviewid`.`maxLogID`=`tblDocumentReviewLog`.`reviewLogID` ".
 			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". (int) $version ."' ").
+			"AND `tblDocumentReviewers`.`type`='0' ".
 			"AND `tblDocumentReviewers`.`required`='". $this->_id ."' ".
 			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
@@ -1247,10 +1375,12 @@ class SeedDMS_Core_User { /* {{{ */
 			"`tblDocumentReviewLog`.`userID` ".
 			"FROM `tblDocumentReviewers` ".
 			"LEFT JOIN `tblDocumentReviewLog` USING (`reviewID`) ".
+			"LEFT JOIN `ttreviewid` on `ttreviewid`.`maxLogID` = `tblDocumentReviewLog`.`reviewLogID` ".
 			"LEFT JOIN `tblGroupMembers` ON `tblGroupMembers`.`groupID` = `tblDocumentReviewers`.`required` ".
-			"WHERE `tblDocumentReviewers`.`type`='1' ".
+			"WHERE `ttreviewid`.`maxLogID`=`tblDocumentReviewLog`.`reviewLogID` ".
 			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". (int) $version ."' ").
+			"AND `tblDocumentReviewers`.`type`='1' ".
 			"AND `tblGroupMembers`.`userID`='". $this->_id ."' ".
 			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
@@ -1305,16 +1435,29 @@ class SeedDMS_Core_User { /* {{{ */
 	function getApprovalStatus($documentID=null, $version=null) { /* {{{ */
 		$db = $this->_dms->getDB();
 
+		if (!$db->createTemporaryTable("ttapproveid")) {
+			return false;
+		}
+
 		$status = array("indstatus"=>array(), "grpstatus"=>array());
+
+		// See if the user is assigned as an individual approver.
+		// Attention: this method didn't use ttapproveid to filter out the latest
+		// log entry. This was added 2021-09-29 because $group->getApprovalStatus()
+		// does it as well. The check below if the date is larger than the date
+		// of a previos entry is still required to just take the latest version
+		// of a document into account.
 		$queryStr =
 			"SELECT `tblDocumentApprovers`.*, `tblDocumentApproveLog`.`status`, ".
 			"`tblDocumentApproveLog`.`comment`, `tblDocumentApproveLog`.`date`, ".
 			"`tblDocumentApproveLog`.`userID` ".
 			"FROM `tblDocumentApprovers` ".
 			"LEFT JOIN `tblDocumentApproveLog` USING (`approveID`) ".
-			"WHERE `tblDocumentApprovers`.`type`='0' ".
+			"LEFT JOIN `ttapproveid` on `ttapproveid`.`maxLogID` = `tblDocumentApproveLog`.`approveLogID` ".
+			"WHERE `ttapproveid`.`maxLogID`=`tblDocumentApproveLog`.`approveLogID` ".
 			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". (int) $version ."' ").
+			"AND `tblDocumentApprovers`.`type`='0' ".
 			"AND `tblDocumentApprovers`.`required`='". $this->_id ."' ".
 			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC";
 
@@ -1341,10 +1484,12 @@ class SeedDMS_Core_User { /* {{{ */
 			"`tblDocumentApproveLog`.`userID` ".
 			"FROM `tblDocumentApprovers` ".
 			"LEFT JOIN `tblDocumentApproveLog` USING (`approveID`) ".
+			"LEFT JOIN `ttapproveid` on `ttapproveid`.`maxLogID` = `tblDocumentApproveLog`.`approveLogID` ".
 			"LEFT JOIN `tblGroupMembers` ON `tblGroupMembers`.`groupID` = `tblDocumentApprovers`.`required` ".
-			"WHERE `tblDocumentApprovers`.`type`='1' ".
+			"WHERE `ttapproveid`.`maxLogID`=`tblDocumentApproveLog`.`approveLogID` ".
 			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". (int) $version ."' ").
+			"AND `tblDocumentApprovers`.`type`='1' ".
 			"AND `tblGroupMembers`.`userID`='". $this->_id ."' ".
 			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
