@@ -8,7 +8,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 
 /**
@@ -18,7 +18,7 @@
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow { /* {{{ */
 	/**
@@ -150,8 +150,13 @@ class SeedDMS_Core_Workflow { /* {{{ */
 		return $this->_transitions;
 	} /* }}} */
 
-	/**
-	 * @return array
+    /**
+     * Get all states this workflow at some point may reach
+     *
+     * It basically iterates through all transistions and makes a unique
+     * list of the start and end state.
+     *
+	 * @return array list of states
 	 */
 	function getStates() { /* {{{ */
 		/** @noinspection PhpUnusedLocalVariableInspection */
@@ -161,7 +166,7 @@ class SeedDMS_Core_Workflow { /* {{{ */
 			$this->getTransitions();
 
 		$states = array();
-		foreach($this->_transitions as $transition) {
+        foreach($this->_transitions as $transition) {
 			if(!isset($states[$transition->getState()->getID()]))
 				$states[$transition->getState()->getID()] = $transition->getState();
 			if(!isset($states[$transition->getNextState()->getID()]))
@@ -199,6 +204,9 @@ class SeedDMS_Core_Workflow { /* {{{ */
 	function getNextTransitions($state) { /* {{{ */
 		$db = $this->_dms->getDB();
 
+		if(!$state)
+			return false;
+
 		$queryStr = "SELECT * FROM `tblWorkflowTransitions` WHERE `workflow`=".$this->_id." AND `state`=".$state->getID();
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
@@ -417,7 +425,7 @@ class SeedDMS_Core_Workflow { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_State { /* {{{ */
 	/**
@@ -654,7 +662,7 @@ class SeedDMS_Core_Workflow_State { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_Action { /* {{{ */
 	/**
@@ -795,7 +803,7 @@ class SeedDMS_Core_Workflow_Action { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_Transition { /* {{{ */
 	/**
@@ -1086,7 +1094,7 @@ class SeedDMS_Core_Workflow_Transition { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_Transition_User { /* {{{ */
 	/**
@@ -1162,7 +1170,7 @@ class SeedDMS_Core_Workflow_Transition_User { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_Transition_Group { /* {{{ */
 	/**
@@ -1257,7 +1265,7 @@ class SeedDMS_Core_Workflow_Transition_Group { /* {{{ */
  * @package    SeedDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_Workflow_Log { /* {{{ */
 	/**
