@@ -8,7 +8,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 /** @noinspection PhpUndefinedClassInspection */
 
@@ -20,7 +20,7 @@
  * @package    SeedDMS_Core
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2012 Uwe Steinmann
- * @version    Release: 5.1.22
+ * @version    Release: @package_version@
  */
 class SeedDMS_Core_DatabaseAccess {
 	/**
@@ -232,7 +232,7 @@ class SeedDMS_Core_DatabaseAccess {
 		$this->_ttapproveid = false;
 		$this->_ttstatid = false;
 		$this->_ttcontentid = false;
-		$this->_useviews = false;
+		$this->_useviews = false; // turn off views, because they are much slower then temp. tables
 		$this->_debug = false;
 	} /* }}} */
 
@@ -245,6 +245,15 @@ class SeedDMS_Core_DatabaseAccess {
 		return $this->_driver;
 	} /* }}} */
 
+	/**
+	 * Turn on views instead of temp. tables
+	 *
+	 * @param bool $onoff turn use of views instead of temp. table on/off
+	 */
+    function useViews($onoff) { /* {{{ */
+        $this->_useviews = $onoff;
+    } /* }}} */
+
 	/**
 	 * Destructor of SeedDMS_Core_DatabaseAccess
 	 */
@@ -283,22 +292,26 @@ class SeedDMS_Core_DatabaseAccess {
 				$dsn = $this->_driver.":".$this->_database;
 				break;
 		}
-		/** @noinspection PhpUndefinedVariableInspection */
-		$this->_conn = new PDO($dsn, $this->_user, $this->_passw);
-		if (!$this->_conn)
-			return false;
+		try {
+			/** @noinspection PhpUndefinedVariableInspection */
+			$this->_conn = new PDO($dsn, $this->_user, $this->_passw);
+			if (!$this->_conn)
+				return false;
 
-		switch($this->_driver) {
-			case 'mysql':
-				$this->_conn->exec('SET NAMES utf8');
-				/* Turn this on if you want strict checking of default values, etc. */
-//				$this->_conn->exec("SET SESSION sql_mode = 'STRICT_TRANS_TABLES'");
-				/* The following is the default on Ubuntu 16.04 */
-//				$this->_conn->exec("SET SESSION sql_mode = 'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION'");
-				break;
-			case 'sqlite':
-				$this->_conn->exec('PRAGMA foreign_keys = ON');
-				break;
+			switch($this->_driver) {
+				case 'mysql':
+					$this->_conn->exec('SET NAMES utf8');
+					/* Turn this on if you want strict checking of default values, etc. */
+					/* $this->_conn->exec("SET SESSION sql_mode = 'STRICT_TRANS_TABLES'"); */
+					/* The following is the default on Ubuntu 16.04 */
+					/* $this->_conn->exec("SET SESSION sql_mode = 'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION'"); */
+					break;
+				case 'sqlite':
+					$this->_conn->exec('PRAGMA foreign_keys = ON');
+					break;
+			}
+		} catch (Exception $e) {
+			return false;
 		}
 		if($this->_useviews) {
 			$tmp = $this->ViewList();
@@ -346,6 +359,27 @@ class SeedDMS_Core_DatabaseAccess {
 		return str_replace('`', '"', $text);
 	} /* }}} */
 
+	/**
+	 * Return sql to concat strings or fields
+	 *
+	 * @param array $arr list of field names or strings
+	 * @return string concated string
+	 */
+	function concat($arr) { /* {{{ */
+		switch($this->_driver) {
+		case 'mysql':
+			return 'concat('.implode(',', $arr).')';
+			break;
+		case 'pgsql':
+			return implode(' || ', $arr);
+			break;
+		case 'sqlite':
+			return implode(' || ', $arr);
+			break;
+		}
+		return '';
+	} /* }}} */
+
 	/**
 	 * Execute SQL query and return result
 	 *
@@ -367,8 +401,10 @@ class SeedDMS_Core_DatabaseAccess {
 		}
 		$res = $this->_conn->query($queryStr);
 		if ($res === false) {
-			if($this->_debug)
+			if($this->_debug) {
 				echo "error: ".$queryStr."<br />";
+				print_r($this->_conn->errorInfo());
+			}
 			return false;
 		}
 		$resArr = $res->fetchAll(PDO::FETCH_ASSOC);
@@ -395,8 +431,10 @@ class SeedDMS_Core_DatabaseAccess {
 		}
 		$res = $this->_conn->exec($queryStr);
 		if($res === false) {
-			if($this->_debug)
+			if($this->_debug) {
 				echo "error: ".$queryStr."<br />";
+				print_r($this->_conn->errorInfo());
+			}
 			return false;
 		} else
 			return true;
@@ -489,7 +527,7 @@ class SeedDMS_Core_DatabaseAccess {
 			}
 			else {
 				if (is_bool($override) && $override) {
-					if (!$this->getResult("DELETE FROM `ttreviewid`"))
+					if (!$this->getResult("DROP TABLE IF EXISTS `ttreviewid`"))
 						return false;
 					if (!$this->getResult($queryStr))
 						return false;
@@ -530,7 +568,7 @@ class SeedDMS_Core_DatabaseAccess {
 			}
 			else {
 				if (is_bool($override) && $override) {
-					if (!$this->getResult("DELETE FROM `ttapproveid`"))
+					if (!$this->getResult("DROP TABLE IF NOT EXISTS `ttapproveid`"))
 						return false;
 					if (!$this->getResult($queryStr))
 						return false;
@@ -571,7 +609,7 @@ class SeedDMS_Core_DatabaseAccess {
 			}
 			else {
 				if (is_bool($override) && $override) {
-					if (!$this->getResult("DELETE FROM `ttstatid`"))
+					if (!$this->getResult("DROP TABLE IF NOT EXISTS `ttstatid`"))
 						return false;
 					if (!$this->getResult($queryStr))
 						return false;
@@ -612,7 +650,7 @@ class SeedDMS_Core_DatabaseAccess {
 			}
 			else {
 				if (is_bool($override) && $override) {
-					if (!$this->getResult("DELETE FROM `ttcontentid`"))
+					if (!$this->getResult("DROP TABLE IF NOT EXISTS `ttcontentid`"))
 						return false;
 					if (!$this->getResult($queryStr))
 						return false;
@@ -623,11 +661,44 @@ class SeedDMS_Core_DatabaseAccess {
 		return false;
 	} /* }}} */
 
+	/**
+	 * Drop various temporary tables to enforce recreation when needed
+	 *
+	 * @param string $tableName
+     *
+	 * @return bool
+	 */
+    private function __dropTemporaryTable($tableName) { /* {{{ */
+        $queryStr = '';
+        if (!strcasecmp($tableName, "ttreviewid")) {
+            $queryStr = "DROP TABLE IF EXISTS `ttreviewid`";
+		}
+		elseif (!strcasecmp($tableName, "ttapproveid")) {
+            $queryStr = "DROP TABLE IF EXISTS `ttapproveid`";
+		}
+		elseif (!strcasecmp($tableName, "ttstatid")) {
+            $queryStr = "DROP TABLE IF EXISTS `ttstatid`";
+		}
+		elseif (!strcasecmp($tableName, "ttcontentid")) {
+            $queryStr = "DROP TABLE IF EXISTS `ttcontentid`";
+        }
+        if($queryStr) {
+			if (!$this->getResult($queryStr))
+                return false;
+            else {
+                $this->{'_'.$tableName} = false;
+                return true;
+            }
+        }
+		return false;
+	} /* }}} */
+
 	/**
 	 * Create various views to speed up and simplify sql queries
 	 *
 	 * @param string $tableName
 	 * @param bool $override
+     *
 	 * @return bool
 	 */
 	private function __createView($tableName, $override=false) { /* {{{ */
@@ -793,7 +864,8 @@ class SeedDMS_Core_DatabaseAccess {
 	 * Create various temporary tables or view to speed up and simplify sql queries
 	 *
 	 * @param string $tableName
-	 * @param bool $override
+     * @param bool $override
+     *
 	 * @return bool
 	 */
 	public function createTemporaryTable($tableName, $override=false) { /* {{{ */
@@ -803,6 +875,20 @@ class SeedDMS_Core_DatabaseAccess {
 			return $this->__createTemporaryTable($tableName, $override);
 	} /* }}} */
 
+	/**
+	 * Drop various temporary tables to force recreation when next time needed
+	 *
+     * @param string $tableName
+     *
+	 * @return bool
+	 */
+	public function dropTemporaryTable($tableName) { /* {{{ */
+		if($this->_useviews)
+			return true; // No need to recreate a view
+		else
+			return $this->__dropTemporaryTable($tableName);
+	} /* }}} */
+
 	/**
 	 * Return sql statement for extracting the date part from a field
 	 * containing a unix timestamp
@@ -888,4 +974,35 @@ class SeedDMS_Core_DatabaseAccess {
 		}
 		return $field;
 	} /* }}} */
+
+	/**
+	 * Create an sql dump of the complete database
+	 *
+	 * @param resource $fp name of dump file
+	 * @return bool
+	 */
+	function createDump($fp) { /* {{{ */
+		$tables = $this->TableList('TABLES');
+        foreach($tables as $table) {
+            if($table == 'sqlite_sequence')
+                continue;
+			$query = "SELECT * FROM `".$table."`";
+			$records = $this->getResultArray($query);
+			fwrite($fp,"\n-- TABLE: ".$table."--\n\n");
+			foreach($records as $record) {
+				$values="";
+				$i = 1;
+				foreach ($record as $column) {
+					if (is_numeric($column)) $values .= $column;
+					else $values .= $this->qstr($column);
+
+					if ($i<(count($record))) $values .= ",";
+					$i++;
+				}
+
+				fwrite($fp, "INSERT INTO `".$table."` VALUES (".$values.");\n");
+			}
+		}
+		return true;
+	} /* }}} */
 }
