@@ -8,7 +8,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2010, Uwe Steinmann
- * @version    Release: 1.0.15
+ * @version    Release: @package_version@
  */
 
 
@@ -20,7 +20,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2011, Uwe Steinmann
- * @version    Release: 1.0.15
+ * @version    Release: @package_version@
  */
 class SeedDMS_SQLiteFTS_Term {
 
@@ -62,7 +62,11 @@ class SeedDMS_SQLiteFTS_Term {
 			11 => 'status',
 			12 => 'path'
 		);
-		$this->field = $fields[$col];
+		/* fts5 pass the column name in $col, fts4 uses an integer */
+		if(is_int($col))
+			$this->field = $fields[$col];
+		else
+			$this->field = $col; //$fields[$col];
 		$this->_occurrence = $occurrence;
 	} /* }}} */
 
