@@ -51,6 +51,12 @@ class SeedDMS_Extension_Mgr {
 	 */
 	protected $cachedir;
 
+	/**
+	 * @var array $configcache cached result of checkExtensionByName()
+	 * @access protected
+	 */
+	protected $configcache;
+
 	/**
 	 * @var string[] $errmsg list of error message from last operation
 	 * @access protected
@@ -104,6 +110,7 @@ class SeedDMS_Extension_Mgr {
 	 * is given
 	 */
 	public function __construct($extdir = '', $cachedir = '', $reposurl = '', $proxyurl='', $proxyuser='', $proxypass='') { /* {{{ */
+		$this->configcache = [];
 		$this->cachedir = $cachedir;
 		$this->extdir = $extdir;
 		$this->reposurl = $reposurl;
@@ -304,7 +311,7 @@ class SeedDMS_Extension_Mgr {
 	 * @param SeedDMS_Core_DMS $dms
 	 * @return boolean true on success, false on error
 	 */
-	public function migrate($extname, $settings, $dms) { /* {{{ */
+	public function migrate($extname, $settings, $dms, $logger) { /* {{{ */
 		if(!isset($this->extconf[$extname]))
 			return false;
 		$extconf = $this->extconf[$extname];
@@ -313,7 +320,7 @@ class SeedDMS_Extension_Mgr {
 			$classfile = $settings->_rootDir."/ext/".$extname."/".$extconf['class']['file'];
 			if(file_exists($classfile)) {
 				require_once($classfile);
-				$obj = new $extconf['class']['name']($settings, $dms);
+				$obj = new $extconf['class']['name']($settings, $dms, $logger);
 				if(method_exists($obj, 'migrate'))
 					$ret = $obj->migrate();
 			}
@@ -321,48 +328,66 @@ class SeedDMS_Extension_Mgr {
 		return $ret;
 	} /* }}} */
 
+	public function checkExtensionByDir($dir, $options = array()) { /* {{{ */
+		$this->errmsgs = array();
+
+		if(!file_exists($dir)) {
+			if(!file_exists($this->extdir.'/'.$dir))
+				return false;
+			else
+				$dir = $this->extdir.'/'.$dir;
+		}
+		if(!file_exists($dir."/conf.php")) {
+			$this->errmsgs[] = "Missing extension configuration";
+			return false;
+		}
+		include($dir."/conf.php");
+		if(!isset($EXT_CONF)) {
+			$this->errmsgs[] = "Missing \$EXT_CONF in configuration";
+			return false;
+		}
+		$extname = key($EXT_CONF);
+		if(!$extname || !preg_match('/[a-zA-Z_]*/', $extname)) {
+			$this->errmsgs[] = "Extension has invalid or no name";
+			return false;
+		}
+
+		$extconf = $EXT_CONF[$extname];
+
+		if(!empty($extconf['language']['file']) && !file_exists($dir."/".$extconf['language']['file'])) {
+			$this->errmsgs[] = "Missing language file";
+		}
+		if(!empty($extconf['class']['file']) && !file_exists($dir."/".$extconf['class']['file'])) {
+			$this->errmsgs[] = "Missing class file";
+		}
+		if(!empty($extconf['icon']) && !file_exists($dir."/".$extconf['icon'])) {
+			$this->errmsgs[] = "Missing icon file";
+		}
+
+		if($this->errmsgs)
+			return false;
+
+		return self::checkExtensionByName($extname, $extconf, $options);
+	}
+
 	/**
 	 * Check content of extension directory or configuration of extension
 	 *
 	 * @param string|array $dir full path to extension directory or extension name
 	 * or an array containing the configuration.
-	 * @param boolean $noconstraints set to true if constraints to local seeddms
-	 * installation shall not be checked.
+	 * @param array $options array with options elements 'noconstraints' and 'nofiles'.
+	 * Set 'noconstraints' to true if
+	 * constraints to local seeddms installation shall not be checked. Set 'nofiles'
+	 * to true to turn off checking of files
+	 * @return boolean true if check was successful, otherwise false
 	 */
-	public function checkExtension($dir, $options=array()) { /* {{{ */
-		$this->errmsgs = array();
-
-		if(is_string($dir)) {
-			if(!file_exists($dir)) {
-				if(!file_exists($this->extdir.'/'.$dir))
-					return false;
-				else
-					$dir = $this->extdir.'/'.$dir;
-			}
-			if(!file_exists($dir."/conf.php")) {
-				$this->errmsgs[] = "Missing extension configuration";
-				return false;
-			}
-			include($dir."/conf.php");
-			if(!isset($EXT_CONF)) {
-				$this->errmsgs[] = "Missing \$EXT_CONF in configuration";
-				return false;
-			}
-			$extname = key($EXT_CONF);
-			if(!$extname || !preg_match('/[a-zA-Z_]*/', $extname)) {
-				$this->errmsgs[] = "Extension has invalid or no name";
-				return false;
-			}
-
-			$extconf = $EXT_CONF[$extname];
-		} elseif(is_array($dir)) {
-			$extconf = $dir;
-			/* If just the configuration is passed, then there is no way to check
-			 * for existence of files.
-			 */
-			$options['nofiles'] = true;
+	public function checkExtensionByName($extname, $extconf, $options=array()) { /* {{{ */
+		if(isset($this->configcache[$extname])) {
+			return $this->configcache[$extname];
 		}
 
+		$this->errmsgs = array();
+
 		if(!isset($extconf['constraints']['depends']['seeddms'])) {
 			$this->errmsgs[] = "Missing dependency on SeedDMS";
 		}
@@ -378,17 +403,6 @@ class SeedDMS_Extension_Mgr {
 		if(!isset($extconf['author'])) {
 			$this->errmsgs[] = "Missing author";
 		}
-		if(!isset($options['nofiles']) || $options['nofiles'] == false) {
-			if(!empty($extconf['language']['file']) && !file_exists($dir."/".$extconf['language']['file'])) {
-				$this->errmsgs[] = "Missing language file";
-			}
-			if(!empty($extconf['class']['file']) && !file_exists($dir."/".$extconf['class']['file'])) {
-				$this->errmsgs[] = "Missing class file";
-			}
-			if(!empty($extconf['icon']) && !file_exists($dir."/".$extconf['icon'])) {
-				$this->errmsgs[] = "Missing icon file";
-			}
-		}
 
 		if(!isset($options['noconstraints']) || $options['noconstraints'] == false) {
 			if(isset($extconf['constraints']['depends'])) {
@@ -442,9 +456,11 @@ class SeedDMS_Extension_Mgr {
 		}
 
 		if($this->errmsgs)
-			return false;
+			$this->configcache[$extname] = false;
+		else
+			$this->configcache[$extname] = true;
 
-		return true;
+		return $this->configcache[$extname];
 	} /* }}} */
 
 	static protected function rrmdir($dir) { /* {{{ */
@@ -472,7 +488,7 @@ class SeedDMS_Extension_Mgr {
 	 */
 	public function updateExtension($file) { /* {{{ */
 		/* unzip the extension in a temporary directory */
-		$newdir = $this->cachedir ."/ext.new";
+		$newdir = addDirSep($this->cachedir)."ext.new";
 		/* First remove a left over from a previous extension */
 		if(file_exists($newdir)) {
 			self::rrmdir($newdir);
@@ -494,7 +510,7 @@ class SeedDMS_Extension_Mgr {
 //		exec($cmd);
 
 		/* Check if extension is complete and fullfills the constraints */
-		if(!self::checkExtension($newdir)) {
+		if(!self::checkExtensionByDir($newdir)) {
 			self::rrmdir($newdir);
 			return false;
 		}
@@ -513,7 +529,21 @@ class SeedDMS_Extension_Mgr {
 			$this->rrmdir($this->extdir ."/". $extname);
 		}
 		/* Move the temp. created ext directory to the final location */
-		if(!rename($newdir, $this->extdir ."/". $extname)) {
+		/* rename() may fail if dirs are moved from one device to another.
+		 * See https://bugs.php.net/bug.php?id=54097
+		 *
+		 * exec("mv ".escapeshellarg($newdir)." ".escapeshellarg($this->extdir ."/". $extname));
+		 *
+		 * It's also sufficient to just copy the extracted archive to the final
+		 * location and leave the extracted archive in place. The next time an
+		 * extension is imported the last extracted archive will be removed.
+		 */
+//		if(!rename($newdir, $this->extdir ."/". $extname)) {
+		if(false === exec('mv '.escapeshellarg($newdir).' '.escapeshellarg($this->extdir."/".$extname))) {
+			/* If copy didn't succeed, then there is probably nothing to delete,
+			 * but do it anyway, just to be sure not just parts of the extension
+			 * has been copied.
+			 */
 			$this->rrmdir($this->extdir ."/". $extname);
 			return false;
 		}
