@@ -23,7 +23,10 @@
 class Settings { /* {{{ */
 	// Config File Path
 	var $_configFilePath = null;
+	var $_configFileDir = '';
 
+	// Fields not shown in gui
+	var $_hiddenConfFields = '';
 	// Name of site
 	var $_siteName = "SeedDMS";
 	// Message to display at the bottom of every page.
@@ -59,7 +62,7 @@ class Settings { /* {{{ */
 	// maximum amount of bytes a user may consume, 0 = unlimited
 	var $_quota = 0;
 	// comma separated list of undeleteable user ids
-	var $_undelUserIds = 0;
+	var $_undelUserIds = array();
 	// Restricted access: only allow users to log in if they have an entry in
 	// the local database (irrespective of successful authentication with LDAP).
 	var $_restricted = true;
@@ -83,6 +86,9 @@ class Settings { /* {{{ */
 	// list of form fields which are visible by default but can be explixitly
 	// turn off (comment, keywords, categories, sequence, expiration, owner
 	var $_noDocumentFormFields = array();
+	// list of form fields which are visible by default but can be explixitly
+	// turn off (comment, keywords, categories, sequence, expiration, owner
+	var $_noFolderFormFields = array();
 	// Path to where SeedDMS is located
 	var $_rootDir = null;
 	// Path to SeedDMS_Core
@@ -152,8 +158,6 @@ class Settings { /* {{{ */
 	var $_overrideTheme = false;
 	// experimental one page mode for ViewFolder page
 	var $_onePageMode = false;
-	// Workaround for page titles that go over more than 2 lines.
-	var $_titleDisplayHack = true;
 	// enable/disable automatic email notification
 	var $_enableEmail = true;
 	// enable/disable group and user view for all users
@@ -166,6 +170,8 @@ class Settings { /* {{{ */
 	var $_enableSelfRevApp = false;
 	// enable/disable update of a review/approval by the reviewer/approver
 	var $_enableUpdateRevApp = false;
+	// enable/disable removal of a review/approval by the admiistrator
+	var $_enableRemoveRevApp = false;
 	// enable/disable default notification for owner
 	var $_enableOwnerNotification = false;
 	// enable/disable deleting of versions for regular users
@@ -215,6 +221,12 @@ class Settings { /* {{{ */
 	var $_calendarDefaultView = "y";
 	// first day of the week (0=sunday, 1=monday, 6=saturday)
 	var $_firstDayOfWeek = 0;
+	// enable/disable download of extensions
+	var $_enableExtensionDownload = true;
+	// enable/disable import of extensions
+	var $_enableExtensionImport = true;
+	// enable/disable import of extensions from repository
+	var $_enableExtensionImportFromRepository = true;
 	// enable/disable display of the clipboard
 	var $_enableClipboard = true;
 	// enable/disable list of tasks in main menu
@@ -249,6 +261,8 @@ class Settings { /* {{{ */
 	var $_sortFoldersDefault = '';
 	// Where to insert new documents ('start' or 'end')
 	var $_defaultDocPosition = 'end';
+	// Where to insert new folders ('start' or 'end')
+	var $_defaultFolderPosition = 'end';
 	// Set valid IP for admin logins
 	// if enabled admin can login only by specified IP addres
 	var $_adminIP = "";
@@ -344,6 +358,8 @@ class Settings { /* {{{ */
 				exit;
 			}
 		}
+		$this->_configFileDir = dirname($this->_configFilePath);
+
 		if(!$this->load($configFilePath)) {
 				echo "Your configuration contains errors.";
 				exit;
@@ -382,8 +398,8 @@ class Settings { /* {{{ */
 	 *
 	 */
 	function arrayToString($value) { /* {{{ */
-    return implode(";", $value);
-  } /* }}} */
+		return implode(";", $value);
+	} /* }}} */
 
 	/**
 	 * Return array from ';' seperated string
@@ -392,8 +408,8 @@ class Settings { /* {{{ */
 	 *
 	 */
 	function stringToArray($value) { /* {{{ */
-    return explode(";", $Value);
-  } /* }}} */
+		return explode(";", $Value);
+	} /* }}} */
 
 	/**
 	 * set $_viewOnlineFileTypes
@@ -401,9 +417,9 @@ class Settings { /* {{{ */
 	 * @param string $stringValue string value
 	 *
 	 */
-  function setViewOnlineFileTypesFromString($stringValue) { /* {{{ */
-    $this->_viewOnlineFileTypes = explode(";", $stringValue);
-  } /* }}} */
+	function setViewOnlineFileTypesFromString($stringValue) { /* {{{ */
+		$this->_viewOnlineFileTypes = explode(";", $stringValue);
+	} /* }}} */
 
 	/**
 	 * get $_viewOnlineFileTypes in a string value
@@ -411,9 +427,9 @@ class Settings { /* {{{ */
 	 * @return string value
 	 *
 	 */
-  function getViewOnlineFileTypesToString() { /* {{{ */
-    return implode(";", $this->_viewOnlineFileTypes);
-  } /* }}} */
+	function getViewOnlineFileTypesToString() { /* {{{ */
+		return implode(";", $this->_viewOnlineFileTypes);
+	} /* }}} */
 
 	/**
 	 * set $_editOnlineFileTypes
@@ -421,9 +437,9 @@ class Settings { /* {{{ */
 	 * @param string $stringValue string value
 	 *
 	 */
-  function setEditOnlineFileTypesFromString($stringValue) { /* {{{ */
-    $this->_editOnlineFileTypes = explode(";", $stringValue);
-  } /* }}} */
+	function setEditOnlineFileTypesFromString($stringValue) { /* {{{ */
+		$this->_editOnlineFileTypes = explode(";", $stringValue);
+	} /* }}} */
 
 	/**
 	 * get $_editOnlineFileTypes in a string value
@@ -431,9 +447,9 @@ class Settings { /* {{{ */
 	 * @return string value
 	 *
 	 */
-  function getEditOnlineFileTypesToString() { /* {{{ */
-    return implode(";", $this->_editOnlineFileTypes);
-  } /* }}} */
+	function getEditOnlineFileTypesToString() { /* {{{ */
+		return implode(";", $this->_editOnlineFileTypes);
+	} /* }}} */
 
 	/**
 	 * Load config file
@@ -488,6 +504,8 @@ class Settings { /* {{{ */
 		$this->_inlineEditing = Settings::boolVal($tab["inlineEditing"]);
 		if(trim(strval($tab["noDocumentFormFields"])))
 			$this->_noDocumentFormFields = explode(',',strval($tab["noDocumentFormFields"]));
+		if(trim(strval($tab["noFolderFormFields"])))
+			$this->_noFolderFormFields = explode(',',strval($tab["noFolderFormFields"]));
 		$this->setViewOnlineFileTypesFromString(strval($tab["viewOnlineFileTypes"]));
 		$this->setEditOnlineFileTypesFromString(strval($tab["editOnlineFileTypes"]));
 		$this->_enableConverting = Settings::boolVal($tab["enableConverting"]);
@@ -515,8 +533,9 @@ class Settings { /* {{{ */
 		$this->_sortFoldersDefault = strval($tab["sortFoldersDefault"]);
 		$this->_expandFolderTree = intval($tab["expandFolderTree"]);
 		$this->_defaultDocPosition = strval($tab["defaultDocPosition"]);
+		$this->_defaultFolderPosition = strval($tab["defaultFolderPosition"]);
 
-		// XML Path: /configuration/site/calendar
+		// XML Path: /configuration/site/webdav
 		$node = $xml->xpath('/configuration/site/webdav');
 		if($node) {
 			$tab = $node[0]->attributes();
@@ -532,6 +551,15 @@ class Settings { /* {{{ */
 			$this->_firstDayOfWeek = intval($tab["firstDayOfWeek"]);
 		}
 
+		// XML Path: /configuration/site/extensionmgr
+		$node = $xml->xpath('/configuration/site/extensionmgr');
+		if($node) {
+			$tab = $node[0]->attributes();
+			$this->_enableExtensionDownload = Settings::boolVal($tab["enableExtensionDownload"]);
+			$this->_enableExtensionImport = Settings::boolVal($tab["enableExtensionImport"]);
+			$this->_enableExtensionImportFromRepository = Settings::boolVal($tab["enableExtensionImportFromRepository"]);
+		}
+
 		// XML Path: /configuration/system/server
 		$node = $xml->xpath('/configuration/system/server');
 		if($node) {
@@ -572,7 +600,8 @@ class Settings { /* {{{ */
 			$this->_loginFailure = intval($tab["loginFailure"]);
 			$this->_autoLoginUser = intval($tab["autoLoginUser"]);
 			$this->_quota = intval($tab["quota"]);
-			$this->_undelUserIds = strval($tab["undelUserIds"]);
+			if(trim(strval($tab["undelUserIds"])))
+				$this->_undelUserIds = explode(',',strval($tab["undelUserIds"]));
 			$this->_encryptionKey = strval($tab["encryptionKey"]);
 			$this->_cookieLifetime = intval($tab["cookieLifetime"]);
 			$this->_defaultAccessDocs = intval($tab["defaultAccessDocs"]);
@@ -667,8 +696,8 @@ class Settings { /* {{{ */
 			$this->_siteDefaultPage = strval($tab["siteDefaultPage"]);
 			$this->_rootFolderID = intval($tab["rootFolderID"]);
 			$this->_useHomeAsRootFolder = Settings::boolval($tab["useHomeAsRootFolder"]);
-			$this->_titleDisplayHack = Settings::boolval($tab["titleDisplayHack"]);
 			$this->_showMissingTranslations = Settings::boolval($tab["showMissingTranslations"]);
+			$this->_hiddenConfFields = explode(';', strval($tab["hiddenConfFields"]));
 		}
 
 		// XML Path: /configuration/advanced/authentication
@@ -690,6 +719,7 @@ class Settings { /* {{{ */
 			$this->_enableOwnerRevApp = Settings::boolval($tab["enableOwnerRevApp"]);
 			$this->_enableSelfRevApp = Settings::boolval($tab["enableSelfRevApp"]);
 			$this->_enableUpdateRevApp = Settings::boolval($tab["enableUpdateRevApp"]);
+			$this->_enableRemoveRevApp = Settings::boolval($tab["enableRemoveRevApp"]);
 			$this->_presetExpirationDate = strval($tab["presetExpirationDate"]);
 			$this->_versioningFileName = strval($tab["versioningFileName"]);
 			$this->_workflowMode = strval($tab["workflowMode"]);
@@ -776,20 +806,20 @@ class Settings { /* {{{ */
 	 *
 	 * @return true/false
 	 */
-  protected function setXMLAttributValue($node, $attributName, $attributValue) { /* {{{ */
-    if (is_bool($attributValue)) {
-      if ($attributValue)
-        $attributValue = "true";
-      else
-        $attributValue = "false";
-    }
+	protected function setXMLAttributValue($node, $attributName, $attributValue) { /* {{{ */
+		if (is_bool($attributValue)) {
+			if ($attributValue)
+				$attributValue = "true";
+			else
+				$attributValue = "false";
+		}
 
-    if (isset($node[$attributName])) {
-      $node[$attributName] = $attributValue;
-    } else {
-      $node->addAttribute($attributName, $attributValue);
-    }
-  } /* }}} */
+		if (isset($node[$attributName])) {
+			$node[$attributName] = $attributValue;
+		} else {
+			$node->addAttribute($attributName, $attributValue);
+		}
+	} /* }}} */
 
 	/**
 	 * Get XML node, create it if not exists
@@ -821,12 +851,12 @@ class Settings { /* {{{ */
 	 * @return true/false
 	 */
 	public function save($configFilePath=NULL) { /* {{{ */
-    if (is_null($configFilePath))
-      $configFilePath = $this->_configFilePath;
+		if (is_null($configFilePath))
+			$configFilePath = $this->_configFilePath;
 
-    // Load
-    $xml = simplexml_load_string(file_get_contents($configFilePath));
-    $this->getXMLNode($xml, '/', 'configuration');
+		// Load
+		$xml = simplexml_load_string(file_get_contents($configFilePath));
+		$this->getXMLNode($xml, '/', 'configuration');
 
     // XML Path: /configuration/site/display
     $this->getXMLNode($xml, '/configuration', 'site');
@@ -855,6 +885,7 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "strictFormCheck", $this->_strictFormCheck);
     $this->setXMLAttributValue($node, "inlineEditing", $this->_inlineEditing);
     $this->setXMLAttributValue($node, "noDocumentFormFields", implode(',', $this->_noDocumentFormFields));
+    $this->setXMLAttributValue($node, "noFolderFormFields", implode(',', $this->_noFolderFormFields));
     $this->setXMLAttributValue($node, "viewOnlineFileTypes", $this->getViewOnlineFileTypesToString());
     $this->setXMLAttributValue($node, "editOnlineFileTypes", $this->getEditOnlineFileTypesToString());
     $this->setXMLAttributValue($node, "enableConverting", $this->_enableConverting);
@@ -882,8 +913,9 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "sortUsersInList", $this->_sortUsersInList);
     $this->setXMLAttributValue($node, "sortFoldersDefault", $this->_sortFoldersDefault);
     $this->setXMLAttributValue($node, "defaultDocPosition", $this->_defaultDocPosition);
+    $this->setXMLAttributValue($node, "defaultFolderPosition", $this->_defaultFolderPosition);
 
-    // XML Path: /configuration/site/calendar
+    // XML Path: /configuration/site/webdav
     $node = $this->getXMLNode($xml, '/configuration/site', 'webdav');
 		$this->setXMLAttributValue($node, "enableWebdavReplaceDoc", $this->_enableWebdavReplaceDoc);
 
@@ -893,6 +925,12 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "calendarDefaultView", $this->_calendarDefaultView);
     $this->setXMLAttributValue($node, "firstDayOfWeek", $this->_firstDayOfWeek);
 
+    // XML Path: /configuration/site/extensionmgr
+		$node = $this->getXMLNode($xml, '/configuration/site', 'extensionmgr');
+		$this->setXMLAttributValue($node, "enableExtensionDownload", $this->_enableExtensionDownload);
+		$this->setXMLAttributValue($node, "enableExtensionImport", $this->_enableExtensionImport);
+		$this->setXMLAttributValue($node, "enableExtensionImportFromRepository", $this->_enableExtensionImportFromRepository);
+
     // XML Path: /configuration/system/server
     $this->getXMLNode($xml, '/configuration', 'system');
     $node = $this->getXMLNode($xml, '/configuration/system', 'server');
@@ -927,7 +965,7 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "loginFailure", $this->_loginFailure);
     $this->setXMLAttributValue($node, "autoLoginUser", $this->_autoLoginUser);
     $this->setXMLAttributValue($node, "quota", $this->_quota);
-    $this->setXMLAttributValue($node, "undelUserIds", $this->_undelUserIds);
+    $this->setXMLAttributValue($node, "undelUserIds", implode(',', $this->_undelUserIds));
     $this->setXMLAttributValue($node, "encryptionKey", $this->_encryptionKey);
     $this->setXMLAttributValue($node, "cookieLifetime", $this->_cookieLifetime);
     $this->setXMLAttributValue($node, "defaultAccessDocs", $this->_defaultAccessDocs);
@@ -935,71 +973,71 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "enableUserImage", $this->_enableUserImage);
     $this->setXMLAttributValue($node, "disableSelfEdit", $this->_disableSelfEdit);
 
-    // XML Path: /configuration/system/authentication/connectors
-    foreach($this->_usersConnectors as $keyConn => $paramConn)
-    {
-      // search XML node
-      $node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="'. $keyConn .'"]');
+		// XML Path: /configuration/system/authentication/connectors
+		foreach($this->_usersConnectors as $keyConn => $paramConn)
+		{
+			// search XML node
+			$node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="'. $keyConn .'"]');
 
-      // Just the first is configured
-      if (isset($node))
-      {
-        if (count($node)>0)
-        {
-          $node = $node[0];
-        }
-        else
-        {
-          $nodeParent = $xml->xpath('/configuration/system/authentication/connectors');
-          $node = $nodeParent[0]->addChild("connector");
-        }
+			// Just the first is configured
+			if (isset($node))
+			{
+				if (count($node)>0)
+				{
+					$node = $node[0];
+				}
+				else
+				{
+					$nodeParent = $xml->xpath('/configuration/system/authentication/connectors');
+					$node = $nodeParent[0]->addChild("connector");
+				}
 
-        foreach($paramConn as $key => $value)
-        {
-          $this->setXMLAttributValue($node, $key, $value);
-        }
+				foreach($paramConn as $key => $value)
+				{
+					$this->setXMLAttributValue($node, $key, $value);
+				}
 
-      } // isset($node)
+			} // isset($node)
 
-    } // foreach
+		} // foreach
 
-    // XML Path: /configuration/system/authentication/connectors
-    // manage old settings parameters
-    if (isset($this->_ldapHost) && (strlen($this->_ldapHost)>0))
-    {
-      if ($this->_ldapType == 1)
-      {
-        $node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="AD"]');
-        $node = $node[0];
-        $this->setXMLAttributValue($node, "accountDomainName", $this->_ldapAccountDomainName);
-      }
-      else
-      {
-        $node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="ldap"]');
-        $node = $node[0];
-      }
+		// XML Path: /configuration/system/authentication/connectors
+		// manage old settings parameters
+		if (isset($this->_ldapHost) && (strlen($this->_ldapHost)>0))
+		{
+			if ($this->_ldapType == 1)
+			{
+				$node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="AD"]');
+				$node = $node[0];
+				$this->setXMLAttributValue($node, "accountDomainName", $this->_ldapAccountDomainName);
+			}
+			else
+			{
+				$node = $xml->xpath('/configuration/system/authentication/connectors/connector[@type="ldap"]');
+				$node = $node[0];
+			}
 
-      $this->setXMLAttributValue($node, "host", $this->_ldapHost);
-      $this->setXMLAttributValue($node, "port", $this->_ldapPort);
-      $this->setXMLAttributValue($node, "baseDN", $this->_ldapBaseDN);
-    }
+			$this->setXMLAttributValue($node, "host", $this->_ldapHost);
+			$this->setXMLAttributValue($node, "port", $this->_ldapPort);
+			$this->setXMLAttributValue($node, "baseDN", $this->_ldapBaseDN);
+		}
 
-    // XML Path: /configuration/system/database
-    $node = $this->getXMLNode($xml, '/configuration/system', 'database');
-    $this->setXMLAttributValue($node, "dbDriver", $this->_dbDriver);
-    $this->setXMLAttributValue($node, "dbHostname", $this->_dbHostname);
-    $this->setXMLAttributValue($node, "dbDatabase", $this->_dbDatabase);
-    $this->setXMLAttributValue($node, "dbUser", $this->_dbUser);
-    $this->setXMLAttributValue($node, "dbPass", $this->_dbPass);
-    $this->setXMLAttributValue($node, "doNotCheckVersion", $this->_doNotCheckDBVersion);
+		// XML Path: /configuration/system/database
+		$node = $this->getXMLNode($xml, '/configuration/system', 'database');
+		$this->setXMLAttributValue($node, "dbDriver", $this->_dbDriver);
+		$this->setXMLAttributValue($node, "dbHostname", $this->_dbHostname);
+		$this->setXMLAttributValue($node, "dbDatabase", $this->_dbDatabase);
+		$this->setXMLAttributValue($node, "dbUser", $this->_dbUser);
+		$this->setXMLAttributValue($node, "dbPass", $this->_dbPass);
+		$this->setXMLAttributValue($node, "doNotCheckDBVersion", $this->_doNotCheckDBVersion);
 
-    // XML Path: /configuration/system/smtp
-    $node = $this->getXMLNode($xml, '/configuration/system', 'smtp');
-    $this->setXMLAttributValue($node, "smtpServer", $this->_smtpServer);
-    $this->setXMLAttributValue($node, "smtpPort", $this->_smtpPort);
-    $this->setXMLAttributValue($node, "smtpSendFrom", $this->_smtpSendFrom);
-    $this->setXMLAttributValue($node, "smtpUser", $this->_smtpUser);
-    $this->setXMLAttributValue($node, "smtpPassword", $this->_smtpPassword);
+		// XML Path: /configuration/system/smtp
+		$node = $this->getXMLNode($xml, '/configuration/system', 'smtp');
+		$this->setXMLAttributValue($node, "smtpServer", $this->_smtpServer);
+		$this->setXMLAttributValue($node, "smtpPort", $this->_smtpPort);
+		$this->setXMLAttributValue($node, "smtpSendFrom", $this->_smtpSendFrom);
+		$this->setXMLAttributValue($node, "smtpUser", $this->_smtpUser);
+		$this->setXMLAttributValue($node, "smtpPassword", $this->_smtpPassword);
 
     // XML Path: /configuration/advanced/display
     $advnode = $this->getXMLNode($xml, '/configuration', 'advanced');
@@ -1007,52 +1045,53 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "siteDefaultPage", $this->_siteDefaultPage);
     $this->setXMLAttributValue($node, "rootFolderID", $this->_rootFolderID);
     $this->setXMLAttributValue($node, "useHomeAsRootFolder", $this->_useHomeAsRootFolder);
-    $this->setXMLAttributValue($node, "titleDisplayHack", $this->_titleDisplayHack);
     $this->setXMLAttributValue($node, "showMissingTranslations", $this->_showMissingTranslations);
+//    $this->setXMLAttributValue($node, "hiddenConfFields", $this->_hiddenConfFields);
 
-    // XML Path: /configuration/advanced/authentication
-    $node = $this->getXMLNode($xml, '/configuration/advanced', 'authentication');
-    $this->setXMLAttributValue($node, "guestID", $this->_guestID);
-    $this->setXMLAttributValue($node, "adminIP", $this->_adminIP);
-    $this->setXMLAttributValue($node, "apiKey", $this->_apiKey);
-    $this->setXMLAttributValue($node, "apiUserId", $this->_apiUserId);
-    $this->setXMLAttributValue($node, "apiOrigin", $this->_apiOrigin);
+		// XML Path: /configuration/advanced/authentication
+		$node = $this->getXMLNode($xml, '/configuration/advanced', 'authentication');
+		$this->setXMLAttributValue($node, "guestID", $this->_guestID);
+		$this->setXMLAttributValue($node, "adminIP", $this->_adminIP);
+		$this->setXMLAttributValue($node, "apiKey", $this->_apiKey);
+		$this->setXMLAttributValue($node, "apiUserId", $this->_apiUserId);
+		$this->setXMLAttributValue($node, "apiOrigin", $this->_apiOrigin);
 
-    // XML Path: /configuration/advanced/edition
-    $node = $this->getXMLNode($xml, '/configuration/advanced', 'edition');
-    $this->setXMLAttributValue($node, "enableAdminRevApp", $this->_enableAdminRevApp);
-    $this->setXMLAttributValue($node, "enableOwnerRevApp", $this->_enableOwnerRevApp);
-    $this->setXMLAttributValue($node, "enableSelfRevApp", $this->_enableSelfRevApp);
-    $this->setXMLAttributValue($node, "enableUpdateRevApp", $this->_enableUpdateRevApp);
-    $this->setXMLAttributValue($node, "presetExpirationDate", $this->_presetExpirationDate);
-    $this->setXMLAttributValue($node, "versioningFileName", $this->_versioningFileName);
-    $this->setXMLAttributValue($node, "presetExpirationDate", $this->_presetExpirationDate);
-    $this->setXMLAttributValue($node, "workflowMode", $this->_workflowMode);
-    $this->setXMLAttributValue($node, "allowReviewerOnly", $this->_allowReviewerOnly);
-    $this->setXMLAttributValue($node, "enableVersionDeletion", $this->_enableVersionDeletion);
-    $this->setXMLAttributValue($node, "enableVersionModification", $this->_enableVersionModification);
-    $this->setXMLAttributValue($node, "enableDuplicateDocNames", $this->_enableDuplicateDocNames);
-    $this->setXMLAttributValue($node, "enableDuplicateSubFolderNames", $this->_enableDuplicateSubFolderNames);
-    $this->setXMLAttributValue($node, "overrideMimeType", $this->_overrideMimeType);
-    $this->setXMLAttributValue($node, "removeFromDropFolder", $this->_removeFromDropFolder);
+		// XML Path: /configuration/advanced/edition
+		$node = $this->getXMLNode($xml, '/configuration/advanced', 'edition');
+		$this->setXMLAttributValue($node, "enableAdminRevApp", $this->_enableAdminRevApp);
+		$this->setXMLAttributValue($node, "enableOwnerRevApp", $this->_enableOwnerRevApp);
+		$this->setXMLAttributValue($node, "enableSelfRevApp", $this->_enableSelfRevApp);
+		$this->setXMLAttributValue($node, "enableUpdateRevApp", $this->_enableUpdateRevApp);
+		$this->setXMLAttributValue($node, "enableRemoveRevApp", $this->_enableRemoveRevApp);
+		$this->setXMLAttributValue($node, "presetExpirationDate", $this->_presetExpirationDate);
+		$this->setXMLAttributValue($node, "versioningFileName", $this->_versioningFileName);
+		$this->setXMLAttributValue($node, "presetExpirationDate", $this->_presetExpirationDate);
+		$this->setXMLAttributValue($node, "workflowMode", $this->_workflowMode);
+		$this->setXMLAttributValue($node, "allowReviewerOnly", $this->_allowReviewerOnly);
+		$this->setXMLAttributValue($node, "enableVersionDeletion", $this->_enableVersionDeletion);
+		$this->setXMLAttributValue($node, "enableVersionModification", $this->_enableVersionModification);
+		$this->setXMLAttributValue($node, "enableDuplicateDocNames", $this->_enableDuplicateDocNames);
+		$this->setXMLAttributValue($node, "enableDuplicateSubFolderNames", $this->_enableDuplicateSubFolderNames);
+		$this->setXMLAttributValue($node, "overrideMimeType", $this->_overrideMimeType);
+		$this->setXMLAttributValue($node, "removeFromDropFolder", $this->_removeFromDropFolder);
 
-    // XML Path: /configuration/advanced/notification
-    $node = $this->getXMLNode($xml, '/configuration/advanced', 'notification');
-    $this->setXMLAttributValue($node, "enableNotificationAppRev", $this->_enableNotificationAppRev);
-    $this->setXMLAttributValue($node, "enableOwnerNotification", $this->_enableOwnerNotification);
-    $this->setXMLAttributValue($node, "enableNotificationWorkflow", $this->_enableNotificationWorkflow);
+		// XML Path: /configuration/advanced/notification
+		$node = $this->getXMLNode($xml, '/configuration/advanced', 'notification');
+		$this->setXMLAttributValue($node, "enableNotificationAppRev", $this->_enableNotificationAppRev);
+		$this->setXMLAttributValue($node, "enableOwnerNotification", $this->_enableOwnerNotification);
+		$this->setXMLAttributValue($node, "enableNotificationWorkflow", $this->_enableNotificationWorkflow);
 
-    // XML Path: /configuration/advanced/server
-    $node = $this->getXMLNode($xml, '/configuration/advanced', 'server');
-    $this->setXMLAttributValue($node, "coreDir", $this->_coreDir);
-    $this->setXMLAttributValue($node, "luceneClassDir", $this->_luceneClassDir);
-    $this->setXMLAttributValue($node, "extraPath", $this->_extraPath);
-    $this->setXMLAttributValue($node, "contentOffsetDir", $this->_contentOffsetDir);
-    $this->setXMLAttributValue($node, "maxDirID", $this->_maxDirID);
-    $this->setXMLAttributValue($node, "updateNotifyTime", $this->_updateNotifyTime);
-    $this->setXMLAttributValue($node, "maxExecutionTime", $this->_maxExecutionTime);
-    $this->setXMLAttributValue($node, "cmdTimeout", $this->_cmdTimeout);
-    $this->setXMLAttributValue($node, "enableDebugMode", $this->_enableDebugMode);
+		// XML Path: /configuration/advanced/server
+		$node = $this->getXMLNode($xml, '/configuration/advanced', 'server');
+		$this->setXMLAttributValue($node, "coreDir", $this->_coreDir);
+		$this->setXMLAttributValue($node, "luceneClassDir", $this->_luceneClassDir);
+		$this->setXMLAttributValue($node, "extraPath", $this->_extraPath);
+		$this->setXMLAttributValue($node, "contentOffsetDir", $this->_contentOffsetDir);
+		$this->setXMLAttributValue($node, "maxDirID", $this->_maxDirID);
+		$this->setXMLAttributValue($node, "updateNotifyTime", $this->_updateNotifyTime);
+		$this->setXMLAttributValue($node, "maxExecutionTime", $this->_maxExecutionTime);
+		$this->setXMLAttributValue($node, "cmdTimeout", $this->_cmdTimeout);
+		$this->setXMLAttributValue($node, "enableDebugMode", $this->_enableDebugMode);
 
 		/* Check if there is still a converters list with a target attribute */
 		$node = $xml->xpath('/configuration/advanced/converters[count(@*)=0]');
@@ -1091,8 +1130,8 @@ class Settings { /* {{{ */
 		} // foreach
 
 
-    // XML Path: /configuration/extensions
-    $extnodes = $xml->xpath('/configuration/extensions');
+		// XML Path: /configuration/extensions
+		$extnodes = $xml->xpath('/configuration/extensions');
 		if(!$extnodes) {
 			$nodeParent = $xml->xpath('/configuration');
 			$extnodes = $nodeParent[0]->addChild("extensions");
@@ -1100,9 +1139,9 @@ class Settings { /* {{{ */
 			unset($xml->extensions);
 			$extnodes = $xml->addChild("extensions");
 		}
-    foreach($this->_extensions as $name => $extension)
+		foreach($this->_extensions as $name => $extension)
 		{
-      // search XML node
+			// search XML node
 			$extnode = $extnodes->addChild('extension');
 			$this->setXMLAttributValue($extnode, 'name', $name);
 			$this->setXMLAttributValue($extnode, 'disable', $extension['__disable__'] ? 'true' : 'false');
@@ -1128,10 +1167,10 @@ class Settings { /* {{{ */
 			 */
 
 
-    } // foreach
+		} // foreach
 
-    // Save
-    return $xml->asXML($configFilePath);
+		// Save
+		return $xml->asXML($configFilePath);
   } /* }}} */
 
 	/**
@@ -1158,12 +1197,16 @@ class Settings { /* {{{ */
 	 * @return NULL|string config directory
 	 */
 	static function getConfigDir() { /* {{{ */
+		if(defined("SEEDDMS_CONFIG_FILE"))
+			return dirname(SEEDDMS_CONFIG_FILE);
+		elseif(getenv("SEEDDMS_CONFIG_FILE"))
+			return dirname(getenv("SEEDDMS_CONFIG_FILE"));
 		$_tmp = dirname($_SERVER['SCRIPT_FILENAME']);
 		$_arr = preg_split('/\//', rtrim(str_replace('\\', '/', $_tmp)));
 		$configDir = null;
 		/* new code starts here */
 		while($_arr && !$configDir) {
-			if(file_exists(implode('/', $_arr)."/conf/"))
+			if(file_exists(implode('/', $_arr)."/conf/settings.xml"))
 				$configDir = implode('/', $_arr)."/conf/";
 			else
 				array_pop($_arr);
@@ -1199,15 +1242,15 @@ class Settings { /* {{{ */
 	  $pageURL = 'http';
 
 	  if (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on") {
-	    $pageURL .= "s";
+			$pageURL .= "s";
 	  }
 
 	  $pageURL .= "://";
 
 	  if ($_SERVER["SERVER_PORT"] != "80") {
-	    $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
+			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
 	  } else {
-	    $pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
+			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
 	  }
 
 	  return $pageURL;
@@ -1264,6 +1307,7 @@ class Settings { /* {{{ */
 
 		// TODO
 		// $this->_coreDir
+/*
 		if($this->_coreDir) {
 			if (!file_exists($this->_coreDir ."Core.php")) {
 				$result["coreDir"] = array(
@@ -1284,7 +1328,7 @@ class Settings { /* {{{ */
 					);
 			}
 		}
-
+*/
 		// $this->_httpRoot
 		$tmp = $this->curPageURL();
 		$tmp = str_replace ("install.php", "" , $tmp);
@@ -1435,7 +1479,7 @@ class Settings { /* {{{ */
 						if(!empty($this->_coreDir))
 							require_once($this->_coreDir.'/Core.php');
 						else
-							require_once('SeedDMS/Core.php');
+							require_once($this->_rootDir.'../pear/SeedDMS/Core.php');
 						$tmpcore = new SeedDMS_Core_DMS(null, $this->_contentDir);
 						$db = new SeedDMS_Core_DatabaseAccess($this->_dbDriver, $this->_dbHostname, $this->_dbUser, $this->_dbPass, $this->_dbDatabase);
 						if(!$db->connect()) {
@@ -1498,7 +1542,7 @@ class Settings { /* {{{ */
 		}
 
 		// Check PHP version
-		if (version_compare(PHP_VERSION, '5.6.38') < 0) {
+		if (version_compare(PHP_VERSION, '7.2.5') < 0) {
 			$result["php_version"] = array(
 				"status" => "versiontolow",
 				"type" => "error",
@@ -1508,6 +1552,15 @@ class Settings { /* {{{ */
 
 		// Check PHP configuration
 		$loaded_extensions = get_loaded_extensions();
+		// xml
+		if (!in_array("xml", $loaded_extensions)) {
+			$result["php_xml"] = array(
+				"status" => "notfound",
+				"type" => "error",
+				"suggestion" => "activate_php_extension"
+			);
+		}
+
 		// gd2
 		if (!in_array("gd", $loaded_extensions)) {
 			$result["php_gd2"] = array(
@@ -1526,6 +1579,42 @@ class Settings { /* {{{ */
 			);
 		}
 
+		// json
+		if (!in_array("json", $loaded_extensions)) {
+			$result["php_json"] = array(
+				"status" => "notfound",
+				"type" => "error",
+				"suggestion" => "activate_php_extension"
+			);
+		}
+
+		// zip
+		if (!in_array("zip", $loaded_extensions)) {
+			$result["php_zip"] = array(
+				"status" => "notfound",
+				"type" => "error",
+				"suggestion" => "activate_php_extension"
+			);
+		}
+
+		// fileinfo
+		if (!in_array("fileinfo", $loaded_extensions)) {
+			$result["php_fileinfo"] = array(
+				"status" => "notfound",
+				"type" => "error",
+				"suggestion" => "activate_php_extension"
+			);
+		}
+
+		// sqlite3
+		if (!in_array("sqlite3", $loaded_extensions)) {
+			$result["php_sqlite3"] = array(
+				"status" => "notfound",
+				"type" => "error",
+				"suggestion" => "activate_php_extension"
+			);
+		}
+
 		// database
 		if (!in_array('pdo_'.$this->_dbDriver, $loaded_extensions)) {
 			$result["php_dbDriver"] = array(
@@ -1549,6 +1638,7 @@ class Settings { /* {{{ */
 		 */
 
 		// Check for HTTP/WebDAV/Server.php
+		/*
 		if (!Settings::findInIncPath('HTTP/WebDAV/Server.php')) {
 			$result["pear_webdav"] = array(
 				"status" => "notfound",
@@ -1556,8 +1646,10 @@ class Settings { /* {{{ */
 				"suggestion" => "install_pear_package_webdav"
 			);
 		}
+		 */
 
 		// Check for Zend/Search/Lucene.php
+		/*
 		if (!Settings::findInIncPath('Zend/Search/Lucene.php')) {
 			$result["zendframework"] = array(
 				"status" => "notfound",
@@ -1565,6 +1657,7 @@ class Settings { /* {{{ */
 				"suggestion" => "install_zendframework"
 			);
 		}
+		 */
 		return $result;
 	} /* }}} */
 
