@@ -13,7 +13,7 @@
  */
 
 global $logger;
-$notifier = new SeedDMS_NotificationService($logger);
+$notifier = new SeedDMS_NotificationService($logger, $settings);
 
 if(isset($GLOBALS['SEEDDMS_HOOKS']['notification'])) {
 	foreach($GLOBALS['SEEDDMS_HOOKS']['notification'] as $notificationObj) {
