@@ -406,14 +406,19 @@ function add_log_line($msg="", $priority=null) { /* {{{ */
 
 	if(!$logger) return;
 
+	$ip = "-";
 	if(!empty($_SERVER['HTTP_X_FORWARDED_FOR']))
 		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
-	else
+	elseif(!empty($_SERVER['REMOTE_ADDR']))
 		$ip = $_SERVER['REMOTE_ADDR'];
-	if($user)
-		$logger->log($user->getLogin()." (".$ip.") ".basename($_SERVER["REQUEST_URI"], ".php").($msg ? $msg : ''), $priority);
+	if(!empty($_SERVER["REQUEST_URI"]))
+		$scriptname = basename($_SERVER["REQUEST_URI"]).' ';
 	else
-		$logger->log("-- (".$ip.") ".basename($_SERVER["REQUEST_URI"], ".php").($msg ? $msg : ''), $priority);
+		$scriptname = basename($_SERVER["SCRIPT_NAME"]).' ';
+	if($user)
+		$logger->log($user->getLogin()." (".$ip.") ".$scriptname.($msg ? $msg : ''), $priority);
+	else
+		$logger->log("-- (".$ip.") ".$scriptname.($msg ? $msg : ''), $priority);
 } /* }}} */
 
 function _add_log_line($msg="") { /* {{{ */
@@ -426,7 +431,7 @@ function _add_log_line($msg="") { /* {{{ */
 	else $logname=date("Ym", time());
 
 	if($h = fopen($settings->_contentDir.$logname.".log", "a")) {
-		fwrite($h,date("Y/m/d H:i", time())." ".$user->getLogin()." (".$_SERVER['REMOTE_ADDR'].") ".basename($_SERVER["REQUEST_URI"], ".php").$msg."\n");
+		fwrite($h,date("Y/m/d H:i", time())." ".$user->getLogin()." (".$_SERVER['REMOTE_ADDR'].") ".basename($_SERVER["REQUEST_URI"]).$msg."\n");
 		fclose($h);
 	}
 } /* }}} */
@@ -473,10 +478,10 @@ function showtree() { /* {{{ */
 function createFormKey($formid='') { /* {{{ */
 	global $settings, $session;
 
-	if($id = $session->getId()) {
+	if($session && $id = $session->getId()) {
 		return md5($id.$settings->_encryptionKey.$formid);
 	} else {
-		return false;
+		return md5($settings->_encryptionKey.$formid);
 	}
 } /* }}} */
 
@@ -778,6 +783,44 @@ function createNonce() { /* {{{ */
 	return base64_encode($bytes);
 } /* }}} */
 
+/**
+ * Compare function for sorting users by login
+ *
+ * Use this for usort()
+ *
+ * <code>
+ * $users = $dms->getAllUsers();
+ * usort($users, 'cmp_user_login');
+ * </code>
+ */
+function cmp_user_login($a, $b) { /* {{{ */
+	$as = strtolower($a->getLogin());
+	$bs = strtolower($b->getLogin());
+	if ($as == $bs) {
+		return 0;
+	}
+	return ($as < $bs) ? -1 : 1;
+} /* }}} */
+
+/**
+ * Compare function for sorting users by name 
+ *
+ * Use this for usort()
+ *
+ * <code>
+ * $users = $dms->getAllUsers();
+ * usort($users, 'cmp_user_fullname');
+ * </code>
+ */
+function cmp_user_fullname($a, $b) { /* {{{ */
+	$as = strtolower($a->getFullName());
+	$bs = strtolower($b->getFullName());
+	if ($as == $bs) {
+		return 0;
+	}
+	return ($as < $bs) ? -1 : 1;
+} /* }}} */
+
 /**
  * Returns the mandatory reviewers
  *
@@ -913,15 +956,76 @@ class SeedDMS_CSRF { /* {{{ */
 	} /* }}} */
 } /* }}} */
 
+/**
+ * Class to represent a jwt token
+ *
+ *
+ * @category   DMS
+ * @package    SeedDMS
+ * @author     Uwe Steinmann <uwe@steinmann.cx>
+ * @copyright  2016 Uwe Steinmann
+ * @version    Release: @package_version@
+ */
+class SeedDMS_JwtToken { /* {{{ */
+	protected $jwtsecret;
+
+	public function __construct($jwtsecret = '') { /* {{{ */
+		$this->jwtsecret = $jwtsecret;
+	} /* }}} */
+
+	public function jwtEncode($payload) { /* {{{ */
+		$header = [
+				"alg" => "HS256",
+				"typ" => "JWT"
+		];
+		$encHeader = self::base64UrlEncode(json_encode($header));
+		$encPayload = self::base64UrlEncode(json_encode($payload));
+		$hash = self::base64UrlEncode(self::calculateHash($encHeader, $encPayload));
+
+		return "$encHeader.$encPayload.$hash";
+	} /* }}} */
+
+	public function jwtDecode($token) { /* {{{ */
+		if (!$this->jwtsecret) return "";
+
+		$split = explode(".", $token);
+		if (count($split) != 3) return "";
+
+		$hash = self::base64UrlEncode(self::calculateHash($split[0], $split[1]));
+
+		if (strcmp($hash, $split[2]) != 0) return "";
+		return self::base64UrlDecode($split[1]);
+	} /* }}} */
+
+	protected function calculateHash($encHeader, $encPayload) { /* {{{ */
+		return hash_hmac("sha256", "$encHeader.$encPayload", $this->jwtsecret, true);
+	} /* }}} */
+
+	protected function base64UrlEncode($str) { /* {{{ */
+		return str_replace("/", "_", str_replace("+", "-", trim(base64_encode($str), "=")));
+	} /* }}} */
+
+	protected function base64UrlDecode($payload) { /* {{{ */
+		$b64 = str_replace("_", "/", str_replace("-", "+", $payload));
+		switch (strlen($b64) % 4) {
+			case 2:
+				$b64 = $b64 . "=="; break;
+			case 3:
+				$b64 = $b64 . "="; break;
+		}
+		return base64_decode($b64);
+	} /* }}} */
+} /* }}} */
+
 class SeedDMS_FolderTree { /* {{{ */
 
 	public function __construct($folder, $callback) { /* {{{ */
-    $iter = new \SeedDMS\RecursiveFolderIterator($folder);
-    $iter2 = new RecursiveIteratorIterator($iter, RecursiveIteratorIterator::       SELF_FIRST);
+		$iter = new \SeedDMS\RecursiveFolderIterator($folder);
+		$iter2 = new RecursiveIteratorIterator($iter, RecursiveIteratorIterator::SELF_FIRST);
 		foreach($iter2 as $ff) {
-			call_user_func($callback, $ff);
+			call_user_func($callback, $ff, $iter2->getDepth());
 //      echo $ff->getID().': '.$ff->getFolderPathPlain().'-'.$ff->getName()."<br />";
-    }
+		}
 	} /* }}} */
 
 } /* }}} */
