@@ -33,6 +33,13 @@ include("../inc/inc.ClassController.php");
 $tmp = explode('.', basename($_SERVER['SCRIPT_FILENAME']));
 $controller = Controller::factory($tmp[1], array('dms'=>$dms, 'user'=>$user));
 
+/* if post_max_size is to small, then $_POST will not be set and the content
+ * lenght will exceed post_max_size
+ */
+if(empty($_POST) && $_SERVER['CONTENT_LENGTH'] > SeedDMS_Core_File::parse_filesize(ini_get('post_max_size'))) {
+	UI::exitError(getMLText("folder_title", array("foldername" => '')),getMLText("uploading_postmaxsize"));
+}
+
 /* Check if the form data comes from a trusted request */
 if(!checkFormKey('adddocument')) {
 	UI::exitError(getMLText("folder_title", array("foldername" => getMLText("invalid_request_token"))),getMLText("invalid_request_token"));
@@ -205,13 +212,17 @@ if($settings->_workflowMode == 'traditional' || $settings->_workflowMode == 'tra
 		$mreviewers = getMandatoryReviewers($folder, $user);
 		if($mreviewers['i'])
 			$reviewers['i'] = array_merge($reviewers['i'], $mreviewers['i']);
+		if($mreviewers['g'])
+			$reviewers['g'] = array_merge($reviewers['g'], $mreviewers['g']);
 	}
 	$mapprovers = getMandatoryApprovers($folder, $user);
 	if($mapprovers['i'])
 		$approvers['i'] = array_merge($approvers['i'], $mapprovers['i']);
+	if($mapprovers['g'])
+		$approvers['g'] = array_merge($approvers['g'], $mapprovers['g']);
 
 	if($settings->_workflowMode == 'traditional' && !$settings->_allowReviewerOnly) {
-		/* Check if reviewers are send but no approvers */
+		/* Check if reviewers are set but no approvers */
 		if(($reviewers["i"] || $reviewers["g"]) && !$approvers["i"] && !$approvers["g"]) {
 			UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("error_uploading_reviewer_only"));
 		}
@@ -233,25 +244,43 @@ if($settings->_workflowMode == 'traditional' || $settings->_workflowMode == 'tra
 	}
 }
 
-$docsource = 'upload';
+function reArrayFiles(&$file_post) {
+	$file_ary = array();
+	$file_count = count($file_post['name']);
+	$file_keys = array_keys($file_post);
+
+	for ($i=0; $i<$file_count; $i++) {
+		if($file_post['error'][$i] != 4) { // no file uploaded
+		foreach ($file_keys as $key) {
+			$file_ary[$i][$key] = $file_post[$key][$i];
+		}
+		$file_ary[$i]['source'] = 'upload';
+		}
+	}
+
+	return $file_ary;
+}
+
+if ($_FILES['userfile']) {
+	$file_ary = reArrayFiles($_FILES['userfile']);
+} else {
+	$file_ary = array();
+}
 
 if($settings->_dropFolderDir) {
-	if(isset($_POST["dropfolderfileform1"]) && $_POST["dropfolderfileform1"]) {
-		$fullfile = $settings->_dropFolderDir.'/'.$user->getLogin().'/'.$_POST["dropfolderfileform1"];
+	if(isset($_POST["dropfolderfileadddocform"]) && $_POST["dropfolderfileadddocform"]) {
+		$fullfile = $settings->_dropFolderDir.'/'.$user->getLogin().'/'.$_POST["dropfolderfileadddocform"];
 		if(file_exists($fullfile)) {
-			$docsource = 'dropfolder';
-			/* Check if a local file is uploaded as well */
-			if(isset($_FILES["userfile"]['error'][0])) {
-				if($_FILES["userfile"]['error'][0] != 0)
-					$_FILES["userfile"] = array();
-			}
 			$finfo = finfo_open(FILEINFO_MIME_TYPE);
 			$mimetype = finfo_file($finfo, $fullfile);
-			$_FILES["userfile"]['tmp_name'][] = $fullfile;
-			$_FILES["userfile"]['type'][] = $mimetype;
-			$_FILES["userfile"]['name'][] = $_POST["dropfolderfileform1"];
-			$_FILES["userfile"]['size'][] = filesize($fullfile);
-			$_FILES["userfile"]['error'][] = 0;
+			$file_ary[] = array(
+				'tmp_name' => $fullfile,
+				'type' => $mimetype,
+				'name' => $_POST["dropfolderfileadddocform"],
+				'size' => filesize($fullfile),
+				'error' => 0,
+				'source' => 'dropfolder'
+			);
 		}
 	}
 }
@@ -265,15 +294,26 @@ if(isset($_POST[$prefix.'-fine-uploader-uuids']) && $_POST[$prefix.'-fine-upload
 		if(file_exists($fullfile)) {
 			$finfo = finfo_open(FILEINFO_MIME_TYPE);
 			$mimetype = finfo_file($finfo, $fullfile);
-			$_FILES["userfile"]['tmp_name'][] = $fullfile;
-			$_FILES["userfile"]['type'][] = $mimetype;
-			$_FILES["userfile"]['name'][] = isset($names[$i]) ? $names[$i] : $uuid;
-			$_FILES["userfile"]['size'][] = filesize($fullfile);
-			$_FILES["userfile"]['error'][] = 0;
+			$file_ary[] = array(
+				'tmp_name' => $fullfile,
+				'type' => $mimetype,
+				'name' => isset($names[$i]) ? $names[$i] : $uuid,
+				'size' => filesize($fullfile),
+				'error' => 0,
+				'source' => 'upload',
+			);
 		}
 	}
 }
 
+if($controller->hasHook('getDocument')) {
+	$file_ary = array_merge($file_ary, $controller->callHook('getDocument', $_POST));
+}
+
+if(!$file_ary) {
+	UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_failed"));
+}
+
 /* Check if additional notification shall be added */
 $notusers = array();
 if(!empty($_POST['notification_users'])) {
@@ -296,22 +336,25 @@ if(!empty($_POST['notification_groups'])) {
 
 /* Check files for Errors first */
 $maxuploadsize = SeedDMS_Core_File::parse_filesize($settings->_maxUploadSize);
-for ($file_num=0;$file_num<count($_FILES["userfile"]["tmp_name"]);$file_num++){
-	if ($_FILES["userfile"]["size"][$file_num]==0) {
-		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_zerosize"));
-	}
-	if ($maxuploadsize && $_FILES["userfile"]["size"][$file_num] > $maxuploadsize) {
+foreach($file_ary as $file) {
+	if($file['error']==1) {
 		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_maxsize"));
 	}
-	if (/* is_uploaded_file($_FILES["userfile"]["tmp_name"][$file_num]) && */$_FILES['userfile']['error'][$file_num]!=0){
+	if($file['error']!=0) {
 		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_failed"));
 	}
+	if ($file["size"]==0) {
+		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_zerosize"));
+	}
+	if ($maxuploadsize && $file["size"] > $maxuploadsize) {
+		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("uploading_maxsize"));
+	}
 }
 
-for ($file_num=0;$file_num<count($_FILES["userfile"]["tmp_name"]);$file_num++){
-	$userfiletmp = $_FILES["userfile"]["tmp_name"][$file_num];
-	$userfiletype = $_FILES["userfile"]["type"][$file_num];
-	$userfilename = $_FILES["userfile"]["name"][$file_num];
+foreach($file_ary as $file) {
+	$userfiletmp = $file["tmp_name"];
+	$userfiletype = $file["type"];
+	$userfilename = $file["name"];
 	
 	$fileType = ".".pathinfo($userfilename, PATHINFO_EXTENSION);
 
@@ -322,7 +365,7 @@ for ($file_num=0;$file_num<count($_FILES["userfile"]["tmp_name"]);$file_num++){
 			$userfiletype = $tmpfiletype;
 	}
 
-	if ((count($_FILES["userfile"]["tmp_name"])==1)&&($_POST["name"]!=""))
+	if ($_POST["name"]!="")
 		$name = trim($_POST["name"]);
 	else $name = utf8_basename($userfilename);
 
@@ -333,7 +376,8 @@ for ($file_num=0;$file_num<count($_FILES["userfile"]["tmp_name"]);$file_num++){
 		}
 	}
 
-	$controller->setParam('documentsource', $docsource);
+	$controller->setParam('documentsource', $file['source']);
+	$controller->setParam('documentsourcedetails', !empty($file['source_details']) ? $file['source_details'] : null);
 	$controller->setParam('folder', $folder);
 	$controller->setParam('fulltextservice', $fulltextservice);
 	$controller->setParam('name', $name);
@@ -372,105 +416,7 @@ for ($file_num=0;$file_num<count($_FILES["userfile"]["tmp_name"]);$file_num++){
 	} else {
 		// Send notification to subscribers of folder.
 		if($notifier) {
-			$fnl = $folder->getNotifyList();
-			$dnl = $document->getNotifyList();
-			$nl = array(
-				'users'=>array_unique(array_merge($dnl['users'], $fnl['users']), SORT_REGULAR),
-				'groups'=>array_unique(array_merge($dnl['groups'], $fnl['groups']), SORT_REGULAR)
-			);
-
-			$subject = "new_document_email_subject";
-			$message = "new_document_email_body";
-			$params = array();
-			$params['name'] = $name;
-			$params['folder_name'] = $folder->getName();
-			$params['folder_path'] = $folder->getFolderPathPlain();
-			$params['username'] = $user->getFullName();
-			$params['comment'] = $comment;
-			$params['version_comment'] = $version_comment;
-			$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-			$params['sitename'] = $settings->_siteName;
-			$params['http_root'] = $settings->_httpRoot;
-			$notifier->toList($user, $nl["users"], $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-			foreach ($nl["groups"] as $grp) {
-				$notifier->toGroup($user, $grp, $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-			}
-
-			/* Get workflow from controller in case it was modified in a hook */
-			$workflow = $controller->getParam('workflow');
-			if($workflow && $settings->_enableNotificationWorkflow) {
-				$subject = "request_workflow_action_email_subject";
-				$message = "request_workflow_action_email_body";
-				$params = array();
-				$params['name'] = $document->getName();
-				$params['version'] = $reqversion;
-				$params['workflow'] = $workflow->getName();
-				$params['folder_path'] = $folder->getFolderPathPlain();
-				$params['current_state'] = $workflow->getInitState()->getName();
-				$params['username'] = $user->getFullName();
-				$params['sitename'] = $settings->_siteName;
-				$params['http_root'] = $settings->_httpRoot;
-				$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-
-				foreach($workflow->getNextTransitions($workflow->getInitState()) as $ntransition) {
-					foreach($ntransition->getUsers() as $tuser) {
-						$notifier->toIndividual($user, $tuser->getUser(), $subject, $message, $params, SeedDMS_NotificationService::RECV_WORKFLOW);
-					}
-					foreach($ntransition->getGroups() as $tuser) {
-						$notifier->toGroup($user, $tuser->getGroup(), $subject, $message, $params, SeedDMS_NotificationService::RECV_WORKFLOW);
-					}
-				}
-			}
-
-			if($settings->_enableNotificationAppRev) {
-				/* Reviewers and approvers will be informed about the new document */
-				/* Get reviewers and approvers from controller in case it was
-				 * modified in a hook
-				 */
-				$reviewers = $controller->getParam('reviewers');
-        $approvers = $controller->getParam('approvers');
-				if($reviewers['i'] || $reviewers['g']) {
-					$subject = "review_request_email_subject";
-					$message = "review_request_email_body";
-					$params = array();
-					$params['name'] = $document->getName();
-					$params['folder_path'] = $folder->getFolderPathPlain();
-					$params['version'] = $reqversion;
-					$params['comment'] = $comment;
-					$params['username'] = $user->getFullName();
-					$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-					$params['sitename'] = $settings->_siteName;
-					$params['http_root'] = $settings->_httpRoot;
-
-					foreach($reviewers['i'] as $reviewerid) {
-						$notifier->toIndividual($user, $dms->getUser($reviewerid), $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
-					}
-					foreach($reviewers['g'] as $reviewergrpid) {
-						$notifier->toGroup($user, $dms->getGroup($reviewergrpid), $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
-					}
-				}
-
-				elseif($approvers['i'] || $approvers['g']) {
-					$subject = "approval_request_email_subject";
-					$message = "approval_request_email_body";
-					$params = array();
-					$params['name'] = $document->getName();
-					$params['folder_path'] = $folder->getFolderPathPlain();
-					$params['version'] = $reqversion;
-					$params['comment'] = $comment;
-					$params['username'] = $user->getFullName();
-					$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-					$params['sitename'] = $settings->_siteName;
-					$params['http_root'] = $settings->_httpRoot;
-
-					foreach($approvers['i'] as $approverid) {
-						$notifier->toIndividual($user, $dms->getUser($approverid), $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
-					}
-					foreach($approvers['g'] as $approvergrpid) {
-						$notifier->toGroup($user, $dms->getGroup($approvergrpid), $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
-					}
-				}
-			}
+			$notifier->sendNewDocumentMail($document, $user);
 		}
 		if($settings->_removeFromDropFolder) {
 			if(file_exists($userfiletmp)) {
