@@ -64,7 +64,7 @@ if (isset($_COOKIE["mydms_session"])) {
 	}
 
 	global $logger;
-	$notifier = new SeedDMS_NotificationService($logger);
+	$notifier = new SeedDMS_NotificationService($logger, $settings);
 	if(isset($GLOBALS['SEEDDMS_HOOKS']['notification'])) {
 		foreach($GLOBALS['SEEDDMS_HOOKS']['notification'] as $notificationObj) {
 			if(method_exists($notificationObj, 'preAddService')) {
@@ -74,7 +74,7 @@ if (isset($_COOKIE["mydms_session"])) {
 	}
 
 	if($settings->_enableEmail) {
-		$notifier->addService(new SeedDMS_EmailNotify($dms, $settings->_smtpSendFrom, $settings->_smtpServer, $settings->_smtpPort, $settings->_smtpUser, $settings->_smtpPassword));
+		$notifier->addService(new SeedDMS_EmailNotify($dms, $settings->_smtpSendFrom, $settings->_smtpServer, $settings->_smtpPort, $settings->_smtpUser, $settings->_smtpPassword), 'email');
 	}
 
 	if(isset($GLOBALS['SEEDDMS_HOOKS']['notification'])) {
@@ -145,6 +145,37 @@ switch($command) {
 		if($user) {
 			$query = $_GET['query'];
 
+			if(false !== ($pos = strpos($query, '/'))) {
+				$subquery = substr($query, 0, $pos);
+				$hits = $dms->search($subquery, $limit=0, $offset=0, $logicalmode='AND', $searchin=array(), $startFolder=$dms->getRootFolder(), $owner=null, $status = array(), $creationstartdate=array(), $creationenddate=array(), $modificationstartdate=array(), $modificationenddate=array(), $categories=array(), $attributes=array(), $mode=0x2, $expirationstartdate=array(), $expirationenddate=array());
+				if($hits) {
+					if(count($hits['folders']) == 1) {
+						$hit = $hits['folders'][0];
+						$basefolder = $dms->getFolder($hit->getID());
+						if($subquery = substr($query, $pos+1)) {
+							$hits = $dms->search($subquery, $limit=0, $offset=0, $logicalmode='AND', $searchin=array(), $startFolder=$basefolder, $owner=null, $status = array(), $creationstartdate=array(), $creationenddate=array(), $modificationstartdate=array(), $modificationenddate=array(), $categories=array(), $attributes=array(), $mode=0x2, $expirationstartdate=array(), $expirationenddate=array());
+							if($hits) {
+								$result = array();
+								foreach($hits['folders'] as $hit) {
+									$result[] = $hit->getID().'#'.$basefolder->getName().'/'.$hit->getName();
+								}
+								header('Content-Type: application/json');
+								echo json_encode($result);
+								return;
+							}
+						} else {
+							$subfolders = $basefolder->getSubFolders();
+							$result = array();
+							foreach($subfolders as $subfolder) {
+								$result[] = $subfolder->getID().'#'.$basefolder->getName().'/'.$subfolder->getName();
+							}
+							header('Content-Type: application/json');
+							echo json_encode($result);
+							return;
+						}
+					}
+				}
+			}
 			$hits = $dms->search($query, $limit=0, $offset=0, $logicalmode='AND', $searchin=array(), $startFolder=$dms->getRootFolder(), $owner=null, $status = array(), $creationstartdate=array(), $creationenddate=array(), $modificationstartdate=array(), $modificationenddate=array(), $categories=array(), $attributes=array(), $mode=0x2, $expirationstartdate=array(), $expirationenddate=array());
 			if($hits) {
 				$result = array();
@@ -279,7 +310,11 @@ switch($command) {
 					if ($mfolder->getAccessMode($user, 'moveFolder') >= M_READWRITE) {
 						if($folder = $dms->getFolder($_REQUEST['targetfolderid'])) {
 							if($folder->getAccessMode($user, 'moveFolder') >= M_READWRITE) {
+								$oldFolder = $mfolder->getParent();
 								if($mfolder->setParent($folder)) {
+									if($notifier) {
+										$notifier->sendMovedFolderMail($mfolder, $user, $oldFolder);
+									}
 									header('Content-Type: application/json');
 									echo json_encode(array('success'=>true, 'message'=>getMLText('splash_move_folder'), 'data'=>''));
 									add_log_line();
@@ -318,7 +353,14 @@ switch($command) {
 					if ($mdocument->getAccessMode($user, 'moveDocument') >= M_READWRITE) {
 						if($folder = $dms->getFolder($_REQUEST['targetfolderid'])) {
 							if($folder->getAccessMode($user, 'moveDocument') >= M_READWRITE) {
+								$oldFolder = $mdocument->getFolder();
 								if($mdocument->setFolder($folder)) {
+									if(isset($_REQUEST['sequence'])) {
+										$mdocument->setSequence((float) $_REQUEST['sequence']);
+									}
+									if($notifier) {
+										$notifier->sendMovedDocumentMail($mdocument, $user, $oldFolder);
+									}
 									header('Content-Type: application/json');
 									echo json_encode(array('success'=>true, 'message'=>getMLText('splash_move_document'), 'data'=>''));
 									add_log_line();
@@ -465,22 +507,10 @@ switch($command) {
 
 						if($folder->remove()) {
 							if ($notifier) {
-								$subject = "folder_deleted_email_subject";
-								$message = "folder_deleted_email_body";
-								$params = array();
-								$params['name'] = $foldername;
-								$params['folder_path'] = $parent->getFolderPathPlain();
-								$params['username'] = $user->getFullName();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewFolder.php?folderid=".$parent->getID();
-								$notifier->toList($user, $nl["users"], $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-								foreach ($nl["groups"] as $grp) {
-									$notifier->toGroup($user, $grp, $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-								}
+								$notifier->sendDeleteFolderMail($folder, $user);
 							}
 							header('Content-Type: application/json');
-							echo json_encode(array('success'=>true, 'message'=>'', 'data'=>''));
+							echo json_encode(array('success'=>true, 'message'=>getMLText('splash_folder_deleted'), 'data'=>''));
 							add_log_line();
 						} else {
 							header('Content-Type: application/json');
@@ -511,10 +541,6 @@ switch($command) {
 						/* Get the notify list before removing the document */
 						$dnl =	$document->getNotifyList();
 						$fnl =	$folder->getNotifyList();
-						$nl = array(
-							'users'=>array_unique(array_merge($dnl['users'], $fnl['users']), SORT_REGULAR),
-							'groups'=>array_unique(array_merge($dnl['groups'], $fnl['groups']), SORT_REGULAR)
-						);
 						$docname = $document->getName();
 
 						$controller = Controller::factory('RemoveDocument', array('dms'=>$dms, 'user'=>$user));
@@ -522,22 +548,14 @@ switch($command) {
 						$controller->setParam('fulltextservice', $fulltextservice);
 						if($controller->run()) {
 							if ($notifier){
-								$subject = "document_deleted_email_subject";
-								$message = "document_deleted_email_body";
-								$params = array();
-								$params['name'] = $docname;
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['username'] = $user->getFullName();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-								$notifier->toList($user, $nl["users"], $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-								foreach ($nl["groups"] as $grp) {
-									$notifier->toGroup($user, $grp, $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-								}
+								/* $document still has the data from the just deleted document,
+								 * which is just enough to send the email.
+								 */
+								$notifier->sendDeleteDocumentMail($document, $user);
 							}
 
 							header('Content-Type: application/json');
-							echo json_encode(array('success'=>true, 'message'=>'', 'data'=>''));
+							echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_deleted'), 'data'=>''));
 							add_log_line();
 						} else {
 							header('Content-Type: application/json');
@@ -557,64 +575,78 @@ switch($command) {
 
 	case 'tooglelockdocument': /* {{{ */
 		if($user) {
-			$document = $dms->getDocument($_REQUEST['id']);
-			if($document) {
-				if ($document->getAccessMode($user) >= M_READWRITE) {
-					if ($document->isLocked()) {
-						$lockingUser = $document->getLockingUser();
-						if (($lockingUser->getID() == $user->getID()) || ($document->getAccessMode($user) == M_ALL)) {
-							if (!$document->setLocked(false)) {
-								header('Content-Type: application/json');
-								echo json_encode(array('success'=>false, 'message'=>'Error unlocking document', 'data'=>''));
+			if(checkFormKey('tooglelockdocument', 'GET')) {
+				$document = $dms->getDocument($_REQUEST['id']);
+				if($document) {
+					if ($document->getAccessMode($user) >= M_READWRITE) {
+						if ($document->isLocked()) {
+							$lockingUser = $document->getLockingUser();
+							if (($lockingUser->getID() == $user->getID()) || ($document->getAccessMode($user) == M_ALL)) {
+								if (!$document->setLocked(false)) {
+									header('Content-Type: application/json');
+									echo json_encode(array('success'=>false, 'message'=>'Error unlocking document', 'data'=>''));
+								} else {
+									header('Content-Type: application/json');
+									echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_unlocked'), 'data'=>''));
+								}
 							} else {
 								header('Content-Type: application/json');
-								echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_unlocked'), 'data'=>''));
+								echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
 							}
 						} else {
-							header('Content-Type: application/json');
-							echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
+							if (!$document->setLocked($user)) {
+								header('Content-Type: application/json');
+								echo json_encode(array('success'=>false, 'message'=>'Error locking document', 'data'=>''));
+							} else {
+								header('Content-Type: application/json');
+								echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_locked'), 'data'=>''));
+								add_log_line();
+							}
 						}
 					} else {
-						if (!$document->setLocked($user)) {
-							header('Content-Type: application/json');
-							echo json_encode(array('success'=>false, 'message'=>'Error locking document', 'data'=>''));
-						} else {
-							header('Content-Type: application/json');
-							echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_locked'), 'data'=>''));
-							add_log_line();
-						}
+						header('Content-Type: application/json');
+						echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
 					}
 				} else {
 					header('Content-Type: application/json');
-					echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
+					echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_doc_id'), 'data'=>''));
 				}
 			} else {
 				header('Content-Type: application/json');
-				echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_doc_id'), 'data'=>''));
+				echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_request_token'), 'data'=>''));
 			}
 		}
 		break; /* }}} */
 
 	case 'setdocumentname': /* {{{ */
-		if(1||$user) {
-			$document = $dms->getDocument($_REQUEST['id']);
-			if($document) {
-				if ($document->getAccessMode($user) >= M_READWRITE) {
-					if (!$document->setName($_REQUEST['name'])) {
-						header('Content-Type: application/json');
-						echo json_encode(array('success'=>false, 'message'=>'Error setting name', 'data'=>''));
+		if($user) {
+			if(checkFormKey('setdocumentname')) {
+				$document = $dms->getDocument($_REQUEST['id']);
+				if($document) {
+					if ($document->getAccessMode($user) >= M_READWRITE) {
+						$oldname = $document->getName();
+						if (!$document->setName($_REQUEST['name'])) {
+							header('Content-Type: application/json');
+							echo json_encode(array('success'=>false, 'message'=>'Error setting name', 'data'=>''));
+						} else {
+							if($notifier) {
+								$notifier->sendChangedNameMail($document, $user, $oldname);
+							}
+							header('Content-Type: application/json');
+							echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_name_changed'), 'data'=>''));
+							add_log_line();
+						}
 					} else {
 						header('Content-Type: application/json');
-						echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_name_changed'), 'data'=>''));
-						add_log_line();
+						echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
 					}
 				} else {
 					header('Content-Type: application/json');
-					echo json_encode(array('success'=>false, 'message'=>getMLText('access_denied'), 'data'=>''));
+					echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_doc_id'), 'data'=>''));
 				}
 			} else {
 				header('Content-Type: application/json');
-				echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_doc_id'), 'data'=>''));
+				echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_request_token'), 'data'=>''));
 			}
 		}
 		break; /* }}} */
@@ -726,10 +758,14 @@ switch($command) {
 						$mreviewers = getMandatoryReviewers($folder, $user);
 						if($mreviewers['i'])
 							$reviewers['i'] = array_merge($reviewers['i'], $mreviewers['i']);
+						if($mreviewers['g'])
+							$reviewers['g'] = array_merge($reviewers['g'], $mreviewers['g']);
 					}
 					$mapprovers = getMandatoryApprovers($folder, $user);
 					if($mapprovers['i'])
 						$approvers['i'] = array_merge($approvers['i'], $mapprovers['i']);
+					if($mapprovers['g'])
+						$approvers['g'] = array_merge($approvers['g'], $mapprovers['g']);
 
 				} elseif($settings->_workflowMode == 'advanced') {
 					$workflow = $user->getMandatoryWorkflow();
@@ -781,106 +817,7 @@ switch($command) {
 				} else {
 					// Send notification to subscribers of folder.
 					if($notifier) {
-						$fnl = $folder->getNotifyList();
-						$dnl = $document->getNotifyList();
-						$nl = array(
-							'users'=>array_unique(array_merge($dnl['users'], $fnl['users']), SORT_REGULAR),
-							'groups'=>array_unique(array_merge($dnl['groups'], $fnl['groups']), SORT_REGULAR)
-						);
-
-						$subject = "new_document_email_subject";
-						$message = "new_document_email_body";
-						$params = array();
-						$params['name'] = $name;
-						$params['folder_name'] = $folder->getName();
-						$params['folder_path'] = $folder->getFolderPathPlain();
-						$params['username'] = $user->getFullName();
-						$params['comment'] = '';
-						$params['version_comment'] = '';
-						$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-						$params['sitename'] = $settings->_siteName;
-						$params['http_root'] = $settings->_httpRoot;
-						$notifier->toList($user, $nl["users"], $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-						foreach ($nl["groups"] as $grp) {
-							$notifier->toGroup($user, $grp, $subject, $message, $params, SeedDMS_NotificationService::RECV_NOTIFICATION);
-						}
-
-						/* Get workflow from controller in case it was modified in a hook */
-						$workflow = $controller->getParam('workflow');
-						if($workflow && $settings->_enableNotificationWorkflow) {
-							$subject = "request_workflow_action_email_subject";
-							$message = "request_workflow_action_email_body";
-							$params = array();
-							$params['name'] = $document->getName();
-							$params['version'] = 1;
-							$params['workflow'] = $workflow->getName();
-							$params['folder_path'] = $folder->getFolderPathPlain();
-							$params['current_state'] = $workflow->getInitState()->getName();
-							$params['username'] = $user->getFullName();
-							$params['sitename'] = $settings->_siteName;
-							$params['http_root'] = $settings->_httpRoot;
-							$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-
-							foreach($workflow->getNextTransitions($workflow->getInitState()) as $ntransition) {
-								foreach($ntransition->getUsers() as $tuser) {
-									$notifier->toIndividual($user, $tuser->getUser(), $subject, $message, $params, SeedDMS_NotificationService::RECV_WORKFLOW);
-								}
-								foreach($ntransition->getGroups() as $tuser) {
-									$notifier->toGroup($user, $tuser->getGroup(), $subject, $message, $params, SeedDMS_NotificationService::RECV_WORKFLOW);
-								}
-							}
-						}
-
-						if($settings->_enableNotificationAppRev) {
-							/* Reviewers and approvers will be informed about the new document */
-							/* Get reviewers and approvers from controller in case it was
-							 * modified in a hook
-							 */
-							$reviewers = $controller->getParam('reviewers');
-							$approvers = $controller->getParam('approvers');
-							if($reviewers['i'] || $reviewers['g']) {
-								$subject = "review_request_email_subject";
-								$message = "review_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = 1;
-								$params['comment'] = '';
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-
-								foreach($reviewers['i'] as $reviewerid) {
-									$notifier->toIndividual($user, $dms->getUser($reviewerid), $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
-								}
-								foreach($reviewers['g'] as $reviewergrpid) {
-									$notifier->toGroup($user, $dms->getGroup($reviewergrpid), $subject, $message, $params, $params, SeedDMS_NotificationService::RECV_REVIEWER);
-								}
-							}
-
-							elseif($approvers['i'] || $approvers['g']) {
-								$subject = "approval_request_email_subject";
-								$message = "approval_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = 1;
-								$params['comment'] = '';
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-
-								foreach($approvers['i'] as $approverid) {
-									$notifier->toIndividual($user, $dms->getUser($approverid), $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
-								}
-								foreach($approvers['g'] as $approvergrpid) {
-									$notifier->toGroup($user, $dms->getGroup($approvergrpid), $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
-								}
-							}
-						}
-
+						$notifier->sendNewDocumentMail($document, $user);
 					}
 				}
 				header('Content-Type: application/json');
@@ -893,7 +830,87 @@ switch($command) {
 		}
 		break; /* }}} */
 
-	case 'indexdocument': /* {{{ */
+	case 'addfile': /* {{{ */
+		if($user) {
+			if(checkFormKey('addfile')) {
+				if (!isset($_POST["documentid"]) || !is_numeric($_POST["documentid"]) || intval($_POST["documentid"])<1) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("invalid_doc_id")));
+					exit;
+				}
+
+				$documentid = $_POST["documentid"];
+				$document = $dms->getDocument($documentid);
+
+				if (!is_object($document)) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("invalid_doc_id")));
+					exit;
+				}
+
+				if ($document->getAccessMode($user, 'addDocumentFile') < M_READWRITE) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("access_denied")));
+					exit;
+				}
+
+				if (!is_uploaded_file($_FILES["userfile"]["tmp_name"]) || $_FILES['userfile']['error']!=0){
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("uploading_failed")));
+					exit;
+				}
+				if ($_FILES["userfile"]["size"]==0) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("uploading_zerosize")));
+					exit;
+				} 
+
+				$maxuploadsize = SeedDMS_Core_File::parse_filesize($settings->_maxUploadSize);
+				if ($maxuploadsize && $_FILES["userfile"]["size"] > $maxuploadsize) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText("uploading_maxsize")));
+					exit;
+				}
+
+				$userfiletmp = $_FILES["userfile"]["tmp_name"];
+				$userfiletype = $_FILES["userfile"]["type"];
+				$userfilename = $_FILES["userfile"]["name"];
+
+				$fileType = ".".pathinfo($userfilename, PATHINFO_EXTENSION);
+
+				if($settings->_overrideMimeType) {
+					$finfo = finfo_open(FILEINFO_MIME_TYPE);
+					$userfiletype = finfo_file($finfo, $userfiletmp);
+				}
+
+				if (!empty($_POST["name"]))
+					$name = $_POST["name"];
+				else
+					$name = utf8_basename($userfilename);
+				$comment = '';
+				$version = 0;
+				$public = false;
+				$res = $document->addDocumentFile($name, $comment, $user, $userfiletmp, 
+					utf8_basename($userfilename),$fileType, $userfiletype, $version, $public);
+				if (is_bool($res) && !$res) {
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>false, 'message'=>getMLText('error_occured'), 'data'=>''));
+				} else {
+					if($notifier) {
+						$notifier->sendNewFileMail($res, $user);
+					}
+					header('Content-Type: application/json');
+					echo json_encode(array('success'=>true, 'message'=>getMLText('splash_document_added'), 'data'=>$document->getID()));
+					add_log_line();
+				}
+			} else {
+				header('Content-Type: application/json');
+				echo json_encode(array('success'=>false, 'message'=>getMLText('invalid_request_token'), 'data'=>''));
+			}
+		}
+		break; /* }}} */
+
+	case 'indexdocument':
 	case 'indexfolder': /* {{{ */
 		if($user && $user->isAdmin()) {
 			if($fulltextservice) {
@@ -915,7 +932,7 @@ switch($command) {
 								if(isset($GLOBALS['SEEDDMS_HOOKS'][$hook])) {
 									foreach($GLOBALS['SEEDDMS_HOOKS'][$hook] as $hookObj) {
 										if (method_exists($hookObj, 'pre'.ucfirst($hook))) {
-											$ires = $hookObj->preIndexDocument(null, $object, $idoc);
+											$ires = $hookObj->{'pre'.ucfirst($hook)}(null, $object, $idoc);
 										}
 									}
 								}
