@@ -127,39 +127,25 @@ foreach ($pIndRev as $p) {
 				// Proposed reviewer is not a current reviewer, so add as a new
 				// reviewer.
 				$res = $content->addIndReviewer($docAccess["users"][$accessIndex["i"][$p]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res > 0:
 						// Send an email notification to the new reviewer.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "review_request_email_subject";
-								$message = "review_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-								
-								$notifier->toIndividual($user, $docAccess["users"][$accessIndex["i"][$p]], $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
+								$notifier->sendAddReviewMail($content, $user, $docAccess["users"][$accessIndex["i"][$p]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_assigned"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 			else {
@@ -193,39 +179,25 @@ if (count($reviewIndex["i"]) > 0) {
 			}
 			else {
 				$res = $content->delIndReviewer($docAccess["users"][$accessIndex["i"][$rx]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res === 0:
 						// Send an email notification to the reviewer.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "review_deletion_email_subject";
-								$message = "review_deletion_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-								
-								$notifier->toIndividual($user, $docAccess["users"][$accessIndex["i"][$rx]], $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
+								$notifier->sendDeleteReviewMail($content, $user, $docAccess["users"][$accessIndex["i"][$rx]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_removed"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 		}
@@ -239,39 +211,25 @@ foreach ($pGrpRev as $p) {
 				// Proposed reviewer is not a current reviewer, so add as a new
 				// reviewer.
 				$res = $content->addGrpReviewer($docAccess["groups"][$accessIndex["g"][$p]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res > 0:
 						// Send an email notification to the new reviewer.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "review_request_email_subject";
-								$message = "review_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-							
-								$notifier->toGroup($user, $docAccess["groups"][$accessIndex["g"][$p]], $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
+								$notifier->sendAddReviewMail($content, $user, $docAccess["groups"][$accessIndex["g"][$p]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_assigned"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 			else {
@@ -297,39 +255,25 @@ if (count($reviewIndex["g"]) > 0) {
 			}
 			else {
 				$res = $content->delGrpReviewer($docAccess["groups"][$accessIndex["g"][$rx]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res === 0:
 						// Send an email notification to the review group.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "review_deletion_email_subject";
-								$message = "review_deletion_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-							
-								$notifier->toGroup($user, $docAccess["groups"][$accessIndex["g"][$rx]], $subject, $message, $params, SeedDMS_NotificationService::RECV_REVIEWER);
+								$notifier->sendDeleteReviewMail($content, $user, $docAccess["groups"][$accessIndex["g"][$rx]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_removed"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 		}
@@ -359,39 +303,29 @@ foreach ($pIndApp as $p) {
 				// Proposed approver is not a current approver, so add as a new
 				// approver.
 				$res = $content->addIndApprover($docAccess["users"][$accessIndex["i"][$p]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res > 0:
 						// Send an email notification to the new approver.
 						if($settings->_enableNotificationAppRev) {
+							/* Send notification only if document is currently not in review state,
+							 * because then the approvers will be informed anyway when review state
+							 * is left and approval state is entered.
+							 */
 							if ($overallStatus["status"]!=0 && $notifier) {
-								$subject = "approval_request_email_subject";
-								$message = "approval_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-
-								$notifier->toIndividual($user, $docAccess["users"][$accessIndex["i"][$p]], $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
+								$notifier->sendAddApprovalMail($content, $user, $docAccess["users"][$accessIndex["i"][$p]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_assigned"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 			else {
@@ -417,39 +351,25 @@ if (count($approvalIndex["i"]) > 0) {
 			}
 			else {
 				$res = $content->delIndApprover($docAccess["users"][$accessIndex["i"][$rx]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res === 0:
 						// Send an email notification to the approver.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "approval_deletion_email_subject";
-								$message = "approval_deletion_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-
-								$notifier->toIndividual($user, $docAccess["users"][$accessIndex["i"][$rx]], $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
+								$notifier->sendDeleteApprovalMail($content, $user, $docAccess["users"][$accessIndex["i"][$rx]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("reviewer_already_removed"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 		}
@@ -463,39 +383,29 @@ foreach ($pGrpApp as $p) {
 				// Proposed approver is not a current approver, so add as a new
 				// approver.
 				$res = $content->addGrpApprover($docAccess["groups"][$accessIndex["g"][$p]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res > 0:
 						// Send an email notification to the new approver.
 						if($settings->_enableNotificationAppRev) {
+							/* Send notification only if document is currently not in review state,
+							 * because then the approvers will be informed anyway when review state
+							 * is left and approval state is entered.
+							 */
 							if ($overallStatus["status"]!=0 && $notifier) {
-								$subject = "approval_request_email_subject";
-								$message = "approval_request_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-
-								$notifier->toGroup($user, $docAccess["groups"][$accessIndex["g"][$p]], $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
+								$notifier->sendAddApprovalMail($content, $user, $docAccess["groups"][$accessIndex["g"][$p]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("approver_already_assigned"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 			else {
@@ -521,39 +431,25 @@ if (count($approvalIndex["g"]) > 0) {
 			}
 			else {
 				$res = $content->delGrpApprover($docAccess["groups"][$accessIndex["g"][$rx]], $user);
-				switch ($res) {
-					case 0:
+				switch (true) {
+					case $res === 0:
 						// Send an email notification to the approval group.
 						if($settings->_enableNotificationAppRev) {
 							if ($notifier) {
-								$subject = "approval_deletion_email_subject";
-								$message = "approval_deletion_email_body";
-								$params = array();
-								$params['name'] = $document->getName();
-								$params['folder_path'] = $folder->getFolderPathPlain();
-								$params['version'] = $content->getVersion();
-								$params['comment'] = $content->getComment();
-								$params['username'] = $user->getFullName();
-								$params['url'] = getBaseUrl().$settings->_httpRoot."out/out.ViewDocument.php?documentid=".$document->getID();
-								$params['sitename'] = $settings->_siteName;
-								$params['http_root'] = $settings->_httpRoot;
-							
-								$notifier->toGroup($user, $docAccess["groups"][$accessIndex["g"][$rx]], $subject, $message, $params, SeedDMS_NotificationService::RECV_APPROVER);
+								$notifier->sendDeleteApprovalMail($content, $user, $docAccess["groups"][$accessIndex["g"][$rx]]);
 							}
 						}
 						break;
-					case -1:
+					case $res === -1:
+					case $res === false:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("internal_error"));
 						break;
-					case -2:
+					case $res === -2:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
 						break;
-					case -3:
+					case $res === -3:
 						UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("approver_already_removed"));
 						break;
-					case -4:
-						// email error
-						break;
 				}
 			}
 		}
