@@ -51,7 +51,8 @@ if (isset($_GET["navBar"])) {
 
 $accessop = new SeedDMS_AccessOperation($dms, null, $user, $settings);
 
-if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext') || !empty($_GET["fullsearch"])) && $settings->_enableFullSearch) {
+$fullsearch = ((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext') || !empty($_GET["fullsearch"])) && $settings->_enableFullSearch;
+if($fullsearch) {
 // Search in Fulltext {{{
 	if (isset($_GET["query"]) && is_string($_GET["query"])) {
 		$query = $_GET["query"];
@@ -63,16 +64,10 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 	// category
 	$categories = array();
 	$categorynames = array();
+	$category = array();
 	if(isset($_GET['category']) && $_GET['category']) {
-		foreach($_GET['category'] as $catname) {
-			if($catname) {
-				$cat = $dms->getDocumentCategoryByName($catname);
-				$categories[] = $cat;
-				$categorynames[] = $cat->getName();
-			}
-		}
-	} elseif(isset($_GET['categoryids']) && $_GET['categoryids']) {
-		foreach($_GET['categoryids'] as $catid) {
+		$category = $_GET['category'];
+		foreach($_GET['category'] as $catid) {
 			if($catid) {
 				$cat = $dms->getDocumentCategory($catid);
 				$categories[] = $cat;
@@ -104,20 +99,21 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 	// Check to see if the search has been restricted to a particular
 	// document owner.
 	$owner = [];
+	$ownernames = [];
 	if (isset($_GET["owner"])) {
+		$owner = $_GET['owner'];
 		if (!is_array($_GET['owner'])) {
-			if(!empty($_GET['owner']) && $o = $dms->getUserByLogin($_GET['owner']))
-				$owner[] = $o->getLogin();
+			if(!empty($_GET['owner']) && $o = $dms->getUser($_GET['owner']))
+				$ownernames[] = $o->getLogin();
 			else
 				UI::exitError(getMLText("search"),getMLText("unknown_owner"));
 		} else {
 			foreach($_GET["owner"] as $l) {
-				if($l && $o = $dms->getUserByLogin($l))
-					$owner[] = $o->getLogin();
+				if($l && $o = $dms->getUser($l))
+					$ownernames[] = $o->getLogin();
 			}
 		}
 	}
-
 	// Check to see if the search has been restricted to a particular
 	// mimetype.
 	$mimetype = [];
@@ -134,34 +130,22 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 	}
 
 	// status
-	$status = array();
-	if (isset($_GET["pendingReview"])){
-		$status[] = S_DRAFT_REV;
-	}
-	if (isset($_GET["pendingApproval"])){
-		$status[] = S_DRAFT_APP;
-	}
-	if (isset($_GET["inWorkflow"])){
-		$status[] = S_IN_WORKFLOW;
-	}
-	if (isset($_GET["released"])){
-		$status[] = S_RELEASED;
-	}
-	if (isset($_GET["rejected"])){
-		$status[] = S_REJECTED;
-	}
-	if (isset($_GET["obsolete"])){
-		$status[] = S_OBSOLETE;
-	}
-	if (isset($_GET["expired"])){
-		$status[] = S_EXPIRED;
-	}
+	if(isset($_GET['status']))
+		$status = $_GET['status'];
+	else
+		$status = array();
+
+	// record_type
+	if(isset($_GET['record_type']))
+		$record_type = $_GET['record_type'];
+	else
+		$record_type = array();
 
 	// Check to see if the search has been restricted to a particular sub-tree in
 	// the folder hierarchy.
 	$startFolder = null;
-	if (isset($_GET["targetid"]) && is_numeric($_GET["targetid"]) && $_GET["targetid"]>0) {
-		$targetid = $_GET["targetid"];
+	if (isset($_GET["folderfullsearchid"]) && is_numeric($_GET["folderfullsearchid"]) && $_GET["folderfullsearchid"]>0) {
+		$targetid = $_GET["folderfullsearchid"];
 		$startFolder = $dms->getFolder($targetid);
 		if (!is_object($startFolder)) {
 			UI::exitError(getMLText("search"),getMLText("invalid_folder_id"));
@@ -188,7 +172,7 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 		$index = $fulltextservice->Indexer();
 		if($index) {
 			$lucenesearch = $fulltextservice->Search();
-			$searchresult = $lucenesearch->search($query, array('owner'=>$owner, 'status'=>$status, 'category'=>$categorynames, 'user'=>$user->isAdmin() ? [] : [$user->getLogin()], 'mimetype'=>$mimetype, 'startFolder'=>$startFolder, 'rootFolder'=>$rootFolder), ($pageNumber == 'all' ? array() : array('limit'=>$limit, 'offset'=>$limit * ($pageNumber-1))));
+			$searchresult = $lucenesearch->search($query, array('record_type'=>$record_type, 'owner'=>$ownernames, 'status'=>$status, 'category'=>$categorynames, 'user'=>$user->isAdmin() ? [] : [$user->getLogin()], 'mimetype'=>$mimetype, 'startFolder'=>$startFolder, 'rootFolder'=>$rootFolder), ($pageNumber == 'all' ? array() : array('limit'=>$limit, 'offset'=>$limit * ($pageNumber-1))));
 			if($searchresult === false) {
 				$session->setSplashMsg(array('type'=>'error', 'msg'=>getMLText('splash_invalid_searchterm')));
 				$dcount = 0;
@@ -221,6 +205,10 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 							}
 						}
 					}
+					if(isset($facets['record_type'])) {
+						$fcount = isset($facets['record_type']['folder']) ? $facets['record_type']['folder'] : 0;
+						$dcount = isset($facets['record_type']['document']) ? $facets['record_type']['document'] : 0 ;
+					}
 				}
 				if($pageNumber != 'all' && $searchresult['count'] > $limit) {
 					$totalPages = (int) ($searchresult['count']/$limit);
@@ -313,105 +301,81 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 	$owner = array();
 	$ownerobjs = array();
 	if (isset($_GET["owner"])) {
+		$owner = $_GET['owner'];
 		if (!is_array($_GET['owner'])) {
-			if(!empty($_GET['owner']) && $o = $dms->getUserByLogin($_GET['owner'])) {
+			if(!empty($_GET['owner']) && $o = $dms->getUser($_GET['owner'])) {
 				$ownerobjs[] = $o;
-				$owner = $o->getLogin();
 			} else
 				UI::exitError(getMLText("search"),getMLText("unknown_owner"));
 		} else {
 			foreach($_GET["owner"] as $l) {
-				if($o = $dms->getUserByLogin($l)) {
+				if($o = $dms->getUser($l)) {
 					$ownerobjs[] = $o;
-					$owner[] = $o->getLogin();
 				}
 			}
 		}
 	}
 
-	// Is the search restricted to documents created between two specific dates?
-	$startdate = array();
-	$stopdate = array();
-	if (isset($_GET["creationdate"]) && $_GET["creationdate"]!=null) {
-		$creationdate = true;
-	} else {
-		$creationdate = false;
+	/* Creation date {{{ */
+	$createstartdate = array();
+	$createenddate = array();
+	if(!empty($_GET["createstart"])) {
+		$createstartts = makeTsFromDate($_GET["createstart"]);
+		$createstartdate = array('year'=>(int)date('Y', $createstartts), 'month'=>(int)date('m', $createstartts), 'day'=>(int)date('d', $createstartts), 'hour'=>0, 'minute'=>0, 'second'=>0);
 	}
-
-	if(isset($_GET["createstart"])) {
-		$tmp = explode("-", $_GET["createstart"]);
-		$startdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>0, 'minute'=>0, 'second'=>0);
-	} else {
-		if(isset($_GET["createstartyear"]))
-			$startdate = array('year'=>$_GET["createstartyear"], 'month'=>$_GET["createstartmonth"], 'day'=>$_GET["createstartday"], 'hour'=>0, 'minute'=>0, 'second'=>0);
-	}
-	if ($startdate && !checkdate($startdate['month'], $startdate['day'], $startdate['year'])) {
+	if ($createstartdate && !checkdate($createstartdate['month'], $createstartdate['day'], $createstartdate['year'])) {
 		UI::exitError(getMLText("search"),getMLText("invalid_create_date_end"));
 	}
-	if(isset($_GET["createend"])) {
-		$tmp = explode("-", $_GET["createend"]);
-		$stopdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>23, 'minute'=>59, 'second'=>59);
-	} else {
-		if(isset($_GET["createendyear"]))
-			$stopdate = array('year'=>$_GET["createendyear"], 'month'=>$_GET["createendmonth"], 'day'=>$_GET["createendday"], 'hour'=>23, 'minute'=>59, 'second'=>59);
+	if(!empty($_GET["createend"])) {
+		$createendts = makeTsFromDate($_GET["createend"]);
+		$createenddate = array('year'=>(int)date('Y', $createendts), 'month'=>(int)date('m', $createendts), 'day'=>(int)date('d', $createendts), 'hour'=>23, 'minute'=>59, 'second'=>59);
 	}
-	if ($stopdate && !checkdate($stopdate['month'], $stopdate['day'], $stopdate['year'])) {
+	if ($createenddate && !checkdate($createenddate['month'], $createenddate['day'], $createenddate['year'])) {
 		UI::exitError(getMLText("search"),getMLText("invalid_create_date_end"));
 	}
+	/* }}} */
 
+	/* Status date {{{ */
 	$statusstartdate = array();
-	$statusstopdate = array();
-	if (isset($_GET["statusdate"]) && $_GET["statusdate"]!=null) {
-		$statusdate = true;
-	} else {
-		$statusdate = false;
+	$statusenddate = array();
+	if(!empty($_GET["statusdatestart"])) {
+		$statusstartts = makeTsFromDate($_GET["statusdatestart"]);
+		$statusstartdate = array('year'=>(int)date('Y', $statusstartts), 'month'=>(int)date('m', $statusstartts), 'day'=>(int)date('d', $statusstartts), 'hour'=>0, 'minute'=>0, 'second'=>0);
 	}
-
-	if(isset($_GET["statusstart"])) {
-		$tmp = explode("-", $_GET["statusstart"]);
-		$statusstartdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>0, 'minute'=>0, 'second'=>0);
+	if ($statusstartdate && !checkdate($statusstartdate['month'], $statusstartdate['day'], $statusstartdate['year'])) {
+		UI::exitError(getMLText("search"),getMLText("invalid_status_date_start"));
 	}
-	if ($statusstartdate && !checkdate($statusstartdate['month'], $startdate['day'], $startdate['year'])) {
-		UI::exitError(getMLText("search"),getMLText("invalid_status_date_end"));
+	if(!empty($_GET["statusdateend"])) {
+		$statusendts = makeTsFromDate($_GET["statusdateend"]);
+		$statusenddate = array('year'=>(int)date('Y', $statusendts), 'month'=>(int)date('m', $statusendts), 'day'=>(int)date('d', $statusendts), 'hour'=>23, 'minute'=>59, 'second'=>59);
 	}
-	if(isset($_GET["statusend"])) {
-		$tmp = explode("-", $_GET["statusend"]);
-		$statusstopdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>23, 'minute'=>59, 'second'=>59);
-	}
-	if ($statusstopdate && !checkdate($statusstopdate['month'], $stopdate['day'], $stopdate['year'])) {
+	if ($statusenddate && !checkdate($statusenddate['month'], $statusenddate['day'], $statusenddate['year'])) {
 		UI::exitError(getMLText("search"),getMLText("invalid_status_date_end"));
 	}
+	/* }}} */
 
+	/* Expiration date {{{ */
 	$expstartdate = array();
-	$expstopdate = array();
-	if (isset($_GET["expirationdate"]) && $_GET["expirationdate"]!=null) {
-		$expirationdate = true;
-	} else {
-		$expirationdate = false;
-	}
-
-	if(isset($_GET["expirationstart"]) && $_GET["expirationstart"]) {
-		$tmp = explode("-", $_GET["expirationstart"]);
-		$expstartdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>0, 'minute'=>0, 'second'=>0);
+	$expenddate = array();
+	if(!empty($_GET["expirationstart"])) {
+		$expstartts = makeTsFromDate($_GET["expirationstart"]);
+		$expstartdate = array('year'=>(int)date('Y', $expstartts), 'month'=>(int)date('m', $expstartts), 'day'=>(int)date('d', $expstartts), 'hour'=>0, 'minute'=>0, 'second'=>0);
 		if (!checkdate($expstartdate['month'], $expstartdate['day'], $expstartdate['year'])) {
 			UI::exitError(getMLText("search"),getMLText("invalid_expiration_date_start"));
 		}
-	} else {
-//		$expstartdate = array('year'=>$_GET["expirationstartyear"], 'month'=>$_GET["expirationstartmonth"], 'day'=>$_GET["expirationstartday"], 'hour'=>0, 'minute'=>0, 'second'=>0);
-		$expstartdate = array();
 	}
-	if(isset($_GET["expirationend"]) && $_GET["expirationend"]) {
-		$tmp = explode("-", $_GET["expirationend"]);
-		$expstopdate = array('year'=>(int)$tmp[0], 'month'=>(int)$tmp[1], 'day'=>(int)$tmp[2], 'hour'=>0, 'minute'=>0, 'second'=>0);
-		if (!checkdate($expstopdate['month'], $expstopdate['day'], $expstopdate['year'])) {
+	if(!empty($_GET["expirationend"])) {
+		$expendts = makeTsFromDate($_GET["expirationend"]);
+		$expenddate = array('year'=>(int)date('Y', $expendts), 'month'=>(int)date('m', $expendts), 'day'=>(int)date('d', $expendts), 'hour'=>23, 'minute'=>59, 'second'=>59);
+		if (!checkdate($expenddate['month'], $expenddate['day'], $expenddate['year'])) {
 			UI::exitError(getMLText("search"),getMLText("invalid_expiration_date_end"));
 		}
-	} else {
-		//$expstopdate = array('year'=>$_GET["expirationendyear"], 'month'=>$_GET["expirationendmonth"], 'day'=>$_GET["expirationendday"], 'hour'=>23, 'minute'=>59, 'second'=>59);
-		$expstopdate = array();
 	}
+	/* }}} */
 
 	// status
+	$status = isset($_GET['status']) ? $_GET['status'] : array();
+	/*
 	$status = array();
 	if (isset($_GET["pendingReview"])){
 		$status[] = S_DRAFT_REV;
@@ -434,6 +398,7 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 	if (isset($_GET["expired"])){
 		$status[] = S_EXPIRED;
 	}
+	 */
 
 	/* Do not search for folders if result shall be filtered by status.
 	 * If this is not done, unexplainable results will be delivered.
@@ -446,13 +411,12 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 
 	// category
 	$categories = array();
-	$categorynames = array();
+	$category = [];
 	if(isset($_GET['category']) && $_GET['category']) {
-		foreach($_GET['category'] as $catname) {
-			if($catname) {
-				$cat = $dms->getDocumentCategoryByName($catname);
+		$category = $_GET['category'];
+		foreach($_GET['category'] as $catid) {
+			if($cat = $dms->getDocumentCategory($catid)) {
 				$categories[] = $cat;
-				$categorynames[] = $cat->getName();
 			}
 		}
 	}
@@ -513,17 +477,17 @@ if(((!isset($_GET["fullsearch"]) && $settings->_defaultSearchMethod == 'fulltext
 		'startFolder'=>$startFolder,
 		'owner'=>$ownerobjs,
 		'status'=>$status,
-		'creationstartdate'=>$creationdate ? $startdate : array(),
-		'creationenddate'=>$creationdate ? $stopdate : array(),
+		'creationstartdate'=>$createstartdate ? $createstartdate : array(),
+		'creationenddate'=>$createenddate ? $createenddate : array(),
 		'modificationstartdate'=>array(),
 		'modificationenddate'=>array(),
 		'categories'=>$categories,
 		'attributes'=>$attributes,
 		'mode'=>$resultmode,
-		'expirationstartdate'=>$expirationdate ? $expstartdate : array(),
-		'expirationenddate'=>$expirationdate ? $expstopdate : array(),
-		'statusstartdate'=>$statusdate ? $statusstartdate : array(),
-		'statusenddate'=>$statusdate ? $statusstopdate : array(),
+		'expirationstartdate'=>$expstartdate ? $expstartdate : array(),
+		'expirationenddate'=>$expenddate ? $expenddate : array(),
+		'statusstartdate'=>$statusstartdate ? $statusstartdate : array(),
+		'statusenddate'=>$statusenddate ? $statusenddate : array(),
 		'orderby'=>$orderby
 	));
 	$total = $resArr['totalDocs'] + $resArr['totalFolders'];
@@ -585,7 +549,7 @@ if($settings->_showSingleSearchHit && count($entries) == 1) {
 		$view->setParam('total', $total);
 		$view->setParam('totaldocs', $dcount /*resArr['totalDocs']*/);
 		$view->setParam('totalfolders', $fcount /*resArr['totalFolders']*/);
-		$view->setParam('fullsearch', (!empty($_GET["fullsearch"]) && $settings->_enableFullSearch) ? true : false);
+		$view->setParam('fullsearch', $fullsearch);
 		$view->setParam('mode', isset($mode) ? $mode : '');
 		$view->setParam('orderby', isset($orderby) ? $orderby : '');
 		$view->setParam('defaultsearchmethod', !empty($_GET["fullsearch"]) || $settings->_defaultSearchMethod);
@@ -593,18 +557,19 @@ if($settings->_showSingleSearchHit && count($entries) == 1) {
 		$view->setParam('searchin', isset($searchin) ? $searchin : array());
 		$view->setParam('startfolder', isset($startFolder) ? $startFolder : null);
 		$view->setParam('owner', $owner);
-		$view->setParam('startdate', isset($startdate) ? $startdate : array());
-		$view->setParam('stopdate', isset($stopdate) ? $stopdate : array());
-		$view->setParam('expstartdate', isset($expstartdate) ? $expstartdate : array());
-		$view->setParam('expstopdate', isset($expstopdate) ? $expstopdate : array());
-		$view->setParam('statusstartdate', isset($statusstartdate) ? $statusstartdate : array());
-		$view->setParam('statusstopdate', isset($statusstopdate) ? $statusstopdate : array());
+		$view->setParam('createstartdate', !empty($createstartdate) ? getReadableDate($createstartts) : '');
+		$view->setParam('createenddate', !empty($createenddate) ? getReadableDate($createendts) : '');
+		$view->setParam('expstartdate', !empty($expstartdate) ? getReadableDate($expstartts) : '');
+		$view->setParam('expenddate', !empty($expenddate) ? getReadableDate($expendts) : '');
+		$view->setParam('statusstartdate', !empty($statusstartdate) ? getReadableDate($statusstartts) : '');
+		$view->setParam('statusenddate', !empty($statusenddate) ? getReadableDate($statusendts) : '');
 		$view->setParam('creationdate', isset($creationdate) ? $creationdate : '');
 		$view->setParam('expirationdate', isset($expirationdate) ? $expirationdate: '');
 		$view->setParam('statusdate', isset($statusdate) ? $statusdate: '');
-		$view->setParam('status', isset($status) ? $status : array());
+		$view->setParam('status', $status);
+		$view->setParam('recordtype', isset($record_type) ? $record_type : null);
 		$view->setParam('categories', isset($categories) ? $categories : '');
-		$view->setParam('category', isset($categorynames) ? $categorynames : '');
+		$view->setParam('category', $category);
 		$view->setParam('mimetype', isset($mimetype) ? $mimetype : '');
 		$view->setParam('attributes', isset($attributes) ? $attributes : '');
 		$attrdefs = $dms->getAllAttributeDefinitions(array(SeedDMS_Core_AttributeDefinition::objtype_document, SeedDMS_Core_AttributeDefinition::objtype_documentcontent, SeedDMS_Core_AttributeDefinition::objtype_folder, SeedDMS_Core_AttributeDefinition::objtype_all));
