@@ -21,6 +21,7 @@
 
 if(!isset($settings))
 	require_once("../inc/inc.Settings.php");
+require_once("inc/inc.LogInit.php");
 require_once("inc/inc.Utils.php");
 require_once("inc/inc.Language.php");
 require_once("inc/inc.Init.php");
@@ -28,7 +29,6 @@ require_once("inc/inc.Extension.php");
 require_once("inc/inc.DBInit.php");
 require_once("inc/inc.ClassUI.php");
 require_once("inc/inc.Authentication.php");
-require_once("inc/inc.ClassAccessOperation.php");
 
 $tmp = explode('.', basename($_SERVER['SCRIPT_FILENAME']));
 $view = UI::factory($theme, $tmp[1], array('dms'=>$dms, 'user'=>$user));
