@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Class which outputs the html page for AddDocument view
@@ -29,7 +29,7 @@ require_once("class.Bootstrap.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_AddDocument extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_AddDocument extends SeedDMS_Theme_Style {
 
 	function js() { /* {{{ */
 		$dropfolderdir = $this->params['dropfolderdir'];
@@ -39,6 +39,7 @@ class SeedDMS_View_AddDocument extends SeedDMS_Bootstrap_Style {
 		$enablemultiupload = $this->params['enablemultiupload'];
 		header('Content-Type: application/javascript; charset=UTF-8');
 
+		parent::jsTranslations(array('js_form_error', 'js_form_errors'));
 		if($enablelargefileupload) {
 			$this->printFineUploaderJs('../op/op.UploadChunks.php', $partitionsize, $maxuploadsize, $enablemultiupload);
 		}
@@ -57,9 +58,11 @@ $(document).ready(function() {
 	/* The fineuploader validation is actually checking all fields that can contain
 	 * a file to be uploaded. First checks if an alternative input field is set,
 	 * second loops through the list of scheduled uploads, checking if at least one
-	 * file will be submitted.
+	 * file will be submitted. param[0] is the fineuploader, param[1] is the
+	 * field from the dropfolder
 	 */
 	jQuery.validator.addMethod("fineuploader", function(value, element, params) {
+console.log(params);
 		if(params[1].val() != '')
 			return true;
 		uploader = params[0];
@@ -73,16 +76,6 @@ $(document).ready(function() {
 	$("#adddocform").validate({
 		debug: false,
 		ignore: ":hidden:not(.do_validate)",
-		invalidHandler: function(e, validator) {
-			noty({
-				text:  (validator.numberOfInvalids() == 1) ? "<?php printMLText("js_form_error");?>".replace('#', validator.numberOfInvalids()) : "<?php printMLText("js_form_errors");?>".replace('#', validator.numberOfInvalids()),
-				type: 'error',
-				dismissQueue: true,
-				layout: 'topRight',
-				theme: 'defaultTheme',
-				timeout: 1500,
-			});
-		},
 <?php
 		if($enablelargefileupload) {
 ?>
@@ -107,10 +100,12 @@ $(document).ready(function() {
 		} else {
 ?>
 			'userfile[]': {
-				alternatives: $('#dropfolderfileadddocform')
+				require_from_group: [1, ".fileupload-group"]
+//				alternatives: $('#dropfolderfileadddocform')
 			},
 			dropfolderfileadddocform: {
-				 alternatives: $("#userfile") //$(".btn-file input")
+				require_from_group: [1, ".fileupload-group"]
+//				alternatives: $("#userfile")
 			}
 <?php
 		}
@@ -165,6 +160,8 @@ $(document).ready(function() {
 		$folderid = $folder->getId();
 
 		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/jquery-validation/jquery.validate.js"></script>'."\n", 'js');
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/jquery-validation/additional-methods.js"></script>'."\n", 'js');
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/styles/validation-default.js"></script>'."\n", 'js');
 		if($enablelargefileupload) {
 			$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/fine-uploader/jquery.fine-uploader.min.js"></script>'."\n", 'js');
 			$this->htmlAddHeader($this->getFineUploaderTemplate(), 'js');
@@ -226,23 +223,25 @@ $(document).ready(function() {
 			getMLText("keywords"),
 				$this->getKeywordChooserHtml('adddocform')
 		);
-		if(!$nodocumentformfields || !in_array('categories', $nodocumentformfields)) {
-		$options = array();
 		$categories = $dms->getDocumentCategories();
-		foreach($categories as $category) {
-			$options[] = array($category->getID(), $category->getName());
-		}
-		$this->formField(
-			getMLText("categories"),
-			array(
-				'element'=>'select',
-				'class'=>'chzn-select',
-				'name'=>'categories[]',
-				'multiple'=>true,
-				'attributes'=>array(array('data-placeholder', getMLText('select_category'), array('data-no_results_text', getMLText('unknown_document_category')))),
-				'options'=>$options
-			)
-		);
+		if($categories) {
+			if(!$nodocumentformfields || !in_array('categories', $nodocumentformfields)) {
+				$options = array();
+				foreach($categories as $category) {
+					$options[] = array($category->getID(), $category->getName());
+				}
+				$this->formField(
+					getMLText("categories"),
+					array(
+						'element'=>'select',
+						'class'=>'chzn-select',
+						'name'=>'categories[]',
+						'multiple'=>true,
+						'attributes'=>array(array('data-placeholder', getMLText('select_category'), array('data-no_results_text', getMLText('unknown_document_category')))),
+						'options'=>$options
+					)
+				);
+			}
 		}
 		if(!$nodocumentformfields || !in_array('sequence', $nodocumentformfields)) {
 			$this->formField(getMLText("sequence"), $this->getSequenceChooser($folder->getDocuments('s')).($orderby != 's' ? "<br />".getMLText('order_by_sequence_off') : ''));
@@ -259,7 +258,7 @@ $(document).ready(function() {
 					'element'=>'input',
 					'type'=>'hidden',
 					'name'=>'sequence',
-					'value'=>$seq,
+					'value'=>(string) $seq,
 				)
 			);
 		}
@@ -334,6 +333,46 @@ $(document).ready(function() {
 		}
 
 		$this->contentContainerEnd();
+		if(!$nodocumentformfields || !in_array('notification', $nodocumentformfields)) {
+			$this->contentSubHeading(getMLText("add_document_notify"));
+			$this->contentContainerStart();
+
+		$options = array();
+		$allUsers = $dms->getAllUsers($sortusersinlist);
+		foreach ($allUsers as $userObj) {
+			if (!$userObj->isGuest() && $folder->getAccessMode($userObj) >= M_READ)
+				$options[] = array($userObj->getID(), htmlspecialchars($userObj->getLogin() . " - " . $userObj->getFullName()));
+		}
+		$this->formField(
+			getMLText("individuals"),
+			array(
+				'element'=>'select',
+				'name'=>'notification_users[]',
+				'class'=>'chzn-select',
+				'attributes'=>array(array('data-placeholder', getMLText('select_ind_notification'))),
+				'multiple'=>true,
+				'options'=>$options
+			)
+		);
+		$options = array();
+		$allGroups = $dms->getAllGroups();
+		foreach ($allGroups as $groupObj) {
+			if ($folder->getGroupAccessMode($groupObj) >= M_READ)
+				$options[] = array($groupObj->getID(), htmlspecialchars($groupObj->getName()));
+		}
+		$this->formField(
+			getMLText("groups"),
+			array(
+				'element'=>'select',
+				'name'=>'notification_groups[]',
+				'class'=>'chzn-select',
+				'attributes'=>array(array('data-placeholder', getMLText('select_grp_notification'))),
+				'multiple'=>true,
+				'options'=>$options
+			)
+		);
+			$this->contentContainerEnd();
+		}
 		$this->columnEnd();
 		$this->columnStart(6);
 		$this->contentSubHeading(getMLText("version_info"));
@@ -360,6 +399,14 @@ $(document).ready(function() {
 				$this->getDropFolderChooserHtml("adddocform", $dropfolderfile)
 			);
 		}
+		if($arr = $this->callHook('addDocumentContentFile')) {
+			foreach($arr as $ar)
+				if(is_array($ar)) {
+					$this->formField($ar[0], $ar[1], isset($ar[2]) ? $ar[2] : null);
+				} elseif(is_string($ar)) {
+					echo $ar;
+				}
+		}
 		if(!$nodocumentformfields || !in_array('version_comment', $nodocumentformfields)) {
 		$this->formField(
 			getMLText("comment_for_current_version"),
@@ -657,46 +704,6 @@ $(document).ready(function() {
 			$this->contentContainerEnd();
 			$this->warningMsg(getMLText("add_doc_reviewer_approver_warning"));
 		}
-		if(!$nodocumentformfields || !in_array('notification', $nodocumentformfields)) {
-			$this->contentSubHeading(getMLText("add_document_notify"));
-			$this->contentContainerStart();
-
-		$options = array();
-		$allUsers = $dms->getAllUsers($sortusersinlist);
-		foreach ($allUsers as $userObj) {
-			if (!$userObj->isGuest() && $folder->getAccessMode($userObj) >= M_READ)
-				$options[] = array($userObj->getID(), htmlspecialchars($userObj->getLogin() . " - " . $userObj->getFullName()));
-		}
-		$this->formField(
-			getMLText("individuals"),
-			array(
-				'element'=>'select',
-				'name'=>'notification_users[]',
-				'class'=>'chzn-select',
-				'attributes'=>array(array('data-placeholder', getMLText('select_ind_notification'))),
-				'multiple'=>true,
-				'options'=>$options
-			)
-		);
-		$options = array();
-		$allGroups = $dms->getAllGroups();
-		foreach ($allGroups as $groupObj) {
-			if ($folder->getGroupAccessMode($groupObj) >= M_READ)
-				$options[] = array($groupObj->getID(), htmlspecialchars($groupObj->getName()));
-		}
-		$this->formField(
-			getMLText("groups"),
-			array(
-				'element'=>'select',
-				'name'=>'notification_groups[]',
-				'class'=>'chzn-select',
-				'attributes'=>array(array('data-placeholder', getMLText('select_grp_notification'))),
-				'multiple'=>true,
-				'options'=>$options
-			)
-		);
-			$this->contentContainerEnd();
-		}
 		$this->columnEnd();
 		$this->rowEnd();
 		$this->formSubmit("<i class=\"fa fa-save\"></i> ".getMLText('add_document'));
