@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Include class to preview documents
@@ -34,7 +34,7 @@ require_once("SeedDMS/Preview.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Theme_Style {
 
 	/**
 	 * Output a single attribute in the document info section
@@ -60,6 +60,7 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 		$converttopdf = $this->params['convertToPdf'];
 		$pdfconverters = $this->params['pdfConverters'];
 		$cachedir = $this->params['cachedir'];
+		$conversionmgr = $this->params['conversionmgr'];
 		$version = $this->params['version'];
 		if(!$showfullpreview)
 			return;
@@ -125,7 +126,10 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 
 		if($converttopdf) {
 			$pdfpreviewer = new SeedDMS_Preview_PdfPreviewer($cachedir, $timeout, $xsendfile);
-			$pdfpreviewer->setConverters($pdfconverters);
+			if($conversionmgr)
+				$pdfpreviewer->setConversionMgr($conversionmgr);
+			else
+				$pdfpreviewer->setConverters($pdfconverters);
 			if($pdfpreviewer->hasConverter($version->getMimeType())) {
 				$this->contentHeading(getMLText("preview_pdf"));
 ?>
@@ -145,7 +149,9 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 		$viewonlinefiletypes = $this->params['viewonlinefiletypes'];
 		$enableversionmodification = $this->params['enableversionmodification'];
 		$cachedir = $this->params['cachedir'];
+		$conversionmgr = $this->params['conversionmgr'];
 		$previewwidthdetail = $this->params['previewWidthDetail'];
+		$previewconverters = $this->params['previewConverters'];
 		$timeout = $this->params['timeout'];
 		$xsendfile = $this->params['xsendfile'];
 
@@ -160,9 +166,9 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 		$this->rowStart();
 		$this->columnStart(4);
 		$this->contentHeading(getMLText("document_infos"));
-		$this->contentContainerStart();
+//		$this->contentContainerStart();
 ?>
-<table class="table-condensed">
+<table class="table table-condensed table-sm">
 <tr>
 <td><?php printMLText("owner");?>:</td>
 <td>
@@ -239,7 +245,7 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 ?>
 </table>
 <?php
-		$this->contentContainerEnd();
+//		$this->contentContainerEnd();
 		$this->preview();
 		$this->columnEnd();
 		$this->columnStart(8);
@@ -261,9 +267,25 @@ class SeedDMS_View_DocumentVersionDetail extends SeedDMS_Bootstrap_Style {
 
 		print "</ul>";
 		$previewer = new SeedDMS_Preview_Previewer($cachedir, $previewwidthdetail, $timeout, $xsendfile);
+		if($conversionmgr)
+			$previewer->setConversionMgr($conversionmgr);
+		else
+			$previewer->setConverters($previewconverters);
 		$previewer->createPreview($version);
+		if ($file_exists) {
+			if ($viewonlinefiletypes && (in_array(strtolower($version->getFileType()), $viewonlinefiletypes) || in_array(strtolower($version->getMimeType()), $viewonlinefiletypes))) {
+				print "<a target=\"_blank\" href=\"../op/op.ViewOnline.php?documentid=".$version->getDocument()->getId()."&version=". $version->getVersion()."\">";
+			} else {
+				print "<a href=\"../op/op.Download.php?documentid=".$version->getDocument()->getId()."&version=".$version->getVersion()."\">";
+			}
+		}
 		if($previewer->hasPreview($version)) {
 			print("<img class=\"mimeicon\" width=\"".$previewwidthdetail."\" src=\"../op/op.Preview.php?documentid=".$document->getID()."&version=".$version->getVersion()."&width=".$previewwidthdetail."\" title=\"".htmlspecialchars($version->getMimeType())."\">");
+		} else {
+			print "<img class=\"mimeicon\" width=\"".$previewwidthdetail."\" src=\"".$this->getMimeIcon($version->getFileType())."\" title=\"".htmlspecialchars($version->getMimeType())."\">";
+		}
+		if ($file_exists) {
+			print "</a>";
 		}
 		print "</td>\n";
 
