@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Include class to preview documents
@@ -34,7 +34,7 @@ require_once("SeedDMS/Preview.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_MyDocuments extends SeedDMS_Theme_Style {
 
 	function js() { /* {{{ */
 		$dms = $this->params['dms'];
@@ -58,8 +58,6 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 		$timeout = $this->params['timeout'];
 		$xsendfile = $this->params['xsendfile'];
 
-		$this->htmlAddHeader('<script type="text/javascript" src="../styles/'.$this->theme.'/bootbox/bootbox.min.js"></script>'."\n", 'js');
-
 		$db = $dms->getDB();
 		$previewer = new SeedDMS_Preview_Previewer($cachedir, $previewwidth, $timeout, $xsendfile);
 
@@ -171,7 +169,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 								$document->verifyLastestContentExpriry();
 							
 								if ($printheader){
-									print "<table class=\"table table-condensed\">";
+									print "<table class=\"table table-condensed table-sm\">";
 									print "<thead>\n<tr>\n";
 									print "<th></th>\n";
 									print "<th>".getMLText("name")."</th>\n";
@@ -210,7 +208,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 								$document->verifyLastestContentExpriry();
 
 								if ($printheader){
-									print "<table class=\"table table-condensed\">";
+									print "<table class=\"table table-condensed table-sm\">";
 									print "<thead>\n<tr>\n";
 									print "<th></th>\n";
 									print "<th>".getMLText("name")."</th>\n";
@@ -261,7 +259,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 							$document->verifyLastestContentExpriry();
 						
 							if ($printheader){
-								print "<table class=\"table table-condensed\">";
+								print "<table class=\"table table-condensed table-sm\">";
 								print "<thead>\n<tr>\n";
 								print "<th></th>\n";
 								print "<th>".getMLText("name")."</th>\n";
@@ -298,7 +296,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 							$document = $dms->getDocument($st["documentID"]);
 							$document->verifyLastestContentExpriry();
 							if ($printheader){
-								print "<table class=\"table table-condensed\">";
+								print "<table class=\"table table-condensed table-sm\">";
 								print "<thead>\n<tr>\n";
 								print "<th></th>\n";
 								print "<th>".getMLText("name")."</th>\n";
@@ -382,7 +380,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 				//$this->contentContainerStart();
 				if (count($resArr)>0) {
 
-					print "<table class=\"table table-condensed\">";
+					print "<table class=\"table table-condensed table-sm\">";
 					print "<thead>\n<tr>\n";
 					print "<th></th>";
 					print "<th>".getMLText("name")."</th>\n";
@@ -461,7 +459,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 				//$this->contentContainerStart();
 				if (count($resArr)>0) {
 
-					print "<table class=\"table table-condensed\">";
+					print "<table class=\"table table-condensed table-sm\">";
 					print "<thead>\n<tr>\n";
 					print "<th></th>";
 					print "<th>".getMLText("name")."</th>\n";
@@ -588,7 +586,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 							$document->verifyLastestContentExpriry();
 						
 							if ($printheader){
-								print "<table class=\"table table-condensed\">";
+								print "<table class=\"table table-condensed table-sm\">";
 								print "<thead>\n<tr>\n";
 								print "<th></th>\n";
 								print "<th>".getMLText("name")."</th>\n";
@@ -630,7 +628,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 							$document->verifyLastestContentExpriry();
 
 							if ($printheader){
-								print "<table class=\"table table-condensed\">";
+								print "<table class=\"table table-condensed table-sm\">";
 								print "<thead>\n<tr>\n";
 								print "<th></th>\n";
 								print "<th>".getMLText("name")."</th>\n";
@@ -705,7 +703,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 				//$this->contentContainerStart();
 				if (count($resArr)>0) {
 
-					print "<table class=\"table table-condensed\">";
+					print "<table class=\"table table-condensed table-sm\">";
 					print "<thead>\n<tr>\n";
 					print "<th></th>";
 					print "<th>".getMLText("name")."</th>\n";
@@ -786,7 +784,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 			//$this->contentContainerStart();
 			if (count($resArr)>0) {
 
-				print "<table class=\"table table-condensed\">";
+				print "<table class=\"table table-condensed table-sm\">";
 				print "<thead>\n<tr>\n";
 				print "<th></th>";
 				print "<th>".getMLText("name")."</th>\n";
@@ -845,7 +843,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 			//$this->contentContainerStart();
 			if (count($docs)>0) {
 
-				print "<table class=\"table table-condensed\">";
+				print "<table class=\"table table-condensed table-sm\">";
 				print "<thead>\n<tr>\n";
 				print "<th></th>";
 				print "<th>".getMLText("name")."</th>\n";
@@ -943,7 +941,7 @@ class SeedDMS_View_MyDocuments extends SeedDMS_Bootstrap_Style {
 
 			if (count($resArr)>0) {
 
-				print "<table class=\"table table-condensed\">";
+				print "<table class=\"table table-condensed table-sm\">";
 				print "<thead>\n<tr>\n";
 				print "<th></th>";
 				print "<th><a href=\"../out/out.MyDocuments.php?orderby=n\">".getMLText("name")."</a> — \n";
