@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Class which outputs the html page for Settings view
@@ -29,29 +29,25 @@ require_once("class.Bootstrap.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
-
-	protected function showPaneHeader($name, $title, $isactive) { /* {{{ */
-		echo '<li class="'.($isactive ? 'active' : '').'"><a data-target="#'.$name.'" data-toggle="tab">'.$title.'</a></li>'."\n";
-	} /* }}} */
+class SeedDMS_View_Settings extends SeedDMS_Theme_Style {
 
 	protected function showStartPaneContent($name, $isactive) { /* {{{ */
-		echo '<div class="tab-pane'.($isactive ? ' active' : '').'" id="'.$name.'">';
+		parent::showStartPaneContent($name, $isactive);
 		$this->contentContainerStart();
-		echo '<table class="table-condensed" style="table-layout: fixed;">';
+		echo '<table class="table-condensed table-sm" style="table-layout: fixed;">';
 		echo '<tr><td width="20%"></td><td width="80%"></td></tr>';
 	} /* }}} */
 
-	protected function showEndPaneContent($name, $currentab) { /* {{{ */
+	protected function showEndPaneContent($name, $currenttab) { /* {{{ */
     echo '</table>';
 		$this->contentContainerEnd();
-		echo '</div>';
+		parent::showEndPaneContent($name, $currenttab);
 	} /* }}} */
 
 	protected function getTextField($name, $value, $type='', $placeholder='') { /* {{{ */
 		$html = '';
 		if($type == 'textarea' || ($type != 'password' && strlen($value) > 80))
-			$html .= '<textarea class="input-xxlarge" name="'.$name.'">'.$value.'</textarea>';
+			$html .= '<textarea class="form-control input-xxlarge" name="'.$name.'">'.$value.'</textarea>';
 		else {
 			if(strlen($value) > 40)
 				$class = 'input-xxlarge';
@@ -63,7 +59,7 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
 				$class = 'input-medium';
 			else
 				$class = 'input-small';
-			$html .= '<input '.($type=='password' ? 'type="password"' : 'type="text"').' class="'.$class.'" name="'.$name.'" value="'.$value.'" placeholder="'.$placeholder.'"/>';
+			$html .= '<input '.($type=='password' ? 'type="password"' : ($type=='number' ? 'type="number"' : 'type="text"')).' class="form-control '.$class.'" name="'.$name.'" value="'.$value.'" placeholder="'.$placeholder.'"/>';
 		}
 		return $html;
 	} /* }}} */
@@ -92,6 +88,23 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
 		$this->showRawConfigHeadline(htmlspecialchars(getMLText($title)));
 	} /* }}} */
 
+	/**
+	 * Show a text input configuration option
+	 *
+	 * @param string $title title of the option
+	 * @param string $name name of html input field
+	 * @param string $type can be 'password', 'array'
+	 * @param string $placeholder placeholder for input field
+	 */
+	protected function isVisible($name) { /* {{{ */
+		$settings = $this->params['settings'];
+		if(!($hcf = $settings->_hiddenConfFields))
+			return true;
+		if(in_array($name, $hcf))
+			return false;
+		return true;
+	} /* }}} */
+
 	/**
 	 * Show a text input configuration option
 	 *
@@ -103,15 +116,20 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
 	protected function showConfigText($title, $name, $type='', $placeholder='') { /* {{{ */
 		$settings = $this->params['settings'];
 ?>
-      <tr title="<?= getMLText($title."_desc") ?>">
+			<tr title="<?= getMLText($title."_desc") ?>">
 				<td><?= getMLText($title) ?>:</td>
 <?php
-		if($type == 'array')
+		if($type === 'array')
 			$value = $settings->arrayToString($settings->{"_".$name});
 		else
 			$value = $settings->{"_".$name};
+		echo "				<td>";
+		if($this->isVisible($name))
+			$this->showTextField($name, $value, ($type=='password' || $type=='textarea' ? $type : ''), $placeholder);
+		else
+			echo getMLText('settings_conf_field_not_editable');
+		echo "</td>\n";
 ?>
-				<td><?php $this->showTextField($name, $value, ($type=='password' || $type=='textarea' ? $type : ''), $placeholder); ?></td>
 			</tr>
 <?php
 	} /* }}} */
@@ -158,9 +176,9 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
         <td><?= getMLText($title) ?>:</td>
 				<td>
 <?php if($multiple) { ?>
-					<select name="<?= $name ?>[]" multiple>
+					<select class="form-control" name="<?= $name ?>[]" multiple>
 <?php } else { ?>
-					<select name="<?= $name ?>">
+					<select class="form-control" name="<?= $name ?>">
 <?php }
 		foreach($values as $i=>$value) {
 			$optval = trim($isass ? $i : $value);
@@ -186,7 +204,10 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
 <?php
 		$users = $dms->getAllUsers();
 		if($users) {
-			$selections = explode(',', $settings->{"_".$name});
+			if(is_array($settings->{"_".$name}))
+				$selections = $settings->{"_".$name};
+			else
+				$selections = explode(',', $settings->{"_".$name});
 			echo "<select class=\"chzn-select\"".($allowempty ? " data-allow-clear=\"true\"" : "")."\" name=\"".$name.($multiple ? "[]" : "")."\"".($multiple ? "  multiple" : "").($size ? "  size=\"".$size."\"" : "")." data-placeholder=\"".getMLText("select_user")."\">";
 			if($allowempty)
 				echo "<option value=\"\"></option>";
@@ -252,20 +273,15 @@ class SeedDMS_View_Settings extends SeedDMS_Bootstrap_Style {
 		$this->pageNavigation(getMLText("admin_tools"), "admin_tools");
 		$this->contentHeading(getMLText("settings"));
 
+		$this->rowStart();
+		$this->columnStart(8);
 ?>
   <form action="../op/op.Settings.php" method="post" enctype="multipart/form-data" name="form0" >
 	<?php echo createHiddenFieldWithKey('savesettings'); ?>
   <input type="hidden" name="action" value="saveSettings" />
 	<input type="hidden" id="currenttab" name="currenttab" value="<?php echo $currenttab ? $currenttab : 'site'; ?>" />
-<?php
-if(!is_writeable($settings->_configFilePath)) {
-	print "<div class=\"alert alert-warning\">";
-	echo "<p>".getMLText("settings_notwritable")."</p>";
-	print "</div>";
-}
-?>
 
-  <ul class="nav nav-tabs" id="settingstab">
+  <ul class="nav nav-pills" id="settingstab" role="tablist">
 <?php $this->showPaneHeader('site', getMLText('settings_Site'), (!$currenttab || $currenttab == 'site')); ?>
 <?php $this->showPaneHeader('system', getMLText('settings_System'), ($currenttab == 'system')); ?>
 <?php $this->showPaneHeader('advanced', getMLText('settings_Advanced'), ($currenttab == 'advanced')); ?>
@@ -306,6 +322,7 @@ $this->showStartPaneContent('site', (!$currenttab || $currenttab == 'site'));
 <?php $this->showConfigCheckbox('settings_strictFormCheck', 'strictFormCheck'); ?>
 <?php $this->showConfigCheckbox('settings_inlineEditing', 'inlineEditing'); ?>
 <?php $this->showConfigOption('settings_noDocumentFormFields', 'noDocumentFormFields', array('comment', 'keywords', 'categories', 'sequence', 'expires', 'version', 'version_comment', 'notification'), true, true); ?>
+<?php $this->showConfigOption('settings_noFolderFormFields', 'noFolderFormFields', array('comment', 'sequence', 'notification'), true, true); ?>
 <?php $this->showConfigText('settings_viewOnlineFileTypes', 'viewOnlineFileTypes', 'array'); ?>
 <?php $this->showConfigText('settings_editOnlineFileTypes', 'editOnlineFileTypes', 'array'); ?>
 <?php $this->showConfigCheckbox('settings_enableConverting', 'enableConverting'); ?>
@@ -341,6 +358,7 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 <?php $this->showConfigOption('settings_sortUsersInList', 'sortUsersInList', array(' '=>'settings_sortUsersInList_val_login', 'fullname'=>'settings_sortUsersInList_val_fullname'), false, true); ?>
 <?php $this->showConfigOption('settings_sortFoldersDefault', 'sortFoldersDefault', array('u'=>'settings_sortFoldersDefault_val_unsorted', 's'=>'settings_sortFoldersDefault_val_sequence', 'n'=>'settings_sortFoldersDefault_val_name'), false, true); ?>
 <?php $this->showConfigOption('settings_defaultDocPosition', 'defaultDocPosition', array('end'=>'settings_defaultDocPosition_val_end', 'start'=>'settings_defaultDocPosition_val_start'), false, true); ?>
+<?php $this->showConfigOption('settings_defaultFolderPosition', 'defaultFolderPosition', array('end'=>'settings_defaultDocPosition_val_end', 'start'=>'settings_defaultDocPosition_val_start'), false, true); ?>
 
       <!--
         -- SETTINGS - SITE - WEBDAV
@@ -355,6 +373,14 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 <?php $this->showConfigCheckbox('settings_enableCalendar', 'enableCalendar'); ?>
 <?php $this->showConfigOption('settings_calendarDefaultView', 'calendarDefaultView', array('w'=>'week_view', 'm'=>'month_view', 'y'=>'year_view'), false, true); ?>
 <?php $this->showConfigOption('settings_firstDayOfWeek', 'firstDayOfWeek', array(' 0'=>'sunday', ' 1'=>'monday', ' 2'=>'tuesday', ' 3'=>'wednesday', ' 4'=>'thursday', ' 5'=>'friday', ' 6'=>'saturday'), false, true); ?>
+
+      <!--
+        -- SETTINGS - SITE - EXTENSIONMGR
+      -->
+<?php $this->showConfigHeadline('settings_ExtensionMgr'); ?>
+<?php $this->showConfigCheckbox('settings_enableExtensionDownload', 'enableExtensionDownload'); ?>
+<?php $this->showConfigCheckbox('settings_enableExtensionImport', 'enableExtensionImport'); ?>
+<?php $this->showConfigCheckbox('settings_enableExtensionImportFromRepository', 'enableExtensionImportFromRepository'); ?>
 <?php
 	$this->showEndPaneContent('site', $currenttab);
 
@@ -425,7 +451,7 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 <?php $this->showConfigText('settings_smtpSendFrom', 'smtpSendFrom'); ?>
 <?php $this->showConfigText('settings_smtpUser', 'smtpUser'); ?>
 <?php $this->showConfigText('settings_smtpPassword', 'smtpPassword', 'password'); ?>
-<?php $this->showConfigPlain(htmlspecialchars(getMLText('settings_smtpSendTestMail')), htmlspecialchars(getMLText('settings_smtpSendTestMail_desc')), '<a class="btn sendtestmail">'.getMLText('send_test_mail').'</a><div><pre id="maildebug">You will see debug messages here</pre></div>'); ?>
+<?php $this->showConfigPlain(htmlspecialchars(getMLText('settings_smtpSendTestMail')), htmlspecialchars(getMLText('settings_smtpSendTestMail_desc')), '<a class="btn btn-secondary sendtestmail">'.getMLText('send_test_mail').'</a><div><pre id="maildebug">You will see debug messages here</pre></div>'); ?>
 <?php
 	$this->showEndPaneContent('system', $currenttab);
 
@@ -438,7 +464,6 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 <?php $this->showConfigText('settings_siteDefaultPage', 'siteDefaultPage'); ?>
 <?php $this->showConfigText('settings_rootFolderID', 'rootFolderID'); ?>
 <?php $this->showConfigCheckbox('settings_useHomeAsRootFolder', 'useHomeAsRootFolder'); ?>
-<?php $this->showConfigCheckbox('settings_titleDisplayHack', 'titleDisplayHack'); ?>
 <?php $this->showConfigCheckbox('settings_showMissingTranslations', 'showMissingTranslations'); ?>
 
       <!--
@@ -464,6 +489,7 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 <?php $this->showConfigCheckbox('settings_enableOwnerRevApp', 'enableOwnerRevApp'); ?>
 <?php $this->showConfigCheckbox('settings_enableSelfRevApp', 'enableSelfRevApp'); ?>
 <?php $this->showConfigCheckbox('settings_enableUpdateRevApp', 'enableUpdateRevApp'); ?>
+<?php $this->showConfigCheckbox('settings_enableRemoveRevApp', 'enableRemoveRevApp'); ?>
 <?php $this->showConfigCheckbox('settings_enableVersionDeletion', 'enableVersionDeletion'); ?>
 <?php $this->showConfigCheckbox('settings_enableVersionModification', 'enableVersionModification'); ?>
 <?php $this->showConfigCheckbox('settings_enableDuplicateDocNames', 'enableDuplicateDocNames'); ?>
@@ -515,7 +541,7 @@ if(($kkk = $this->callHook('getFullSearchEngine')) && is_array($kkk))
 		if($this->hasHook('processConfig'))
 			$extconf = $this->callHook('processConfig', $extname, $extconf);
 		if($extconf['config']) {
-			$this->showRawConfigHeadline("<a name=\"".$extname."\"></a>".'<input type="hidden" name="extensions['.$extname.'][__disable__]" value="'.(isset($settings->_extensions[$extname]["__disable__"]) && $settings->_extensions[$extname]["__disable__"] ? '1' : '').'" /><i class="fa fa-circle'.($settings->_extensions[$extname]["__disable__"] ? ' disabled' : ' enabled').'"></i> <span title="'.$extname.'">'.$extconf['title'].'</span>');
+			$this->showRawConfigHeadline("<a name=\"".$extname."\"></a>".'<input type="hidden" name="extensions['.$extname.'][__disable__]" value="'.(isset($settings->_extensions[$extname]["__disable__"]) && $settings->_extensions[$extname]["__disable__"] ? '1' : '').'" /><i class="fa fa-circle'.(isset($settings->_extensions[$extname]["__disable__"]) && $settings->_extensions[$extname]["__disable__"] ? ' disabled' : ' enabled').'"></i> <span title="'.$extname.'">'.$extconf['title'].'</span>');
 			foreach($extconf['config'] as $confkey=>$conf) {
 						ob_start();
 						switch($conf['type']) {
@@ -655,9 +681,29 @@ if(is_writeable($settings->_configFilePath)) {
 }
 ?>
 	</form>
-
-
 <?php
+		$this->columnEnd();
+		$this->columnStart(4);
+		if(!is_writeable($settings->_configFilePath)) {
+			$this->warningMsg(getMLText("settings_notwritable"));
+		}
+		if($settings->_enableGuestLogin && $settings->_guestID) {
+			$guest = $dms->getUser((int) $settings->_guestID);
+			if(!$guest) {
+				$this->warningMsg(getMLText("settings_invalid_guestid"));
+			} elseif($guest->isDisabled()) {
+				$this->warningMsg(getMLText("settings_guestid_is_disabled"));
+			} elseif($guest->isAdmin()) {
+				$this->warningMsg(getMLText("settings_guestid_is_admin"));
+			}
+		}
+		$mus2 = SeedDMS_Core_File::parse_filesize(ini_get("upload_max_filesize"));
+		$mus1 = SeedDMS_Core_File::parse_filesize($settings->_partitionSize);
+		if($settings->_enableLargeFileUpload && $mus2 < $mus1) {
+			$this->warningMsg(getMLText("settings_partionsize_below_max_filesize"));
+		}
+		$this->columnEnd(4);
+		$this->rowEnd(4);
 		$this->contentEnd();
 		$this->htmlEndPage();
 	} /* }}} */
