@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Class which outputs the html page for UpdateDocument view
@@ -29,7 +29,7 @@ require_once("class.Bootstrap.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_UpdateDocument extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_UpdateDocument extends SeedDMS_Theme_Style {
 
 	function js() { /* {{{ */
 		$strictformcheck = $this->params['strictformcheck'];
@@ -38,6 +38,7 @@ class SeedDMS_View_UpdateDocument extends SeedDMS_Bootstrap_Style {
 		$partitionsize = $this->params['partitionsize'];
 		$maxuploadsize = $this->params['maxuploadsize'];
 		header('Content-Type: application/javascript; charset=UTF-8');
+		parent::jsTranslations(array('js_form_error', 'js_form_errors'));
 		$this->printDropFolderChooserJs("form1");
 		$this->printSelectPresetButtonJs();
 		$this->printInputPresetButtonJs();
@@ -71,16 +72,6 @@ $(document).ready( function() {
 	$("#form1").validate({
 		debug: false,
 		ignore: ":hidden:not(.do_validate)",
-		invalidHandler: function(e, validator) {
-			noty({
-				text:  (validator.numberOfInvalids() == 1) ? "<?php printMLText("js_form_error");?>".replace('#', validator.numberOfInvalids()) : "<?php printMLText("js_form_errors");?>".replace('#', validator.numberOfInvalids()),
-				type: 'error',
-				dismissQueue: true,
-				layout: 'topRight',
-				theme: 'defaultTheme',
-				timeout: 1500,
-			});
-		},
 <?php
 		if($enablelargefileupload) {
 ?>
@@ -105,10 +96,12 @@ $(document).ready( function() {
 		} else {
 ?>
 			userfile: {
-				alternatives: $('#dropfolderfileform1')
+				require_from_group: [1, ".fileupload-group"]
+//				alternatives: $('#dropfolderfileform1')
 			},
 			dropfolderfileform1: {
-				 alternatives: $('#userfile')
+				require_from_group: [1, ".fileupload-group"]
+//				alternatives: $('#userfile')
 			}
 <?php
 		}
@@ -154,6 +147,8 @@ console.log(element);
 		$documentid = $document->getId();
 
 		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/jquery-validation/jquery.validate.js"></script>'."\n", 'js');
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/jquery-validation/additional-methods.js"></script>'."\n", 'js');
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/styles/validation-default.js"></script>'."\n", 'js');
 		if($enablelargefileupload) {
 			$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/fine-uploader/jquery.fine-uploader.min.js"></script>'."\n", 'js');
 			$this->htmlAddHeader($this->getFineUploaderTemplate(), 'js');
@@ -169,24 +164,23 @@ console.log(element);
 
 			$lockingUser = $document->getLockingUser();
 
-			print "<div class=\"alert alert-warning\">";
-			
-			printMLText("update_locked_msg", array("username" => htmlspecialchars($lockingUser->getFullName()), "email" => $lockingUser->getEmail()));
+			$html = '';
+			$html .= getMLText("update_locked_msg", array("username" => htmlspecialchars($lockingUser->getFullName()), "email" => $lockingUser->getEmail())).' ';
 			
 			if ($lockingUser->getID() == $user->getID())
-				printMLText("unlock_cause_locking_user");
+				$html .= getMLText("unlock_cause_locking_user");
 			else if ($document->getAccessMode($user) == M_ALL)
-				printMLText("unlock_cause_access_mode_all");
+				$html .= getMLText("unlock_cause_access_mode_all");
 			else
 			{
-				printMLText("no_update_cause_locked");
-				print "</div>";
+				$html .= getMLText("no_update_cause_locked");
+				$this->warningMsg($html);
 				$this->contentEnd();
 				$this->htmlEndPage();
 				exit;
 			}
 
-			print "</div>";
+			$this->warningMsg($html);
 		}
 
 		$latestContent = $document->getLatestContent();
@@ -220,13 +214,13 @@ console.log(element);
 		}
 		if($msg)
 			$this->warningMsg($msg);
-		$this->contentContainerStart();
 ?>
 
 <form class="form-horizontal" action="../op/op.UpdateDocument.php" enctype="multipart/form-data" method="post" name="form1" id="form1">
 	<?php echo createHiddenFieldWithKey('updatedocument'); ?>
 	<input type="hidden" name="documentid" value="<?php print $document->getID(); ?>">
 <?php
+		$this->contentContainerStart();
 		$this->formField(
 			getMLText("local_file"),
 			$enablelargefileupload ? $this->getFineUploaderHtml() : $this->getFileChooserHtml('userfile', false)
@@ -237,6 +231,14 @@ console.log(element);
 				$this->getDropFolderChooserHtml("form1")
 			);
 		}
+		if($arr = $this->callHook('addDocumentContentFile')) {
+			foreach($arr as $ar)
+				if(is_array($ar)) {
+					$this->formField($ar[0], $ar[1], isset($ar[2]) ? $ar[2] : null);
+				} elseif(is_string($ar)) {
+					echo $ar;
+				}
+		}
 		if(!$nodocumentformfields || !in_array('version_comment', $nodocumentformfields)) {
 		$this->formField(
 			getMLText("comment"),
@@ -299,6 +301,7 @@ console.log(element);
 			echo $arrs;
 		}
 
+		$docAccess = $document->getReadAccessList($enableadminrevapp, $enableownerrevapp);
 		if($workflowmode == 'advanced') {
 			$mandatoryworkflows = $user->getMandatoryWorkflows();
 			if($mandatoryworkflows) {
@@ -346,7 +349,6 @@ console.log(element);
 			}
 			$this->warningMsg(getMLText("add_doc_workflow_warning"));
 		} elseif($workflowmode == 'traditional' || $workflowmode == 'traditional_only_approval') {
-			$docAccess = $document->getReadAccessList($enableadminrevapp, $enableownerrevapp);
 			if($workflowmode == 'traditional') {
 				$this->contentSubHeading(getMLText("assign_reviewers"));
 				$res=$user->getMandatoryReviewers();
@@ -649,12 +651,12 @@ console.log(element);
 				}
 			$this->warningMsg(getMLText("add_doc_reviewer_approver_warning"));
 		}
+		$this->contentContainerEnd();
 		$this->formSubmit(getMLText('update_document'));
 ?>
 </form>
 
 <?php
-		$this->contentContainerEnd();
 		$this->contentEnd();
 		$this->htmlEndPage();
 	} /* }}} */
