@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Class which outputs the html page for UsrMgr view
@@ -29,50 +29,58 @@ require_once("class.Bootstrap.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_UsrMgr extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_UsrMgr extends SeedDMS_Theme_Style {
 
 	function js() { /* {{{ */
 		$seluser = $this->params['seluser'];
 		$strictformcheck = $this->params['strictformcheck'];
 
 		header('Content-Type: application/javascript; charset=UTF-8');
+		parent::jsTranslations(array('js_form_error', 'js_form_errors'));
 ?>
-function checkForm()
-{
-	msg = new Array();
-
-	if($("#login").val() == "") msg.push("<?php printMLText("js_no_login");?>");
-	if(($("#userid").val() == "0") && ($("#pwd").val() == "")) msg.push("<?php printMLText("js_no_pwd");?>");
-	if(($("#pwd").val() != $("#pwdconf").val())&&($("#pwd").val() != "")&&($("#pwdconf").val() != "")) msg.push("<?php printMLText("js_pwd_not_conf");?>");
-	if($("#name").val() == "") msg.push("<?php printMLText("js_no_name");?>");
-	if($("#email").val() == "") msg.push("<?php printMLText("js_no_email");?>");
+function runValidation() {
+	$("#form1").validate({
+		rules: {
+			login: {
+				required: true
+			},
+			name: {
+				required: true
+			},
 <?php
 	if ($strictformcheck) {
 ?>
-	if($("#comment").val() == "") msg.push("<?php printMLText("js_no_comment");?>");
+			comment: {
+				required: true
+			},
 <?php
 	}
 ?>
-	if (msg != "") {
-  	noty({
-  		text: msg.join('<br />'),
-  		type: 'error',
-      dismissQueue: true,
-  		layout: 'topRight',
-  		theme: 'defaultTheme',
-			_timeout: 1500,
-  	});
-		return false;
+			email: {
+				required: true,
+				email: true
+			},
+			pwdconf: {
+				equalTo: "#pwd"
+			}
+		},
+		messages: {
+			login: "<?php printMLText("js_no_login");?>",
+			name: "<?php printMLText("js_no_name");?>",
+<?php
+	if ($strictformcheck) {
+?>
+			comment: "<?php printMLText("js_no_comment");?>",
+<?php
 	}
-	else
-		return true;
+?>
+			email: "<?php printMLText("js_no_email");?>",
+			pwdconf: "<?php printMLText("js_pwd_not_conf");?>",
+		}
+	});
 }
 
 $(document).ready( function() {
-	$('body').on('submit', '#form', function(ev){
-		if(checkForm()) return;
-		ev.preventDefault();
-	});
 	$( "#selector" ).change(function() {
 		$('div.ajax').trigger('update', {userid: $(this).val()});
 		window.history.pushState({"html":"","pageTitle":""},"", '../out/out.UsrMgr.php?userid=' + $(this).val());
@@ -94,7 +102,7 @@ $(document).ready( function() {
 			$sessionmgr = new SeedDMS_SessionMgr($dms->getDB());
 
 			$this->contentHeading(getMLText("user_info"));
-			echo "<table class=\"table table-condensed\">\n";
+			echo "<table class=\"table table-condensed table-sm\">\n";
 			echo "<tr><td>".getMLText('discspace')."</td><td>";
 			if($quota) {
 				$qt = $seluser->getQuota() ? $seluser->getQuota() : $quota;
@@ -106,8 +114,16 @@ $(document).ready( function() {
 			echo "</td></tr>\n";
 			$documents = $seluser->getDocuments();
 			echo "<tr><td>".getMLText('documents')."</td><td>".count($documents)."</td></tr>\n";
+			$contents = $seluser->getDocumentContents();
+			echo "<tr><td>".getMLText('document_versions')."</td><td>".count($contents)."</td></tr>\n";
 			$documents = $seluser->getDocumentsLocked();
 			echo "<tr><td>".getMLText('documents_locked')."</td><td>".count($documents)."</td></tr>\n";
+			$links = $seluser->getDocumentLinks();
+			echo "<tr><td>".getMLText('document_links')."</td><td>".count($links)."</td></tr>\n";
+			$files = $seluser->getDocumentFiles();
+			echo "<tr><td>".getMLText('document_files')."</td><td>".count($files)."</td></tr>\n";
+			$folders = $seluser->getFolders();
+			echo "<tr><td>".getMLText('folders')."</td><td>".count($folders)."</td></tr>\n";
 			$categories = $seluser->getKeywordCategories();
 			echo "<tr><td>".getMLText('personal_default_keywords')."</td><td>".count($categories)."</td></tr>\n";
 			$dnot = $seluser->getNotifications(T_DOCUMENT);
@@ -173,29 +189,27 @@ $(document).ready( function() {
 		$quota = $this->params['quota'];
 		$undeluserids = $this->params['undeluserids'];
 		$enableemail = $this->params['enableemail'];
+		$accessobject = $this->params['accessobject'];
 
 		if($seluser) {
-?>
-<div class="btn-group">
-  <a class="btn dropdown-toggle" data-toggle="dropdown" href="#">
-		<?php echo getMLText('action'); ?>
-    <span class="caret"></span>
-  </a>
-  <ul class="dropdown-menu">
-<?php
-			if(!in_array($seluser->getID(), $undeluserids)) {
-				echo '<li><a href="../out/out.RemoveUser.php?userid='.$seluser->getID().'"><i class="fa fa-remove"></i> '.getMLText("rm_user").'</a><li>';
+			$button = array(
+				'label'=>getMLText('action'),
+				'menuitems'=>array(
+				)
+			);
+			if(!in_array($seluser->getID(), $undeluserids) && $accessobject->check_controller_access('UsrMgr', ['action'=>'removeuser'])) {
+				$button['menuitems'][] = array('label'=>'<i class="fa fa-remove"></i> '.getMLText("rm_user"), 'link'=>'../out/out.RemoveUser.php?userid='.$seluser->getID());
 			}
-			echo '<li><a href="../out/out.RemoveUserFromProcesses.php?userid='.$seluser->getID().'"><i class="fa fa-unlink"></i> '.getMLText("rm_user_from_processes").'</a></li>';
-			echo '<li><a href="../out/out.TransferObjects.php?userid='.$seluser->getID().'"><i class="fa fa-share-square-o"></i> '.getMLText("transfer_objects").'</a></li>';
+			if($accessobject->check_controller_access('UsrMgr', ['action'=>'removefromprocesses']))
+				$button['menuitems'][] = array('label'=>'<i class="fa fa-unlink"></i> '.getMLText("rm_user_from_processes"), 'link'=>'../out/out.RemoveUserFromProcesses.php?userid='.$seluser->getID());
+			if($accessobject->check_controller_access('UsrMgr', ['action'=>'transferobjects']))
+				$button['menuitems'][] = array('label'=>'<i class="fa fa-share-square-o"></i> '.getMLText("transfer_objects"), 'link'=>'../out/out.TransferObjects.php?userid='.$seluser->getID());
 			if($user->isAdmin() && $seluser->getID() != $user->getID())
-				echo "<li><a href=\"../op/op.SubstituteUser.php?userid=".$seluser->getID()."&formtoken=".createFormKey('substituteuser')."\"><i class=\"fa fa-exchange\"></i> ".getMLText("substitute_user")."</a></li>\n";
-			if($enableemail)
-				echo '<li><a href="../out/out.SendLoginData.php?userid='.$seluser->getID().'"><i class="fa fa-envelope-o"></i> '.getMLText("send_login_data").'</a></li>';
-?>
-	</ul>
-</div>
-<?php
+				$button['menuitems'][] = array('label'=>'<i class="fa fa-exchange"></i> '.getMLText("substitute_user"), 'link'=>'../op/op.SubstituteUser.php?userid='.$seluser->getID()."&formtoken=".createFormKey('substituteuser'));
+			if($accessobject->check_controller_access('UsrMgr', ['action'=>'sendlogindata']))
+				if($enableemail)
+					$button['menuitems'][] = array('label'=>'<i class="fa fa-envelope-o"></i> '.getMLText("send_login_data"), 'link'=>'../out/out.SendLoginData.php?userid='.$seluser->getID());
+			self::showButtonwithMenu($button);
 		}
 	} /* }}} */
 
@@ -208,6 +222,7 @@ $(document).ready( function() {
 	function showUserForm($currUser) { /* {{{ */
 		$dms = $this->params['dms'];
 		$user = $this->params['user'];
+		$settings = $this->params['settings'];
 		$users = $this->params['allusers'];
 		$groups = $this->params['allgroups'];
 		$passwordstrength = $this->params['passwordstrength'];
@@ -218,7 +233,7 @@ $(document).ready( function() {
 		$workflowmode = $this->params['workflowmode'];
 		$quota = $this->params['quota'];
 ?>
-	<form class="form-horizontal" action="../op/op.UsrMgr.php" method="post" enctype="multipart/form-data" name="form" id="form">
+	<form class="form-horizontal" action="../op/op.UsrMgr.php" method="post" enctype="multipart/form-data" name="form1" id="form1">
 <?php
 		if($currUser) {
 			echo createHiddenFieldWithKey('edituser');
@@ -233,6 +248,7 @@ $(document).ready( function() {
 	<input type="hidden" name="action" value="adduser">
 <?php
 		}
+		$this->contentContainerStart();
 		$this->formField(
 			getMLText("user_login"),
 			array(
@@ -250,7 +266,7 @@ $(document).ready( function() {
 		if($passwordstrength > 0) {
 			$this->formField(
 				getMLText("password_strength"),
-				'<div id="strengthbar'.($currUser ? $currUser->getID() : "0").'" class="progress" style="width: 220px; height: 30px; margin-bottom: 8px;"><div class="bar bar-danger" style="width: 0%;"></div></div>'
+				'<div id="strengthbar'.($currUser ? $currUser->getID() : "0").'" class="progress" style="_width: 220px; height: 30px; margin-bottom: 8px;"><div class="bar bar-danger bg-danger" style="width: 0%;"></div></div>'
 			);
 		}
 		$this->formField(
@@ -262,7 +278,7 @@ $(document).ready( function() {
 				'name'=>'pwdconf',
 			)
 		);
-		if($passwordexpiration > 0) {
+		if($passwordexpiration > 0 && (!$currUser || !$currUser->isAdmin())) {
 			$options = array();
 			if($currUser)
 				$options[] = array('', getMLText("keep"));
@@ -321,6 +337,19 @@ $(document).ready( function() {
 				'options'=>$options
 			)
 		);
+		$themes = UI::getStyles();
+		$options = array();
+		foreach ($themes as $currTheme) {
+			$options[] = array($currTheme, $currTheme, ($currUser && ($currTheme == $currUser->getTheme())) || ($currTheme == $settings->_theme));
+		}
+		$this->formField(
+			getMLText("theme"),
+			array(
+				'element'=>'select',
+				'name'=>'theme',
+				'options'=>$options
+			)
+		);
 		$options = array();
 		foreach($groups as $group) {
 			$options[] = array($group->getID(), htmlspecialchars($group->getName()), ($currUser && $group->isMember($currUser)));
@@ -507,6 +536,7 @@ $(document).ready( function() {
 				);
 			}
 		}
+		$this->contentContainerEnd();
 		$this->formSubmit("<i class=\"fa fa-save\"></i> ".getMLText($currUser ? "save" : "add_user"));
 ?>
 	</form>
@@ -527,6 +557,9 @@ $(document).ready( function() {
 		$workflowmode = $this->params['workflowmode'];
 		$quota = $this->params['quota'];
 
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/vendors/jquery-validation/jquery.validate.js"></script>'."\n", 'js');
+		$this->htmlAddHeader('<script type="text/javascript" src="../views/'.$this->theme.'/styles/validation-default.js"></script>'."\n", 'js');
+
 		$this->htmlStartPage(getMLText("admin_tools"));
 		$this->globalNavigation();
 		$this->contentStart();
@@ -561,12 +594,10 @@ $(document).ready( function() {
 <?php
 		$this->columnEnd();
 		$this->columnStart(4);
-		$this->contentContainerStart();
  ?>
-		<div class="ajax" data-view="UsrMgr" data-action="form" <?php echo ($seluser ? "data-query=\"userid=".$seluser->getID()."\"" : "") ?>></div>
+		<div class="ajax" data-view="UsrMgr" data-action="form" data-afterload="()=>{runValidation();}" <?php echo ($seluser ? "data-query=\"userid=".$seluser->getID()."\"" : "") ?>></div>
 	</div>
 	<?php
-		$this->contentContainerEnd();
 		$this->columnEnd();
 		$this->rowEnd();
 		$this->contentEnd();
