@@ -16,7 +16,7 @@
 /**
  * Include parent class
  */
-require_once("class.Bootstrap.php");
+//require_once("class.Bootstrap.php");
 
 /**
  * Include class to preview documents
@@ -34,7 +34,12 @@ require_once("SeedDMS/Preview.php");
  *             2010-2012 Uwe Steinmann
  * @version    Release: @package_version@
  */
-class SeedDMS_View_ViewFolder extends SeedDMS_Bootstrap_Style {
+class SeedDMS_View_ViewFolder extends SeedDMS_Theme_Style {
+
+	/**
+	 * set a different name which is used to specify the hooks.
+	 */
+	//public $viewAliasName = '';
 
 	function data() { /* {{{ */
 		$dms = $this->params['dms'];
@@ -93,6 +98,21 @@ class SeedDMS_View_ViewFolder extends SeedDMS_Bootstrap_Style {
 		}
 	} /* }}} */
 
+	/**
+	 * Output a single attribute in the document info section
+	 *
+	 * @param object $attribute attribute
+	 */
+	protected function printAttribute($attribute) { /* {{{ */
+		$attrdef = $attribute->getAttributeDefinition();
+?>
+		    <tr>
+					<td><?php echo htmlspecialchars($attrdef->getName()); ?>:</td>
+					<td><?php echo $this->getAttributeValue($attribute); ?></td>
+		    </tr>
+<?php
+	} /* }}} */
+
 	public function subtree() { /* {{{ */
 		$user = $this->params['user'];
 		$node = $this->params['node'];
@@ -189,13 +209,17 @@ $('body').on('click', '[id^=\"table-row-folder\"] td:nth-child(2)', function(ev)
 	 * the table row when deleting the folder
 	 * This was added for the internal_link extensіon
 	 */
-	attr_id = $(ev.currentTarget).parent().data('target-id');
-	if(typeof attr_id == 'undefined')
-		attr_id = $(ev.currentTarget).parent().attr('id').split('-')[3];
-	folderSelectedmaintree(attr_id, '');
-	$([document.documentElement, document.body]).animate({
-	scrollTop: 200
-	}, 200);
+	if(ev.shiftKey) {
+		$(ev.currentTarget).parent().toggleClass('selected');
+	} else {
+		attr_id = $(ev.currentTarget).parent().data('target-id');
+		if(typeof attr_id == 'undefined')
+			attr_id = $(ev.currentTarget).parent().attr('id').split('-')[3];
+		folderSelectedmaintree(attr_id, '');
+		$([document.documentElement, document.body]).animate({
+		scrollTop: 200
+		}, 200);
+	}
 });
 <?php
 		$this->printClickDocumentJs();
@@ -212,14 +236,14 @@ $('body').on('click', '.order-btn', function(ev) {
 			$this->printNewTreeNavigationJs($folder->getID(), M_READ, 0, 'maintree', ($expandFolderTree == 1) ? -1 : 3, $orderby);
 
 		if ($enableDropUpload && $folder->getAccessMode($user) >= M_READWRITE) {
-			echo "SeedDMSUpload.setUrl('../op/op.Ajax.php');";
+			echo "SeedDMSUpload.setUrl('".$this->params['settings']->_httpRoot."op/op.Ajax.php');";
 			echo "SeedDMSUpload.setAbortBtnLabel('".getMLText("cancel")."');";
 			echo "SeedDMSUpload.setEditBtnLabel('".getMLText("edit_document_props")."');";
 			$mus2 = SeedDMS_Core_File::parse_filesize(ini_get("upload_max_filesize"));
 			if($maxuploadsize && $maxuploadsize < $mus2)
-				echo "SeedDMSUpload.setMaxFileSize($maxuploadsize);";
+				echo "SeedDMSUpload.setMaxFileSize($maxuploadsize);\n";
 			else
-				echo "SeedDMSUpload.setMaxFileSize($mus2);";
+				echo "SeedDMSUpload.setMaxFileSize($mus2);\n";
 			echo "SeedDMSUpload.setMaxFileSizeMsg('".getMLText("uploading_maxsize")."');";
 		}
 
@@ -239,11 +263,11 @@ $('body').on('click', '.order-btn', function(ev) {
 
 			$owner = $folder->getOwner();
 			$this->contentHeading(getMLText("folder_infos"));
-			$this->contentContainerStart();
+//			$this->contentContainerStart();
 			$txt = $this->callHook('preFolderInfos', $folder);
 			if(is_string($txt))
 				echo $txt;
-			echo "<table class=\"table-condensed\">\n";
+			echo "<table class=\"table table-condensed table-sm\">\n";
 			if($user->isAdmin()) {
 				echo "<tr>";
 				echo "<td>".getMLText("id").":</td>\n";
@@ -298,13 +322,7 @@ $('body').on('click', '.order-btn', function(ev) {
 					} elseif(is_string($arr)) {
 						echo $arr;
 					} else {
-						$attrdef = $attribute->getAttributeDefinition();
-			?>
-					<tr>
-					<td><?php echo htmlspecialchars($attrdef->getName()); ?>:</td>
-					<td><?php echo $this->getAttributeValue($attribute); ?></td>
-					</tr>
-<?php
+						$this->printAttribute($attribute);
 					}
 				}
 			}
@@ -323,7 +341,7 @@ $('body').on('click', '.order-btn', function(ev) {
 			$txt = $this->callHook('postFolderInfos', $folder);
 			if(is_string($txt))
 				echo $txt;
-			$this->contentContainerEnd();
+//			$this->contentContainerEnd();
 		}
 	} /* }}} */
 
@@ -335,6 +353,7 @@ $('body').on('click', '.order-btn', function(ev) {
 		$orderby = $this->params['orderby'];
 		$orderdir = (isset($orderby[1]) ? ($orderby[1] == 'd' ? 'desc' : 'asc') : 'asc');
 		$cachedir = $this->params['cachedir'];
+		$conversionmgr = $this->params['conversionmgr'];
 		$maxItemsPerPage = $this->params['maxItemsPerPage'];
 		$incItemsPerPage = $this->params['incItemsPerPage'];
 		$previewwidth = $this->params['previewWidthList'];
@@ -344,7 +363,10 @@ $('body').on('click', '.order-btn', function(ev) {
 		$onepage = $this->params['onepage'];
 
 		$previewer = new SeedDMS_Preview_Previewer($cachedir, $previewwidth, $timeout, $xsendfile);
-		$previewer->setConverters($previewconverters);
+		if($conversionmgr)
+			$previewer->setConversionMgr($conversionmgr);
+		else
+			$previewer->setConverters($previewconverters);
 
 		$txt = $this->callHook('listHeader', $folder);
 		if(is_string($txt))
@@ -371,13 +393,13 @@ $('body').on('click', '.order-btn', function(ev) {
 			if(is_string($txt))
 				echo $txt;
 			else {
-				print "<table id=\"viewfolder-table\" class=\"table table-condensed table-hover\">";
+				print "<table id=\"viewfolder-table\" class=\"table table-condensed table-sm table-hover\">";
 				print "<thead>\n<tr>\n";
-				print "<th>".($parent ? '<button class="btn btn-mini btn-secondary" id="goto-parent" data-parentid="'.$parent->getID().'"><i class="fa fa-arrow-up"></i></button>' : '')."</th>\n";	
+				print "<th>".($parent ? '<button class="btn btn-mini btn-secondary btn-sm" id="goto-parent" data-parentid="'.$parent->getID().'"><i class="fa fa-arrow-up"></i></button>' : '')."</th>\n";	
 				print "<th>".getMLText("name");
-				print " <a class=\"order-btn\" href=\"../out/out.ViewFolder.php?folderid=". $folderid .($orderby=="n"||$orderby=="na"?"&orderby=nd":"&orderby=n")."\" data-orderby=\"".($orderby=="n"||$orderby=="na"?"nd":"n")."\"title=\"".getMLText("sort_by_name")."\">".($orderby=="n"||$orderby=="na"?' <i class="fa fa-sort-alpha-asc selected"></i>':($orderby=="nd"?' <i class="fa fa-sort-alpha-desc selected"></i>':' <i class="fa fa-sort-alpha-asc"></i>'))."</a>";
-				print " <a class=\"order-btn\" href=\"../out/out.ViewFolder.php?folderid=". $folderid .($orderby=="s"||$orderby=="sa"?"&orderby=sd":"&orderby=s")."\" data-orderby=\"".($orderby=="s"||$orderby=="sa"?"sd":"s")."\" title=\"".getMLText("sort_by_sequence")."\">".($orderby=="s"||$orderby=="sa"?' <i class="fa fa-sort-numeric-asc selected"></i>':($orderby=="sd"?' <i class="fa fa-sort-numeric-desc selected"></i>':' <i class="fa fa-sort-numeric-asc"></i>'))."</a>";
-				print " <a class=\"order-btn\" href=\"../out/out.ViewFolder.php?folderid=". $folderid .($orderby=="d"||$orderby=="da"?"&orderby=dd":"&orderby=d")."\" data-orderby=\"".($orderby=="d"||$orderby=="da"?"dd":"d")."\" title=\"".getMLText("sort_by_date")."\">".($orderby=="d"||$orderby=="da"?' <i class="fa fa-sort-amount-asc selected"></i>':($orderby=="dd"?' <i class="fa fa-sort-amount-desc selected"></i>':' <i class="fa fa-sort-amount-asc"></i>'))."</a>";
+				print " <a class=\"order-btn\" href=\"".$this->params['settings']->_httpRoot."out/out.ViewFolder.php?folderid=". $folderid .($orderby=="n"||$orderby=="na"?"&orderby=nd":"&orderby=n")."\" data-orderby=\"".($orderby=="n"||$orderby=="na"?"nd":"n")."\"title=\"".getMLText("sort_by_name")."\">".($orderby=="n"||$orderby=="na"?' <i class="fa fa-sort-alpha-asc selected"></i>':($orderby=="nd"?' <i class="fa fa-sort-alpha-desc selected"></i>':' <i class="fa fa-sort-alpha-asc"></i>'))."</a>";
+				print " <a class=\"order-btn\" href=\"".$this->params['settings']->_httpRoot."out/out.ViewFolder.php?folderid=". $folderid .($orderby=="s"||$orderby=="sa"?"&orderby=sd":"&orderby=s")."\" data-orderby=\"".($orderby=="s"||$orderby=="sa"?"sd":"s")."\" title=\"".getMLText("sort_by_sequence")."\">".($orderby=="s"||$orderby=="sa"?' <i class="fa fa-sort-numeric-asc selected"></i>':($orderby=="sd"?' <i class="fa fa-sort-numeric-desc selected"></i>':' <i class="fa fa-sort-numeric-asc"></i>'))."</a>";
+				print " <a class=\"order-btn\" href=\"".$this->params['settings']->_httpRoot."out/out.ViewFolder.php?folderid=". $folderid .($orderby=="d"||$orderby=="da"?"&orderby=dd":"&orderby=d")."\" data-orderby=\"".($orderby=="d"||$orderby=="da"?"dd":"d")."\" title=\"".getMLText("sort_by_date")."\">".($orderby=="d"||$orderby=="da"?' <i class="fa fa-sort-amount-asc selected"></i>':($orderby=="dd"?' <i class="fa fa-sort-amount-desc selected"></i>':' <i class="fa fa-sort-amount-asc"></i>'))."</a>";
 				print "</th>\n";
 	//			print "<th>".getMLText("owner")."</th>\n";
 				print "<th>".getMLText("status")."</th>\n";
@@ -459,7 +481,7 @@ $('body').on('click', '.order-btn', function(ev) {
 		$this->contentHeading(getMLText("dropupload"), true);
 		if ($folder->getAccessMode($user) >= M_READWRITE) {
 ?>
-<div id="draganddrophandler" class="well alert" data-droptarget="folder_<?php echo $folder->getID(); ?>" data-target="<?php echo $folder->getID(); ?>" data-uploadformtoken="<?php echo createFormKey(''); ?>"><?php printMLText('drop_files_here'); ?></div>
+<div id="draganddrophandler" class="well alert alert-warning" data-droptarget="folder_<?php echo $folder->getID(); ?>" data-target="<?php echo $folder->getID(); ?>" data-uploadformtoken="<?php echo createFormKey(''); ?>"><?php printMLText('drop_files_here'); ?></div>
 <?php
 		} else {
 			$this->errorMsg(getMLText('access_denied'));
@@ -473,6 +495,7 @@ $('body').on('click', '.order-btn', function(ev) {
 		$orderby = $this->params['orderby'];
 		$orderdir = (isset($orderby[1]) ? ($orderby[1] == 'd' ? 'desc' : 'asc') : 'asc');
 		$cachedir = $this->params['cachedir'];
+		$conversionmgr = $this->params['conversionmgr'];
 		$previewwidth = $this->params['previewWidthList'];
 		$previewconverters = $this->params['previewConverters'];
 		$timeout = $this->params['timeout'];
@@ -483,7 +506,10 @@ $('body').on('click', '.order-btn', function(ev) {
 		header('Content-Type: application/json');
 
 		$previewer = new SeedDMS_Preview_Previewer($cachedir, $previewwidth, $timeout, $xsendfile);
-		$previewer->setConverters($previewconverters);
+		if($conversionmgr)
+			$previewer->setConversionMgr($conversionmgr);
+		else
+			$previewer->setConverters($previewconverters);
 
 		$subFolders = $this->callHook('folderGetSubFolders', $folder, $orderby[0]);
 		if($subFolders === null)
@@ -550,6 +576,7 @@ $('body').on('click', '.order-btn', function(ev) {
 		$expandFolderTree = $this->params['expandFolderTree'];
 		$showtree = $this->params['showtree'];
 		$cachedir = $this->params['cachedir'];
+		$conversionmgr = $this->params['conversionmgr'];
 		$enableRecursiveCount = $this->params['enableRecursiveCount'];
 		$maxRecursiveCount = $this->params['maxRecursiveCount'];
 		$maxItemsPerPage = $this->params['maxItemsPerPage'];
@@ -561,11 +588,12 @@ $('body').on('click', '.order-btn', function(ev) {
 
 		$folderid = $folder->getId();
 		$previewer = new SeedDMS_Preview_Previewer($cachedir, $previewwidth, $timeout, $xsendfile);
-		$previewer->setConverters($previewconverters);
+		if($conversionmgr)
+			$previewer->setConversionMgr($conversionmgr);
+		else
+			$previewer->setConverters($previewconverters);
 
-		$this->htmlAddHeader('<script type="text/javascript" src="../styles/'.$this->theme.'/bootbox/bootbox.min.js"></script>'."\n", 'js');
-
-		echo $this->callHook('startPage');
+//		echo $this->callHook('startPage');
 		$this->htmlStartPage(getMLText("folder_title", array("foldername" => htmlspecialchars($folder->getName()))));
 		$this->globalNavigation($folder);
 		$this->contentStart();
@@ -592,7 +620,7 @@ $('body').on('click', '.order-btn', function(ev) {
 
 			if ($enableFolderTree) {
 				if ($showtree==1){
-					$this->contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=0\"><i class=\"fa fa-minus-circle\"></i></a>", true);
+					$this->contentHeading("<a href=\"".$this->params['settings']->_httpRoot."out/out.ViewFolder.php?folderid=". $folderid."&showtree=0\"><i class=\"fa fa-minus-circle\"></i></a>", true);
 					$this->contentContainerStart();
 					/*
 					 * access expandFolderTree with $this->params because it can
@@ -601,7 +629,7 @@ $('body').on('click', '.order-btn', function(ev) {
 					$this->printNewTreeNavigationHtml($folderid, M_READ, 0, 'maintree', ($this->params['expandFolderTree'] == 1) ? -1 : 3, $orderby);
 					$this->contentContainerEnd();
 				} else {
-					$this->contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=1\"><i class=\"fa fa-plus-circle\"></i></a>", true);
+					$this->contentHeading("<a href=\"".$this->params['settings']->_httpRoot."out/out.ViewFolder.php?folderid=". $folderid."&showtree=1\"><i class=\"fa fa-plus-circle\"></i></a>", true);
 				}
 			}
 
