@@ -160,6 +160,8 @@ class HTTP_WebDAV_Server_SeedDMS extends HTTP_WebDAV_Server
 			require_once("../inc/inc.ClassLdapAuthentication.php");
 			$authobj = new SeedDMS_LdapAuthentication($this->dms, $settings);
 			$userobj = $authobj->authenticate($user, $pass);
+			if($userobj && $this->logger)
+				$this->logger->log('check_auth: type='.$type.', user='.$user.' authenticated against LDAP', PEAR_LOG_INFO);
 		} /* }}} */
 
 		/* Authenticate against SeedDMS database {{{ */
@@ -167,6 +169,8 @@ class HTTP_WebDAV_Server_SeedDMS extends HTTP_WebDAV_Server
 			require_once("../inc/inc.ClassDbAuthentication.php");
 			$authobj = new SeedDMS_DbAuthentication($this->dms, $settings);
 			$userobj = $authobj->authenticate($user, $pass);
+			if($userobj && $this->logger)
+				$this->logger->log('check_auth: type='.$type.', user='.$user.' authenticated against database', PEAR_LOG_INFO);
 		} /* }}} */
 
 		if(!$userobj) {
@@ -727,7 +731,7 @@ class HTTP_WebDAV_Server_SeedDMS extends HTTP_WebDAV_Server
 							}
 							$approvers = getMandatoryApprovers($document->getFolder(), $this->user);
 						} elseif($settings->_workflowMode == 'advanced') {
-							if($workflows = $user->getMandatoryWorkflows()) {
+							if($workflows = $this->user->getMandatoryWorkflows()) {
 								$workflow = array_shift($workflows);
 							}
 						}
@@ -808,7 +812,7 @@ class HTTP_WebDAV_Server_SeedDMS extends HTTP_WebDAV_Server
 				}
 				$approvers = getMandatoryApprovers($folder, $this->user);
 			} elseif($settings->_workflowMode == 'advanced') {
-				if($workflows = $user->getMandatoryWorkflows()) {
+				if($workflows = $this->user->getMandatoryWorkflows()) {
 					$workflow = array_shift($workflows);
 				}
 			}
@@ -1403,7 +1407,7 @@ class HTTP_WebDAV_Server_SeedDMS extends HTTP_WebDAV_Server
 				}
 				$approvers = getMandatoryApprovers($objdest, $this->user);
 			} elseif($settings->_workflowMode == 'advanced') {
-				if($workflows = $user->getMandatoryWorkflows()) {
+				if($workflows = $this->user->getMandatoryWorkflows()) {
 					$workflow = array_shift($workflows);
 				}
 			}
